@@ -25,7 +25,4 @@ class TableNameCompleter(servercomp.BaseCustomServerSideCompleter):
     def _get_remote_results(self, parsed):
         client = self._get_client('dynamodb', parsed)
         response = self._invoke_api(client, 'list_tables', {})
-        return [
-            table_name for table_name in response.get('TableNames', [])
-        ]
-
+        return [table_name for table_name in response.get('TableNames', [])]
