@@ -11,8 +11,9 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-from awscli.customizations.lightsail.push_container_image \
-    import PushContainerImage
+from awscli.customizations.lightsail.push_container_image import (
+    PushContainerImage,
+)
 
 
 def initialize(cli):
