@@ -10,15 +10,15 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
+import base64
+import hashlib
 import os
 import re
 import shutil
-import hashlib
-import base64
 from pathlib import Path
 
-import pytest
 import py
+import pytest
 
 import awscli
 import backends.pep517
@@ -114,7 +114,8 @@ def test_build_sdist(tmpdir, config_settings):
     assert unpacked_sdist.join("tests", "__init__.py").check()
     assert unpacked_sdist.join("tests", "unit", "__init__.py").check()
     assert unpacked_sdist.join(
-        "tests", "backends", "build_system", "unit", "__init__.py").check()
+        "tests", "backends", "build_system", "unit", "__init__.py"
+    ).check()
     assert unpacked_sdist.join("tests", "__init__.py").check()
 
     # Make sure sdist will be buildable
@@ -122,7 +123,8 @@ def test_build_sdist(tmpdir, config_settings):
     assert unpacked_sdist.join("Makefile.in").check()
     assert unpacked_sdist.join("requirements", "bootstrap.txt").check()
     assert unpacked_sdist.join(
-        "requirements", "download-deps", "bootstrap.txt").check()
+        "requirements", "download-deps", "bootstrap.txt"
+    ).check()
 
     # Make sure exe build files are added to the sdist
     assert unpacked_sdist.join("exe", "pyinstaller", "aws.spec")
@@ -244,7 +246,6 @@ def test_get_requires_for_build_wheel(config_settings, repo_root):
     expected_requirements = [
         "colorama",
         "docutils",
-        "cryptography",
         "ruamel.yaml",
         "ruamel.yaml.clib",
         "prompt-toolkit",
@@ -253,7 +254,6 @@ def test_get_requires_for_build_wheel(config_settings, repo_root):
         "python-dateutil",
         "jmespath",
         "urllib3",
-        "zipp",
     ]
     assert len(expected_requirements) == len(requirements)
     for expected_requirement in expected_requirements:
