@@ -16,5 +16,6 @@ from tests.functional.botocore.docs import BaseDocsFunctionalTest
 class TestAutoscalingDocs(BaseDocsFunctionalTest):
     def test_documents_encoding_of_user_data(self):
         docs = self.get_parameter_documentation_from_service(
-            'autoscaling', 'create_launch_configuration', 'UserData')
+            'autoscaling', 'create_launch_configuration', 'UserData'
+        )
         self.assertIn('base64 encoded automatically', docs.decode('utf-8'))
