@@ -18,13 +18,16 @@ class TestLexDocs(BaseDocsFunctionalTest):
 
     def test_jsonheader_docs(self):
         docs = self.get_docstring_for_method('lex-runtime', 'post_content')
-        self.assert_contains_lines_in_order([
-            '**Request Syntax**',
-            'sessionAttributes=%s,' % self.TYPE_STRING,
-            ':type sessionAttributes: JSON serializable',
-            '**Response Syntax**',
-            '\'slots\': %s,' % self.TYPE_STRING,
-            '\'sessionAttributes\': %s' % self.TYPE_STRING,
-            '**slots** (JSON serializable)',
-            '**sessionAttributes** (JSON serializable)'
-        ], docs)
+        self.assert_contains_lines_in_order(
+            [
+                '**Request Syntax**',
+                f'sessionAttributes={self.TYPE_STRING},',
+                ':type sessionAttributes: JSON serializable',
+                '**Response Syntax**',
+                f'\'slots\': {self.TYPE_STRING},',
+                f'\'sessionAttributes\': {self.TYPE_STRING}',
+                '**slots** (JSON serializable)',
+                '**sessionAttributes** (JSON serializable)',
+            ],
+            docs,
+        )
