@@ -11,43 +11,64 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 import json
-import uuid
-import threading
-import os
 import math
-import time
-import tempfile
+import os
 import shutil
-from datetime import datetime, timedelta
 import sys
+import tempfile
+import threading
+import time
+import uuid
+from datetime import datetime, timedelta, timezone
+from unittest.mock import patch
 
 import pytest
-from dateutil.tz import tzlocal
-from botocore.exceptions import CredentialRetrievalError
-
-from tests import (
-    mock, unittest, IntegerRefresher, BaseEnvVar, BaseSessionTest, random_chars
-)
-from tests import temporary_file, StubbedSession, SessionHTTPStubber
 from botocore import UNSIGNED
-from botocore.credentials import EnvProvider, ContainerProvider
-from botocore.credentials import InstanceMetadataProvider
-from botocore.credentials import Credentials, ReadOnlyCredentials
-from botocore.credentials import AssumeRoleProvider, ProfileProviderBuilder
-from botocore.credentials import CanonicalNameCredentialSourcer
-from botocore.credentials import DeferredRefreshableCredentials
-from botocore.credentials import create_credential_resolver
-from botocore.credentials import JSONFileCache
-from botocore.credentials import SSOProvider
 from botocore.config import Config
+from botocore.credentials import (
+    AssumeRoleProvider,
+    CanonicalNameCredentialSourcer,
+    ContainerProvider,
+    Credentials,
+    DeferredRefreshableCredentials,
+    EnvProvider,
+    InstanceMetadataProvider,
+    JSONFileCache,
+    ProfileProviderBuilder,
+    ReadOnlyCredentials,
+    SSOProvider,
+    create_credential_resolver,
+)
+from botocore.exceptions import (
+    CredentialRetrievalError,
+    InfiniteLoopConfigError,
+    InvalidConfigError,
+)
 from botocore.session import Session
-from botocore.exceptions import InvalidConfigError, InfiniteLoopConfigError
 from botocore.stub import Stubber
 from botocore.tokens import SSOTokenProvider
 from botocore.utils import datetime2timestamp
+from dateutil.tz import tzlocal
 
-TIME_IN_ONE_HOUR = datetime.utcnow() + timedelta(hours=1)
-TIME_IN_SIX_MONTHS = datetime.utcnow() + timedelta(hours=4320)
+from tests import (
+    BaseEnvVar,
+    ClientHTTPStubber,
+    BaseSessionTest,
+    IntegerRefresher,
+    SessionHTTPStubber,
+    StubbedSession,
+    mock,
+    random_chars,
+    temporary_file,
+    unittest,
+)
+from tests.functional.test_useragent import (
+    get_captured_ua_strings,
+    parse_registered_feature_ids,
+)
+
+TIME_IN_ONE_HOUR = datetime.now(tz=timezone.utc) + timedelta(hours=1)
+TIME_IN_SIX_MONTHS = datetime.now(tz=timezone.utc) + timedelta(hours=4320)
 
 
 class TestCredentialRefreshRaces(unittest.TestCase):
@@ -95,16 +116,16 @@ class TestCredentialRefreshRaces(unittest.TestCase):
 
     def test_has_no_race_conditions(self):
         creds = IntegerRefresher(
-            creds_last_for=2,
-            advisory_refresh=1,
-            mandatory_refresh=0
+            creds_last_for=2, advisory_refresh=1, mandatory_refresh=0
         )
+
         def _run_in_thread(collected):
             for _ in range(4000):
                 frozen = creds.get_frozen_credentials()
-                collected.append((frozen.access_key,
-                                  frozen.secret_key,
-                                  frozen.token))
+                collected.append(
+                    (frozen.access_key, frozen.secret_key, frozen.token)
+                )
+
         start = time.time()
         self.assert_consistent_credentials_seen(creds, _run_in_thread)
         end = time.time()
@@ -112,39 +133,41 @@ class TestCredentialRefreshRaces(unittest.TestCase):
         # So, for example, if execution time took 6.1 seconds, then
         # we should see a maximum number of refreshes being (6 / 2.0) + 1 = 4
         max_calls_allowed = math.ceil((end - start) / 2.0) + 1
-        self.assertTrue(creds.refresh_counter <= max_calls_allowed,
-                        "Too many cred refreshes, max: %s, actual: %s, "
-                        "time_delta: %.4f" % (max_calls_allowed,
-                                              creds.refresh_counter,
-                                              (end - start)))
+        self.assertTrue(
+            creds.refresh_counter <= max_calls_allowed,
+            f"Too many cred refreshes, max: {max_calls_allowed}, actual: {creds.refresh_counter}, "
+            f"time_delta: {end - start:.4f}",
+        )
 
     def test_no_race_for_immediate_advisory_expiration(self):
         creds = IntegerRefresher(
-            creds_last_for=1,
-            advisory_refresh=1,
-            mandatory_refresh=0
+            creds_last_for=1, advisory_refresh=1, mandatory_refresh=0
         )
+
         def _run_in_thread(collected):
             for _ in range(100):
                 frozen = creds.get_frozen_credentials()
-                collected.append((frozen.access_key,
-                                  frozen.secret_key,
-                                  frozen.token))
+                collected.append(
+                    (frozen.access_key, frozen.secret_key, frozen.token)
+                )
+
         self.assert_consistent_credentials_seen(creds, _run_in_thread)
 
     def test_no_race_for_initial_refresh_of_deferred_refreshable(self):
         def get_credentials():
             expiry_time = (
-                datetime.now(tzlocal()) + timedelta(hours=24)).isoformat()
+                datetime.now(tzlocal()) + timedelta(hours=24)
+            ).isoformat()
             return {
                 'access_key': 'my-access-key',
                 'secret_key': 'my-secret-key',
                 'token': 'my-token',
-                'expiry_time': expiry_time
+                'expiry_time': expiry_time,
             }
 
         deferred_creds = DeferredRefreshableCredentials(
-            get_credentials, 'fixed')
+            get_credentials, 'fixed'
+        )
 
         def _run_in_thread(collected):
             frozen = deferred_creds.get_frozen_credentials()
@@ -155,7 +178,7 @@ class TestCredentialRefreshRaces(unittest.TestCase):
 
 class BaseAssumeRoleTest(BaseEnvVar):
     def setUp(self):
-        super(BaseAssumeRoleTest, self).setUp()
+        super().setUp()
         self.tempdir = tempfile.mkdtemp()
         self.config_file = os.path.join(self.tempdir, 'config')
         self.environ['AWS_CONFIG_FILE'] = self.config_file
@@ -163,7 +186,7 @@ class BaseAssumeRoleTest(BaseEnvVar):
 
     def tearDown(self):
         shutil.rmtree(self.tempdir)
-        super(BaseAssumeRoleTest, self).tearDown()
+        super().tearDown()
 
     def some_future_time(self):
         timeobj = datetime.now(tzlocal())
@@ -178,21 +201,24 @@ class BaseAssumeRoleTest(BaseEnvVar):
                 'AccessKeyId': credentials.access_key,
                 'SecretAccessKey': credentials.secret_key,
                 'SessionToken': credentials.token,
-                'Expiration': expiration
+                'Expiration': expiration,
             },
             'AssumedRoleUser': {
                 'AssumedRoleId': 'myroleid',
-                'Arn': 'arn:aws:iam::1234567890:user/myuser'
-            }
+                'Arn': 'arn:aws:iam::1234567890:user/myuser',
+            },
         }
 
         return response
 
     def create_random_credentials(self):
         return Credentials(
-            'fake-%s' % random_chars(15),
-            'fake-%s' % random_chars(35),
-            'fake-%s' % random_chars(45)
+            f'fake-{random_chars(15)}',
+            f'fake-{random_chars(35)}',
+            f'fake-{random_chars(45)}',
+            # The account_id gets resolved from the
+            # Arn in create_assume_role_response().
+            account_id='1234567890',
         )
 
     def assert_creds_equal(self, c1, c2):
@@ -211,7 +237,7 @@ class BaseAssumeRoleTest(BaseEnvVar):
 
 class TestAssumeRole(BaseAssumeRoleTest):
     def setUp(self):
-        super(TestAssumeRole, self).setUp()
+        super().setUp()
         self.environ['AWS_ACCESS_KEY_ID'] = 'access_key'
         self.environ['AWS_SECRET_ACCESS_KEY'] = 'secret_key'
 
@@ -225,9 +251,7 @@ class TestAssumeRole(BaseAssumeRoleTest):
         credential_process = os.path.join(
             current_dir, 'utils', 'credentialprocess.py'
         )
-        self.credential_process = '%s %s' % (
-            sys.executable, credential_process
-        )
+        self.credential_process = f'{sys.executable} {credential_process}'
 
     def mock_provider(self, provider_cls):
         mock_instance = mock.Mock(spec=provider_cls)
@@ -253,10 +277,13 @@ class TestAssumeRole(BaseAssumeRoleTest):
             client_creator=self.mock_client_creator,
             cache={},
             profile_name=profile,
-            credential_sourcer=CanonicalNameCredentialSourcer([
-                self.env_provider, self.container_provider,
-                self.metadata_provider
-            ]),
+            credential_sourcer=CanonicalNameCredentialSourcer(
+                [
+                    self.env_provider,
+                    self.container_provider,
+                    self.metadata_provider,
+                ]
+            ),
             profile_provider_builder=ProfileProviderBuilder(
                 session,
                 sso_token_cache=sso_token_cache,
@@ -272,7 +299,7 @@ class TestAssumeRole(BaseAssumeRoleTest):
             'env': self.env_provider,
             'iam-role': self.metadata_provider,
             'container-role': self.container_provider,
-            'assume-role': assume_role_provider
+            'assume-role': assume_role_provider,
         }
         for name, provider in replacements.items():
             try:
@@ -283,9 +310,7 @@ class TestAssumeRole(BaseAssumeRoleTest):
 
             resolver.providers[index] = provider
 
-        session.register_component(
-            'credential_provider', resolver
-        )
+        session.register_component('credential_provider', resolver)
         return session, stubber
 
     def test_assume_role(self):
@@ -470,7 +495,7 @@ class TestAssumeRole(BaseAssumeRoleTest):
             'role_arn = arn:aws:iam::123456789:role/RoleA\n'
             'source_profile = B\n'
             '[profile B]\n'
-            'credential_process = %s\n' % self.credential_process
+            f'credential_process = {self.credential_process}\n'
         )
         self.write_config(config)
 
@@ -503,7 +528,7 @@ class TestAssumeRole(BaseAssumeRoleTest):
             'source_profile = B\n'
             '[profile B]\n'
             'role_arn = arn:aws:iam::123456789:role/RoleB\n'
-            'web_identity_token_file = %s\n' % token_path
+            f'web_identity_token_file = {token_path}\n'
         )
         self.write_config(config)
 
@@ -544,7 +569,7 @@ class TestAssumeRole(BaseAssumeRoleTest):
             'role_arn = arn:aws:iam::123456789:role/RoleA\n'
             'source_profile = B\n'
             '[profile B]\n'
-            'web_identity_token_file = %s\n' % token_path
+            f'web_identity_token_file = {token_path}\n'
         )
         self.write_config(config)
 
@@ -559,7 +584,9 @@ class TestAssumeRole(BaseAssumeRoleTest):
         token_cache_key = 'f395038c92f1828cbb3991d2d6152d326b895606'
         cached_token = {
             'accessToken': 'a.token',
-            'expiresAt': self.some_future_time(),
+            'expiresAt': self.some_future_time().strftime(
+                "%Y-%m-%dT%H:%M:%SZ"
+            ),
         }
         temp_cache = JSONFileCache(self.tempdir)
         temp_cache[token_cache_key] = cached_token
@@ -755,10 +782,30 @@ class TestAssumeRole(BaseAssumeRoleTest):
         self.assert_creds_equal(creds, expected_creds)
         self.assertEqual(self.actual_client_region, 'cn-north-1')
 
+    def test_assume_role_resolves_account_id(self):
+        config = (
+            '[profile A]\n'
+            'role_arn = arn:aws:iam::1234567890:role/RoleA\n'
+            'source_profile = B\n\n'
+            '[profile B]\n'
+            'aws_access_key_id = foo\n'
+            'aws_secret_access_key = bar\n'
+        )
+        self.write_config(config)
+        expected_creds = self.create_random_credentials()
+        response = self.create_assume_role_response(expected_creds)
+
+        session, stubber = self.create_session(profile='A')
+        stubber.add_response('assume_role', response)
+
+        actual_creds = session.get_credentials()
+        self.assert_creds_equal(actual_creds, expected_creds)
+        self.assertEqual(actual_creds.account_id, '1234567890')
+
 
 class TestAssumeRoleWithWebIdentity(BaseAssumeRoleTest):
     def setUp(self):
-        super(TestAssumeRoleWithWebIdentity, self).setUp()
+        super().setUp()
         self.token_file = os.path.join(self.tempdir, 'token.jwt')
         self.write_token('totally.a.token')
 
@@ -774,9 +821,7 @@ class TestAssumeRoleWithWebIdentity(BaseAssumeRoleTest):
         session = StubbedSession(**kwargs)
         stubber = session.stub('sts')
         stubber.add_response(
-            'assume_role_with_web_identity',
-            response,
-            expected_params
+            'assume_role_with_web_identity', response, expected_params
         )
         stubber.activate()
         actual_creds = session.get_credentials()
@@ -788,8 +833,8 @@ class TestAssumeRoleWithWebIdentity(BaseAssumeRoleTest):
             '[profile A]\n'
             'role_arn = arn:aws:iam::123456789:role/RoleA\n'
             'role_session_name = sname\n'
-            'web_identity_token_file = %s\n'
-        ) % self.token_file
+            f'web_identity_token_file = {self.token_file}\n'
+        )
         self.write_config(config)
         expected_params = {
             'RoleArn': 'arn:aws:iam::123456789:role/RoleA',
@@ -799,10 +844,7 @@ class TestAssumeRoleWithWebIdentity(BaseAssumeRoleTest):
         self.assert_session_credentials(expected_params, profile='A')
 
     def test_assume_role_env_vars(self):
-        config = (
-            '[profile B]\n'
-            'region = us-west-2\n'
-        )
+        config = '[profile B]\n' 'region = us-west-2\n'
         self.write_config(config)
         self.environ['AWS_ROLE_ARN'] = 'arn:aws:iam::123456789:role/RoleB'
         self.environ['AWS_WEB_IDENTITY_TOKEN_FILE'] = self.token_file
@@ -820,8 +862,8 @@ class TestAssumeRoleWithWebIdentity(BaseAssumeRoleTest):
             '[profile A]\n'
             'role_arn = arn:aws:iam::123456789:role/RoleA\n'
             'role_session_name = aname\n'
-            'web_identity_token_file = %s\n'
-        ) % self.token_file
+            f'web_identity_token_file = {self.token_file}\n'
+        )
         self.write_config(config)
 
         different_token = os.path.join(self.tempdir, str(uuid.uuid4()))
@@ -844,9 +886,7 @@ class TestProcessProvider(unittest.TestCase):
         credential_process = os.path.join(
             current_dir, 'utils', 'credentialprocess.py'
         )
-        self.credential_process = '%s %s' % (
-            sys.executable, credential_process
-        )
+        self.credential_process = f'{sys.executable} {credential_process}'
         self.environ = os.environ.copy()
         self.environ_patch = mock.patch('os.environ', self.environ)
         self.environ_patch.start()
@@ -855,10 +895,7 @@ class TestProcessProvider(unittest.TestCase):
         self.environ_patch.stop()
 
     def test_credential_process(self):
-        config = (
-            '[profile processcreds]\n'
-            'credential_process = %s\n'
-        )
+        config = '[profile processcreds]\n' 'credential_process = %s\n'
         config = config % self.credential_process
         with temporary_file('w') as f:
             f.write(config)
@@ -901,7 +938,6 @@ class TestProcessProvider(unittest.TestCase):
 
 
 class TestInstanceMetadataFetcher(BaseSessionTest):
-
     @mock.patch('botocore.httpsession.URLLib3Session.send')
     def test_imds_use_truncated_user_agent(self, send):
         self.session.user_agent_version = '24.0'
@@ -1055,3 +1091,523 @@ class SSOSessionTest(BaseEnvVar):
             }
         }
         stubber.add_response(body=json.dumps(response).encode('utf-8'))
+
+
+@pytest.mark.parametrize(
+    "environ_vars,fake_credentials,patches,expected_feature_id",
+    [
+        # Test case 1: IMDS credentials
+        (
+            {},
+            {},
+            [
+                patch(
+                    "botocore.utils.InstanceMetadataFetcher.retrieve_iam_role_credentials",
+                    return_value={
+                        "role_name": "FAKEROLE",
+                        "access_key": "FAKEACCESSKEY",
+                        "secret_key": "FAKESECRET",
+                        "token": "FAKETOKEN",
+                        "expiry_time": "2099-01-01T00:00:00Z",
+                    },
+                ),
+                patch(
+                    "botocore.credentials.ContainerProvider.load",
+                    return_value=None,
+                ),
+                patch(
+                    "botocore.credentials.ConfigProvider.load",
+                    return_value=None,
+                ),
+                patch(
+                    "botocore.credentials.SharedCredentialProvider.load",
+                    return_value=None,
+                ),
+                patch(
+                    "botocore.credentials.EnvProvider.load", return_value=None
+                ),
+            ],
+            '0',
+        ),
+        # Test case 2: HTTP credentials (container)
+        (
+            {
+                'AWS_CONTAINER_CREDENTIALS_FULL_URI': 'http://localhost/foo',
+                'AWS_CONTAINER_AUTHORIZATION_TOKEN': 'Basic auth-token',
+            },
+            {},
+            [
+                patch(
+                    "botocore.credentials.ContainerMetadataFetcher.retrieve_full_uri",
+                    return_value={
+                        "AccessKeyId": "FAKEACCESSKEY",
+                        "SecretAccessKey": "FAKESECRET",
+                        "Token": "FAKETOKEN",
+                        "Expiration": "2099-01-01T00:00:00Z",
+                        "AccountId": "01234567890",
+                    },
+                ),
+                patch(
+                    "botocore.credentials.ConfigProvider.load",
+                    return_value=None,
+                ),
+                patch(
+                    "botocore.credentials.SharedCredentialProvider.load",
+                    return_value=None,
+                ),
+                patch(
+                    "botocore.credentials.EnvProvider.load", return_value=None
+                ),
+            ],
+            'z',
+        ),
+        # Test case 3: Credentials set via Environment variables
+        (
+            {
+                'AWS_ACCESS_KEY_ID': 'FAKEACCESSKEY',
+                'AWS_SECRET_ACCESS_KEY': 'FAKESECRET',
+                'AWS_SESSION_TOKEN': 'FAKETOKEN',
+            },
+            {},
+            [],
+            'g',
+        ),
+        # Test case 4: Credentials set via code
+        (
+            {},
+            {
+                'aws_access_key_id': 'FAKEACCESSKEY',
+                'aws_secret_access_key': 'FAKESECRET',
+                'aws_session_token': 'FAKETOKEN',
+            },
+            [],
+            'e',
+        ),
+        # Test case 5: Credentials set with Boto2 config
+        (
+            {},
+            {},
+            [
+                patch(
+                    "botocore.configloader.raw_config_parse",
+                    return_value={
+                        "Credentials": {
+                            "aws_access_key_id": "FAKEACCESSKEY",
+                            "aws_secret_access_key": "FAKESECRETKEY",
+                        }
+                    },
+                ),
+                patch(
+                    "botocore.credentials.ConfigProvider.load",
+                    return_value=None,
+                ),
+                patch(
+                    "botocore.credentials.SharedCredentialProvider.load",
+                    return_value=None,
+                ),
+                                patch(
+                    "botocore.credentials.EnvProvider.load", return_value=None
+                ),
+            ],
+            'x',
+        ),
+        # Test case 6: Credentials set via process provider
+        (
+            {},
+            {},
+            [
+                patch(
+                    "botocore.credentials.ProcessProvider._retrieve_credentials_using",
+                    return_value={
+                        'access_key': "FAKEACCESSKEY",
+                        'secret_key': "FAKESECRETKEY",
+                        'token': "FAKETOKEN",
+                    },
+                ),
+                patch(
+                    "botocore.credentials.ProcessProvider._credential_process",
+                    return_value="Mock_credential_process",
+                ),
+                patch(
+                    "botocore.credentials.ContainerProvider.load",
+                    return_value=None,
+                ),
+                patch(
+                    "botocore.credentials.ConfigProvider.load",
+                    return_value=None,
+                ),
+                patch(
+                    "botocore.credentials.SharedCredentialProvider.load",
+                    return_value=None,
+                ),
+                patch(
+                    "botocore.credentials.EnvProvider.load", return_value=None
+                ),
+            ],
+            ['v', 'w'],
+        ),
+    ],
+)
+def test_user_agent_feature_ids(
+    environ_vars,
+    fake_credentials,
+    patches,
+    expected_feature_id,
+    monkeypatch,
+    patched_session,
+):
+    for var, value in environ_vars.items():
+        monkeypatch.setenv(var, value)
+
+    for patch_obj in patches:
+        patch_obj.start()
+
+    try:
+        client = patched_session.create_client(
+            "s3", region_name="us-east-1", **fake_credentials
+        )
+        _assert_feature_ids_in_ua(client, expected_feature_id)
+    finally:
+        for patch_obj in patches:
+            patch_obj.stop()
+
+
+@pytest.mark.parametrize(
+    "creds_env_var,creds_file_content,patches,expected_feature_id",
+    [
+        (
+            'AWS_SHARED_CREDENTIALS_FILE',
+            '[default]\naws_access_key_id = FAKEACCESSKEY\naws_secret_access_key = FAKESECRET',
+            [
+                patch(
+                    "botocore.credentials.AssumeRoleProvider.load",
+                    return_value=None,
+                ),
+                patch(
+                    "botocore.credentials.EnvProvider.load", return_value=None
+                ),
+            ],
+            'n',
+        ),
+        (
+            'AWS_CONFIG_FILE',
+            '[default]\naws_access_key_id = FAKEACCESSKEY\naws_secret_access_key = FAKESECRET',
+            [
+                patch(
+                    "botocore.credentials.AssumeRoleProvider.load",
+                    return_value=None,
+                ),
+                patch(
+                    "botocore.credentials.EnvProvider.load", return_value=None
+                ),
+                patch(
+                    "botocore.credentials.SharedCredentialProvider.load",
+                    return_value=None,
+                ),
+            ],
+            'n',
+        ),
+    ],
+)
+def test_user_agent_has_file_based_feature_ids(
+    creds_env_var,
+    creds_file_content,
+    patches,
+    expected_feature_id,
+    tmp_path,
+    monkeypatch,
+):
+    credentials_file = tmp_path / "creds"
+    credentials_file.write_text(creds_file_content)
+    monkeypatch.setenv(creds_env_var, str(credentials_file))
+
+    for patch_obj in patches:
+        patch_obj.start()
+
+    try:
+        session = Session()
+        client = session.create_client("s3", region_name="us-east-1")
+        _assert_feature_ids_in_ua(client, expected_feature_id)
+    finally:
+        for patch_obj in patches:
+            patch_obj.stop()
+
+
+def _assert_feature_ids_in_ua(client, expected_feature_ids):
+    """Helper to test feature IDs appear in user agent for multiple calls."""
+    with ClientHTTPStubber(client, strict=True) as http_stubber:
+        http_stubber.add_response()
+        http_stubber.add_response()
+        client.list_buckets()
+        client.list_buckets()
+
+    ua_strings = get_captured_ua_strings(http_stubber)
+    for ua_string in ua_strings:
+        feature_list = parse_registered_feature_ids(ua_string)
+        for expected_id in expected_feature_ids:
+            assert expected_id in feature_list
+
+
+@patch("botocore.credentials.CachedCredentialFetcher._load_from_cache")
+@patch("botocore.credentials.SSOProvider._load_sso_config")
+@patch(
+    "botocore.credentials.AssumeRoleWithWebIdentityProvider.load",
+    return_value=None,
+)
+@patch("botocore.credentials.AssumeRoleProvider.load", return_value=None)
+@patch("botocore.credentials.EnvProvider.load", return_value=None)
+def test_user_agent_has_sso_legacy_credentials_feature_id(
+    _unused_mock_env_load,
+    _unused_mock_shared_load,
+    _unused_mock_config_load,
+    mock_load_sso_config,
+    mock_load_sso_credentials,
+    monkeypatch,
+    patched_session,
+):
+    fake_fetcher_kwargs = {
+        'sso_start_url': "https://test.awsapps.com/start",
+        'sso_region': "us-east-1",
+        'sso_role_name': "Administrator",
+        'sso_account_id': "1234567890",
+    }
+    fake_response = {
+        "ProviderType": "sso",
+        "Credentials": {
+            "role_name": "FAKEROLE",
+            "AccessKeyId": "FAKEACCESSKEY",
+            "SecretAccessKey": "FAKESECRET",
+            "SessionToken": "FAKETOKEN",
+            "Expiration": "2099-01-01T00:00:00Z",
+        },
+    }
+
+    mock_load_sso_config.return_value = fake_fetcher_kwargs
+    client_one = patched_session.create_client("s3", region_name="us-east-1")
+    mock_load_sso_credentials.return_value = fake_response
+
+    _assert_feature_ids_in_ua(client_one, ['t', 'u'])
+
+
+@patch("botocore.credentials.CachedCredentialFetcher._load_from_cache")
+@patch("botocore.credentials.SSOProvider._load_sso_config")
+@patch(
+    "botocore.credentials.AssumeRoleWithWebIdentityProvider.load",
+    return_value=None,
+)
+@patch("botocore.credentials.AssumeRoleProvider.load", return_value=None)
+@patch("botocore.credentials.EnvProvider.load", return_value=None)
+def test_user_agent_has_sso_credentials_feature_id(
+    _unused_mock_env_load,
+    _unused_mock_shared_load,
+    _unused_mock_config_load,
+    mock_load_sso_config,
+    mock_load_sso_credentials,
+    monkeypatch,
+    patched_session,
+):
+    fake_fetcher_kwargs = {
+        'sso_session': 'sample_test',
+        'sso_start_url': "https://test.awsapps.com/start",
+        'sso_region': "us-east-1",
+        'sso_role_name': "Administrator",
+        'sso_account_id': "1234567890",
+    }
+    fake_response = {
+        "ProviderType": "sso",
+        "Credentials": {
+            "role_name": "FAKEROLE",
+            "AccessKeyId": "FAKEACCESSKEY",
+            "SecretAccessKey": "FAKESECRET",
+            "SessionToken": "FAKETOKEN",
+            "Expiration": "2099-01-01T00:00:00Z",
+        },
+    }
+
+    mock_load_sso_config.return_value = fake_fetcher_kwargs
+    client_one = patched_session.create_client("s3", region_name="us-east-1")
+    mock_load_sso_credentials.return_value = fake_response
+
+    _assert_feature_ids_in_ua(client_one, ['r', 's'])
+
+
+@pytest.mark.parametrize(
+    "config_content,env_vars,expected_source_features,expected_provider_feature",
+    [
+        # Test Case 1: Assume Role with source profile
+        (
+            '''[profile assume-role-test]
+role_arn = arn:aws:iam::123456789012:role/test-role
+source_profile = base
+
+[profile base]
+aws_access_key_id = FAKEACCESSKEY
+aws_secret_access_key = FAKESECRET''',
+            {},
+            [
+                'n',  # CREDENTIALS_PROFILE
+                'o',  # CREDENTIALS_PROFILE_SOURCE_PROFILE
+            ],
+            'i',  # CREDENTIALS_STS_ASSUME_ROLE
+        ),
+        # Test Case 2: Assume Role with named provider
+        (
+            '''[profile assume-role-test]
+role_arn = arn:aws:iam::123456789012:role/test-role
+credential_source = Environment''',
+            {
+                'AWS_ACCESS_KEY_ID': 'FAKEACCESSKEY',
+                'AWS_SECRET_ACCESS_KEY': 'FAKESECRET',
+            },
+            [
+                'g',  # CREDENTIALS_ENV_VARS
+                'p',  # CREDENTIALS_PROFILE_NAMED_PROVIDER
+            ],
+            'i',  # CREDENTIALS_STS_ASSUME_ROLE
+        ),
+    ],
+)
+def test_user_agent_has_assume_role_feature_ids(
+    config_content,
+    env_vars,
+    expected_source_features,
+    expected_provider_feature,
+    tmp_path,
+):
+    session = _create_assume_role_session(config_content, tmp_path)
+
+    # Set env vars if needed
+    with patch.dict(os.environ, env_vars, clear=True):
+        with SessionHTTPStubber(session) as stubber:
+            s3 = session.create_client('s3', region_name='us-east-1')
+            _add_assume_role_http_response(stubber, with_web_identity=False)
+            stubber.add_response()
+            stubber.add_response()
+            s3.list_buckets()
+            s3.list_buckets()
+
+    ua_strings = get_captured_ua_strings(stubber)
+    _assert_deferred_credential_feature_ids(
+        ua_strings, expected_source_features, expected_provider_feature
+    )
+
+
+@pytest.mark.parametrize(
+    "config_content,env_vars,expected_source_features,expected_provider_feature",
+    [
+        # Test Case 1: Assume Role with Web Identity through config profile
+        (
+            '''[profile assume-role-test]
+role_arn = arn:aws:iam::123456789012:role/test-role
+web_identity_token_file = {token_file}''',
+            {},
+            ['q'],  # CREDENTIALS_PROFILE_STS_WEB_ID_TOKEN
+            'k',  # CREDENTIALS_STS_ASSUME_ROLE_WEB_ID
+        ),
+        # Test Case 2: Assume Role with Web Identity through env vars
+        (
+            '',
+            {
+                'AWS_ROLE_ARN': 'arn:aws:iam::123456789012:role/test-role',
+                'AWS_WEB_IDENTITY_TOKEN_FILE': '{token_file}',
+                'AWS_ROLE_SESSION_NAME': 'test-session',
+            },
+            ['h'],  # CREDENTIALS_ENV_VARS_STS_WEB_ID_TOKEN
+            'k',  # CREDENTIALS_STS_ASSUME_ROLE_WEB_ID
+        ),
+    ],
+)
+def test_user_agent_has_assume_role_with_web_identity_feature_ids(
+    config_content,
+    env_vars,
+    expected_source_features,
+    expected_provider_feature,
+    tmp_path,
+):
+    token_file = tmp_path / 'token.jwt'
+    token_file.write_text('fake-jwt-token')
+    if 'AWS_WEB_IDENTITY_TOKEN_FILE' in env_vars:
+        env_vars['AWS_WEB_IDENTITY_TOKEN_FILE'] = str(token_file)
+    elif config_content and 'web_identity_token_file' in config_content:
+        config_content = config_content.replace(
+            '{token_file}', str(token_file)
+        )
+
+    session = _create_assume_role_session(config_content, tmp_path)
+
+    # Set env vars if needed
+    with patch.dict(os.environ, env_vars, clear=True):
+        with SessionHTTPStubber(session) as stubber:
+            s3 = session.create_client('s3', region_name='us-east-1')
+            _add_assume_role_http_response(stubber, with_web_identity=True)
+            stubber.add_response()
+            stubber.add_response()
+            s3.list_buckets()
+            s3.list_buckets()
+
+    ua_strings = get_captured_ua_strings(stubber)
+    _assert_deferred_credential_feature_ids(
+        ua_strings, expected_source_features, expected_provider_feature
+    )
+
+
+def _create_assume_role_session(config_content, tmp_path):
+    if config_content:
+        config_file = tmp_path / 'config'
+        config_file.write_text(config_content)
+        session = Session(profile='assume-role-test')
+        session.set_config_variable('config_file', str(config_file))
+    else:
+        session = Session()
+    return session
+
+
+def _add_assume_role_http_response(stubber, with_web_identity):
+    """Add HTTP response for AssumeRole or AssumeRoleWithWebIdentity call with proper credentials"""
+    expiration = (datetime.now(timezone.utc) + timedelta(hours=1)).strftime(
+        '%Y-%m-%dT%H:%M:%SZ'
+    )
+    method_name = (
+        'AssumeRoleWithWebIdentity' if with_web_identity else 'AssumeRole'
+    )
+    body = (
+        f'<{method_name}Response>'
+        f'  <{method_name}Result>'
+        '    <AssumedRoleUser>'
+        '      <Arn>arn:aws:sts::123456789012:user</Arn>'
+        '      <AssumedRoleId>AKID:test-session-123</AssumedRoleId>'
+        '    </AssumedRoleUser>'
+        '    <Credentials>'
+        f'      <AccessKeyId>FAKEASSUMEROLEKEY</AccessKeyId>'
+        f'      <SecretAccessKey>FAKEASSUMEROLSECRET</SecretAccessKey>'
+        '      <SessionToken>FAKETOKEN</SessionToken>'
+        f'      <Expiration>{expiration}</Expiration>'
+        '    </Credentials>'
+        f'  </{method_name}Result>'
+        f'</{method_name}Response>'
+    )
+    stubber.add_response(body=body.encode('utf-8'))
+
+
+def _assert_deferred_credential_feature_ids(
+    ua_strings,
+    expected_source_features,
+    expected_provider_feature,
+):
+    """Helper to assert feature IDs for deferred credential provider tests"""
+    assert len(ua_strings) == 3
+
+    # Request to fetch credentials should only register feature ids for the credential source
+    credential_source_feature_list = parse_registered_feature_ids(
+        ua_strings[0]
+    )
+    for feature in expected_source_features:
+        assert feature in credential_source_feature_list
+    assert expected_provider_feature not in credential_source_feature_list
+
+    # Original operation request should register feature ids for both the credential source and the provider
+    for i in [1, 2]:
+        operation_feature_list = parse_registered_feature_ids(ua_strings[i])
+        for feature in expected_source_features:
+            assert feature in operation_feature_list
+        assert expected_provider_feature in operation_feature_list
