@@ -14,20 +14,18 @@ import re
 from contextlib import contextmanager
 
 import pytest
-
-from tests import unittest, mock, BaseSessionTest, ClientHTTPStubber
-
 from botocore import exceptions
-from botocore.exceptions import (
-    UnsupportedS3ControlArnError,
-    InvalidHostLabelError,
-    ParamValidationError,
-)
-from botocore.session import Session
+from botocore.awsrequest import AWSResponse
 from botocore.compat import urlsplit
 from botocore.config import Config
-from botocore.awsrequest import AWSResponse
+from botocore.exceptions import (
+    InvalidHostLabelError,
+    ParamValidationError,
+    UnsupportedS3ControlArnError,
+)
+from botocore.session import Session
 
+from tests import BaseSessionTest, ClientHTTPStubber, mock, unittest
 
 ACCESSPOINT_ARN_TEST_CASES = [
     # Outpost accesspoint arn test cases
@@ -45,7 +43,7 @@ ACCESSPOINT_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
@@ -58,7 +56,7 @@ ACCESSPOINT_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
@@ -66,7 +64,7 @@ ACCESSPOINT_ARN_TEST_CASES = [
         'config': {'s3': {'use_arn_region': False}},
         'assertions': {
             'exception': 'UnsupportedS3ControlConfigurationError',
-        }
+        },
     },
     {
         'arn': 'arn:aws-cn:s3-outposts:cn-north-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
@@ -74,7 +72,7 @@ ACCESSPOINT_ARN_TEST_CASES = [
         'config': {'s3': {'use_arn_region': True}},
         'assertions': {
             'exception': 'UnsupportedS3ControlConfigurationError',
-        }
+        },
     },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:us-gov-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
@@ -87,7 +85,7 @@ ACCESSPOINT_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:us-gov-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
@@ -100,15 +98,15 @@ ACCESSPOINT_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
-       'arn': 'arn:aws-us-gov:s3-outposts:fips-us-gov-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
-       'region': 'fips-us-gov-east-1',
-       'config': {'s3': {'use_arn_region': True}},
-       'assertions': {
-           'exception': 'UnsupportedS3ControlArnError',
-       }
+        'arn': 'arn:aws-us-gov:s3-outposts:fips-us-gov-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
+        'region': 'fips-us-gov-east-1',
+        'config': {'s3': {'use_arn_region': True}},
+        'assertions': {
+            'exception': 'UnsupportedS3ControlArnError',
+        },
     },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:us-gov-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
@@ -121,7 +119,7 @@ ACCESSPOINT_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
@@ -140,25 +138,25 @@ ACCESSPOINT_ARN_TEST_CASES = [
         'config': {'s3': {'use_accelerate_endpoint': True}},
         'assertions': {
             'exception': 'UnsupportedS3ControlConfigurationError',
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:op-01234567890123456',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:myaccesspoint',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
 ]
 
@@ -176,7 +174,7 @@ BUCKET_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-east-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -189,7 +187,7 @@ BUCKET_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-east-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -197,7 +195,7 @@ BUCKET_ARN_TEST_CASES = [
         'config': {'s3': {'use_arn_region': False}},
         'assertions': {
             'exception': 'UnsupportedS3ControlConfigurationError',
-        }
+        },
     },
     {
         'arn': 'arn:aws-cn:s3-outposts:cn-north-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -205,7 +203,7 @@ BUCKET_ARN_TEST_CASES = [
         'config': {'s3': {'use_arn_region': True}},
         'assertions': {
             'exception': 'UnsupportedS3ControlConfigurationError',
-        }
+        },
     },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:us-gov-east-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -218,7 +216,7 @@ BUCKET_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:us-gov-east-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -231,7 +229,7 @@ BUCKET_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:fips-us-gov-east-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -239,7 +237,7 @@ BUCKET_ARN_TEST_CASES = [
         'config': {'s3': {'use_arn_region': True}},
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:us-gov-east-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -252,7 +250,7 @@ BUCKET_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -271,25 +269,25 @@ BUCKET_ARN_TEST_CASES = [
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:op-01234567890123456',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:bucket',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:op-01234567890123456:bucket',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
 ]
 
@@ -378,11 +376,9 @@ def _assert_test_case(test_case, client, stubber):
         exception_cls = getattr(exceptions, assertions['exception'])
         if exception_raised is None:
             raise RuntimeError(
-                'Expected exception "%s" was not raised' % exception_cls
+                f'Expected exception "{exception_cls}" was not raised'
             )
-        error_msg = (
-            'Expected exception "%s", got "%s"'
-        ) % (exception_cls, type(exception_raised))
+        error_msg = f'Expected exception "{exception_cls}", got "{type(exception_raised)}"'
         assert isinstance(exception_raised, exception_cls), error_msg
     else:
         assert len(stubber.requests) == 1
