@@ -10,26 +10,22 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-from datetime import datetime
 import re
+from datetime import datetime
 
-from tests import BaseSessionTest
-from tests import mock
-from tests import assert_url_equal
-from tests import ClientHTTPStubber
 from botocore.config import Config
 from botocore.stub import Stubber
 
+from tests import BaseSessionTest, ClientHTTPStubber, assert_url_equal, mock
 
 _V4_SIGNING_REGION_REGEX = re.compile(
-    r'AWS4-HMAC-SHA256 '
-    r'Credential=\w+/\d+/(?P<signing_region>[a-z0-9-]+)/'
+    r'AWS4-HMAC-SHA256 ' r'Credential=\w+/\d+/(?P<signing_region>[a-z0-9-]+)/'
 )
 
 
 class TestSTSPresignedUrl(BaseSessionTest):
     def setUp(self):
-        super(TestSTSPresignedUrl, self).setUp()
+        super().setUp()
         self.client = self.session.create_client('sts', 'us-west-2')
         # Makes sure that no requests will go through
         self.stubber = Stubber(self.client)
@@ -54,23 +50,25 @@ class TestSTSPresignedUrl(BaseSessionTest):
 
 
 class TestSTSEndpoints(BaseSessionTest):
-    def create_sts_client(self, region, endpoint_url=None, use_ssl=True,
-                          config=None):
+    def create_sts_client(
+        self, region, endpoint_url=None, use_ssl=True, config=None
+    ):
         return self.session.create_client(
-            'sts', region_name=region, endpoint_url=endpoint_url,
-            use_ssl=use_ssl, config=config
+            'sts',
+            region_name=region,
+            endpoint_url=endpoint_url,
+            use_ssl=use_ssl,
+            config=config,
         )
 
     def set_sts_regional_for_config_file(self, fileobj, config_val):
-        fileobj.write(
-            '[default]\n'
-            'sts_regional_endpoints=%s\n' % config_val
-        )
+        fileobj.write('[default]\n' f'sts_regional_endpoints={config_val}\n')
         fileobj.flush()
         self.environ['AWS_CONFIG_FILE'] = fileobj.name
 
-    def assert_request_sent(self, sts, expected_url,
-                            expected_signing_region=None):
+    def assert_request_sent(
+        self, sts, expected_url, expected_signing_region=None
+    ):
         body = (
             b'<GetCallerIdentityResponse>'
             b'  <GetCallerIdentityResult>'
@@ -91,7 +89,7 @@ class TestSTSEndpoints(BaseSessionTest):
             if expected_signing_region:
                 self.assertEqual(
                     self._get_signing_region(captured_request),
-                    expected_signing_region
+                    expected_signing_region,
                 )
 
     def _get_signing_region(self, request):
@@ -104,7 +102,7 @@ class TestSTSEndpoints(BaseSessionTest):
         self.assert_request_sent(
             sts,
             expected_url='https://sts.us-west-2.amazonaws.com/',
-            expected_signing_region='us-west-2'
+            expected_signing_region='us-west-2',
         )
 
     def test_fips_endpoint(self):
@@ -112,7 +110,7 @@ class TestSTSEndpoints(BaseSessionTest):
         self.assert_request_sent(
             sts,
             expected_url='https://sts-fips.us-west-2.amazonaws.com/',
-            expected_signing_region='us-west-2'
+            expected_signing_region='us-west-2',
         )
 
     def test_dualstack_endpoint(self):
@@ -121,7 +119,7 @@ class TestSTSEndpoints(BaseSessionTest):
         self.assert_request_sent(
             sts,
             expected_url='https://sts.us-west-2.api.aws/',
-            expected_signing_region='us-west-2'
+            expected_signing_region='us-west-2',
         )
 
     def test_nonaws_partition_region(self):
@@ -129,7 +127,7 @@ class TestSTSEndpoints(BaseSessionTest):
         self.assert_request_sent(
             sts,
             expected_url='https://sts.cn-north-1.amazonaws.com.cn/',
-            expected_signing_region='cn-north-1'
+            expected_signing_region='cn-north-1',
         )
 
     def test_global_region_with_regional_configured(self):
@@ -137,7 +135,7 @@ class TestSTSEndpoints(BaseSessionTest):
         self.assert_request_sent(
             sts,
             expected_url='https://sts.amazonaws.com/',
-            expected_signing_region='us-east-1'
+            expected_signing_region='us-east-1',
         )
 
     def test_client_for_unknown_region(self):
@@ -145,7 +143,7 @@ class TestSTSEndpoints(BaseSessionTest):
         self.assert_request_sent(
             sts,
             expected_url='https://sts.not-real.amazonaws.com/',
-            expected_signing_region='not-real'
+            expected_signing_region='not-real',
         )
 
 
