@@ -27,7 +27,7 @@ class BaseSelectTest(BaseAWSCommandParamsTest):
 
 class TestSelect(BaseSelectTest):
     def setUp(self):
-        super(TestSelect, self).setUp()
+        super().setUp()
         self.parsed_response = {
             "Count": 1,
             "Items": [{"foo": {"S": "spam"}}],
@@ -54,16 +54,14 @@ class TestSelect(BaseSelectTest):
             "Items": [{"foo": {"N": "2"}}],
             "ScannedCount": 1,
         }
-        command = [
-            'ddb', 'select', 'mytable', '--key-condition', 'foo = 1'
-        ]
+        command = ['ddb', 'select', 'mytable', '--key-condition', 'foo = 1']
         expected_params = {
             'TableName': 'mytable',
             'ReturnConsumedCapacity': 'NONE',
             'ConsistentRead': True,
             'KeyConditionExpression': '#n0 = :n1',
             'ExpressionAttributeNames': {'#n0': 'foo'},
-            'ExpressionAttributeValues': {':n1': {'N': '1'}}
+            'ExpressionAttributeValues': {':n1': {'N': '1'}},
         }
         stdout, _, _ = self.assert_params_for_cmd(
             command, expected_params, expected_rc=0
@@ -86,9 +84,7 @@ class TestSelect(BaseSelectTest):
         self.assert_yaml_response_equal(stdout, self.parsed_response)
 
     def test_select_with_projection(self):
-        command = [
-            'ddb', 'select', 'mytable', '--projection', 'foo'
-        ]
+        command = ['ddb', 'select', 'mytable', '--projection', 'foo']
         expected_params = {
             'TableName': 'mytable',
             'ReturnConsumedCapacity': 'NONE',
@@ -108,7 +104,11 @@ class TestSelect(BaseSelectTest):
             "ScannedCount": 1,
         }
         command = [
-            'ddb', 'select', 'mytable', '--filter', 'foo BETWEEN 1 AND 3'
+            'ddb',
+            'select',
+            'mytable',
+            '--filter',
+            'foo BETWEEN 1 AND 3',
         ]
 
         expected_params = {
@@ -120,7 +120,7 @@ class TestSelect(BaseSelectTest):
             'ExpressionAttributeValues': {
                 ':n1': {'N': '1'},
                 ':n2': {'N': '3'},
-            }
+            },
         }
         stdout, _, _ = self.assert_params_for_cmd(
             command, expected_params, expected_rc=0
@@ -129,7 +129,11 @@ class TestSelect(BaseSelectTest):
 
     def test_filter_with_function(self):
         command = [
-            'ddb', 'select', 'mytable', '--filter', 'contains(foo, "bar")'
+            'ddb',
+            'select',
+            'mytable',
+            '--filter',
+            'contains(foo, "bar")',
         ]
 
         expected_params = {
@@ -140,7 +144,7 @@ class TestSelect(BaseSelectTest):
             'ExpressionAttributeNames': {'#n0': 'foo'},
             'ExpressionAttributeValues': {
                 ':n1': {'S': 'bar'},
-            }
+            },
         }
         stdout, _, _ = self.assert_params_for_cmd(
             command, expected_params, expected_rc=0
@@ -148,9 +152,7 @@ class TestSelect(BaseSelectTest):
         self.assert_yaml_response_equal(stdout, self.parsed_response)
 
     def test_filter_with_set(self):
-        command = [
-            'ddb', 'select', 'mytable', '--filter', 'foo = {1, 2, 3}'
-        ]
+        command = ['ddb', 'select', 'mytable', '--filter', 'foo = {1, 2, 3}']
 
         expected_params = {
             'TableName': 'mytable',
@@ -160,7 +162,7 @@ class TestSelect(BaseSelectTest):
             'ExpressionAttributeNames': {'#n0': 'foo'},
             'ExpressionAttributeValues': {
                 ':n1': {'NS': ['1', '2', '3']},
-            }
+            },
         }
         stdout, _, _ = self.assert_params_for_cmd(
             command, expected_params, expected_rc=0
@@ -168,9 +170,7 @@ class TestSelect(BaseSelectTest):
         self.assert_yaml_response_equal(stdout, self.parsed_response)
 
     def test_filter_with_bytes(self):
-        command = [
-            'ddb', 'select', 'mytable', '--filter', 'foo <> b"4pyT"'
-        ]
+        command = ['ddb', 'select', 'mytable', '--filter', 'foo <> b"4pyT"']
 
         expected_params = {
             'TableName': 'mytable',
@@ -181,7 +181,7 @@ class TestSelect(BaseSelectTest):
             'ExpressionAttributeValues': {
                 # This will be base64 encoded during serialization
                 ':n1': {'B': b'\xe2\x9c\x93'},
-            }
+            },
         }
         stdout, _, _ = self.assert_params_for_cmd(
             command, expected_params, expected_rc=0
@@ -190,7 +190,11 @@ class TestSelect(BaseSelectTest):
 
     def test_filter_with_list(self):
         command = [
-            'ddb', 'select', 'mytable', '--filter', 'foo <> [-1, 2, "3"]'
+            'ddb',
+            'select',
+            'mytable',
+            '--filter',
+            'foo <> [-1, 2, "3"]',
         ]
 
         expected_params = {
@@ -200,10 +204,14 @@ class TestSelect(BaseSelectTest):
             'FilterExpression': '#n0 <> :n1',
             'ExpressionAttributeNames': {'#n0': 'foo'},
             'ExpressionAttributeValues': {
-                ':n1': {'L': [
-                    {'N': '-1'}, {'N': '2'}, {'S': '3'},
-                ]},
-            }
+                ':n1': {
+                    'L': [
+                        {'N': '-1'},
+                        {'N': '2'},
+                        {'S': '3'},
+                    ]
+                },
+            },
         }
         stdout, _, _ = self.assert_params_for_cmd(
             command, expected_params, expected_rc=0
@@ -211,9 +219,7 @@ class TestSelect(BaseSelectTest):
         self.assert_yaml_response_equal(stdout, self.parsed_response)
 
     def test_filter_with_map(self):
-        command = [
-            'ddb', 'select', 'mytable', '--filter', 'foo <> {"bar": 4}'
-        ]
+        command = ['ddb', 'select', 'mytable', '--filter', 'foo <> {"bar": 4}']
 
         expected_params = {
             'TableName': 'mytable',
@@ -223,7 +229,7 @@ class TestSelect(BaseSelectTest):
             'ExpressionAttributeNames': {'#n0': 'foo'},
             'ExpressionAttributeValues': {
                 ':n1': {'M': {"bar": {"N": "4"}}},
-            }
+            },
         }
         stdout, _, _ = self.assert_params_for_cmd(
             command, expected_params, expected_rc=0
@@ -231,9 +237,7 @@ class TestSelect(BaseSelectTest):
         self.assert_yaml_response_equal(stdout, self.parsed_response)
 
     def test_select_with_attributes_all(self):
-        command = [
-            'ddb', 'select', 'mytable', '--attributes', 'ALL'
-        ]
+        command = ['ddb', 'select', 'mytable', '--attributes', 'ALL']
         expected_params = {
             'TableName': 'mytable',
             'ReturnConsumedCapacity': 'NONE',
@@ -247,8 +251,13 @@ class TestSelect(BaseSelectTest):
 
     def test_select_with_attributes_all_projected(self):
         command = [
-            'ddb', 'select', 'mytable', '--attributes', 'ALL_PROJECTED',
-            '--index-name', 'myindex',
+            'ddb',
+            'select',
+            'mytable',
+            '--attributes',
+            'ALL_PROJECTED',
+            '--index-name',
+            'myindex',
         ]
         expected_params = {
             'TableName': 'mytable',
@@ -267,9 +276,7 @@ class TestSelect(BaseSelectTest):
             "Count": 1,
             "ScannedCount": 1,
         }
-        command = [
-            'ddb', 'select', 'mytable', '--attributes', 'COUNT'
-        ]
+        command = ['ddb', 'select', 'mytable', '--attributes', 'COUNT']
         expected_params = {
             'TableName': 'mytable',
             'ReturnConsumedCapacity': 'NONE',
@@ -283,7 +290,10 @@ class TestSelect(BaseSelectTest):
 
     def test_select_consistent_read(self):
         command = [
-            'ddb', 'select', 'mytable', '--consistent-read',
+            'ddb',
+            'select',
+            'mytable',
+            '--consistent-read',
         ]
         expected_params = {
             'TableName': 'mytable',
@@ -297,7 +307,10 @@ class TestSelect(BaseSelectTest):
 
     def test_select_no_consistent_read(self):
         command = [
-            'ddb', 'select', 'mytable', '--no-consistent-read',
+            'ddb',
+            'select',
+            'mytable',
+            '--no-consistent-read',
         ]
         expected_params = {
             'TableName': 'mytable',
@@ -311,7 +324,10 @@ class TestSelect(BaseSelectTest):
 
     def test_select_no_return_consumed_capacity(self):
         command = [
-            'ddb', 'select', 'mytable', '--no-return-consumed-capacity',
+            'ddb',
+            'select',
+            'mytable',
+            '--no-return-consumed-capacity',
         ]
         expected_params = {
             'TableName': 'mytable',
@@ -325,7 +341,10 @@ class TestSelect(BaseSelectTest):
 
     def test_select_return_consumed_capacity(self):
         command = [
-            'ddb', 'select', 'mytable', '--return-consumed-capacity',
+            'ddb',
+            'select',
+            'mytable',
+            '--return-consumed-capacity',
         ]
         expected_params = {
             'TableName': 'mytable',
@@ -339,8 +358,12 @@ class TestSelect(BaseSelectTest):
 
     def test_select_return_consumed_capacity_with_index(self):
         command = [
-            'ddb', 'select', 'mytable', '--return-consumed-capacity',
-            '--index-name', 'myindex',
+            'ddb',
+            'select',
+            'mytable',
+            '--return-consumed-capacity',
+            '--index-name',
+            'myindex',
         ]
         expected_params = {
             'TableName': 'mytable',
@@ -354,9 +377,7 @@ class TestSelect(BaseSelectTest):
         self.assert_yaml_response_equal(stdout, self.parsed_response)
 
     def test_select_with_query(self):
-        command = [
-            'ddb', 'select', 'mytable', '--query', 'Items'
-        ]
+        command = ['ddb', 'select', 'mytable', '--query', 'Items']
         expected_params = {
             'TableName': 'mytable',
             'ReturnConsumedCapacity': 'NONE',
@@ -405,10 +426,15 @@ class TestSelect(BaseSelectTest):
             'ScannedCount': 1,
         }
         command = [
-            'ddb', 'select', 'laptops',
-            '--projection', 'name, price',
-            '--filter', 'price < 3000',
-            '--key-condition', 'name = "macbook"',
+            'ddb',
+            'select',
+            'laptops',
+            '--projection',
+            'name, price',
+            '--filter',
+            'price < 3000',
+            '--key-condition',
+            'name = "macbook"',
         ]
         expected = {
             'TableName': 'laptops',
@@ -426,8 +452,7 @@ class TestSelect(BaseSelectTest):
             'ExpressionAttributeValues': {
                 ':n3': {'N': '3000'},
                 ':n5': {'S': 'macbook'},
-            }
-
+            },
         }
         stdout, _, _ = self.assert_params_for_cmd(
             command, expected, expected_rc=0
@@ -436,14 +461,19 @@ class TestSelect(BaseSelectTest):
     def test_select_project_complex_identifier(self):
         self.parsed_response = {
             'Count': 1,
-            'Items': [{
-                'name': {'S': 'spam n eggs'},
-                'ingredients': {'L': [{'M': {'name': {'S': 'spam'}}}]},
-            }]
+            'Items': [
+                {
+                    'name': {'S': 'spam n eggs'},
+                    'ingredients': {'L': [{'M': {'name': {'S': 'spam'}}}]},
+                }
+            ],
         }
         command = [
-            'ddb', 'select', 'recipes',
-            '--projection', 'name, ingredients[8].name',
+            'ddb',
+            'select',
+            'recipes',
+            '--projection',
+            'name, ingredients[8].name',
         ]
         expected = {
             'TableName': 'recipes',
@@ -454,11 +484,9 @@ class TestSelect(BaseSelectTest):
                 '#n0': 'name',
                 '#n1': 'ingredients',
                 '#n2': 'name',
-            }
+            },
         }
-        self.assert_params_for_cmd(
-            command, expected, expected_rc=0
-        )
+        self.assert_params_for_cmd(command, expected, expected_rc=0)
 
     def test_select_unsupported_output(self):
         unsupported_output = ['json', 'table', 'text', 'yaml-stream']
@@ -466,20 +494,22 @@ class TestSelect(BaseSelectTest):
             with self.subTest(output):
                 cmdline = f'ddb select mytable --output {output}'
                 stdout, _, _ = self.assert_params_for_cmd(
-                    cmdline, expected_rc=252,
+                    cmdline,
+                    expected_rc=252,
                     stderr_contains=f'{output} output format is not supported for ddb commands',
                 )
 
     def test_select_parsing_error_rc(self):
         cmdline = 'ddb select mytable --filter a=?!f'
         stdout, _, _ = self.assert_params_for_cmd(
-            cmdline, expected_rc=252,
+            cmdline,
+            expected_rc=252,
         )
 
 
 class TestSelectPagination(BaseSelectTest):
     def setUp(self):
-        super(TestSelectPagination, self).setUp()
+        super().setUp()
         self.parsed_responses = [
             {
                 "Count": 1,
@@ -495,24 +525,17 @@ class TestSelectPagination(BaseSelectTest):
         ]
 
     def test_select_paginates(self):
-        command = [
-            'ddb', 'select', 'mytable'
-        ]
+        command = ['ddb', 'select', 'mytable']
         stdout, _, _ = self.run_cmd(command, expected_rc=0)
         expected_response = {
             'Count': 2,
-            'Items': [
-                {'foo': 1},
-                {'foo': 2}
-            ],
-            'ScannedCount': 2
+            'Items': [{'foo': 1}, {'foo': 2}],
+            'ScannedCount': 2,
         }
         self.assert_yaml_response_equal(stdout, expected_response)
 
     def test_no_paginate(self):
-        command = [
-            'ddb', 'select', 'mytable', '--no-paginate'
-        ]
+        command = ['ddb', 'select', 'mytable', '--no-paginate']
         stdout, _, _ = self.run_cmd(command, expected_rc=0)
         expected_response = {
             "Count": 1,
@@ -524,15 +547,18 @@ class TestSelectPagination(BaseSelectTest):
 
     def test_no_paginate_with_paging_params_set(self):
         command = [
-            'ddb', 'select', 'mytable', '--no-paginate', '--max-items', '1'
+            'ddb',
+            'select',
+            'mytable',
+            '--no-paginate',
+            '--max-items',
+            '1',
         ]
         _, stderr, _ = self.run_cmd(command, expected_rc=252)
         self.assertIn('Cannot specify --no-paginate along with ', stderr)
 
     def test_max_items(self):
-        command = [
-            'ddb', 'select', 'mytable', '--max-items', '1'
-        ]
+        command = ['ddb', 'select', 'mytable', '--max-items', '1']
         stdout, _, _ = self.run_cmd(command, expected_rc=0)
         expected_response = {
             'Count': 1,
@@ -547,9 +573,7 @@ class TestSelectPagination(BaseSelectTest):
         self.assert_yaml_response_equal(stdout, expected_response)
 
     def test_page_size(self):
-        command = [
-            'ddb', 'select', 'mytable', '--page-size', '1'
-        ]
+        command = ['ddb', 'select', 'mytable', '--page-size', '1']
         stdout, _, _ = self.run_cmd(command, expected_rc=0)
         params = self.operations_called[1][1]
         expected_initial_params = {
@@ -563,22 +587,24 @@ class TestSelectPagination(BaseSelectTest):
 
         expected_response = {
             'Count': 2,
-            'Items': [
-                {'foo': 1},
-                {'foo': 2}
-            ],
-            'ScannedCount': 2
+            'Items': [{'foo': 1}, {'foo': 2}],
+            'ScannedCount': 2,
         }
         self.assert_yaml_response_equal(stdout, expected_response)
 
     def test_starting_token(self):
-        self.parsed_responses = [{
-            "Count": 1,
-            "Items": [{"foo": {"N": "2"}}],
-            "ScannedCount": 1,
-        }]
+        self.parsed_responses = [
+            {
+                "Count": 1,
+                "Items": [{"foo": {"N": "2"}}],
+                "ScannedCount": 1,
+            }
+        ]
         command = [
-            'ddb', 'select', 'mytable', '--starting-token',
+            'ddb',
+            'select',
+            'mytable',
+            '--starting-token',
             'eyJFeGNsdXNpdmVTdGFydEtleSI6IHsiZm9vIjogeyJOIjogIjEifX19',
         ]
         expected_params = {
@@ -591,11 +617,8 @@ class TestSelectPagination(BaseSelectTest):
             command, expected_params, expected_rc=0
         )
         expected_response = {
-            'Count': 0,
-            'Items': [
-                {'foo': 2}
-            ],
-            'ScannedCount': 0
+            'Count': 1,
+            'Items': [{'foo': 2}],
+            'ScannedCount': 1,
         }
         self.assert_yaml_response_equal(stdout, expected_response)
-
