@@ -14,22 +14,19 @@
 import base64
 import datetime
 
-import mock
-from six.moves import cStringIO
-
 import awscli.customizations.ec2.bundleinstance
-from awscli.compat import six
-from awscli.testutils import BaseAWSCommandParamsTest
+from awscli.compat import StringIO
+from awscli.testutils import BaseAWSCommandParamsTest, mock
 
 
 class TestBundleInstance(BaseAWSCommandParamsTest):
-
     prefix = 'ec2 bundle-instance'
 
     POLICY = (
         b'{"expiration": "2013-08-10T00:00:00.000000Z",'
         b'"conditions": [{"bucket": "mybucket"},{"acl": '
-        b'"ec2-bundle-read"},["starts-with", "$key", "foobar"]]}')
+        b'"ec2-bundle-read"},["starts-with", "$key", "foobar"]]}'
+    )
     POLICY_SIGNATURE = 'ynxybUMv9YuGbPl7HZ8AFJW/2t0='
 
     def setUp(self):
@@ -40,8 +37,9 @@ class TestBundleInstance(BaseAWSCommandParamsTest):
         # don't what the policy or its signature to change each time
         # we run the test.
         self.datetime_patcher = mock.patch.object(
-            awscli.customizations.ec2.bundleinstance.datetime, 'datetime',
-            mock.Mock(wraps=datetime.datetime)
+            awscli.customizations.ec2.bundleinstance.datetime,
+            'datetime',
+            mock.Mock(wraps=datetime.datetime),
         )
         mocked_datetime = self.datetime_patcher.start()
         mocked_datetime.utcnow.return_value = datetime.datetime(2013, 8, 9)
@@ -55,43 +53,53 @@ class TestBundleInstance(BaseAWSCommandParamsTest):
         args += ' --owner-sak wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY'
         args += ' --bucket mybucket --prefix foobar'
         args_list = (self.prefix + args).split()
-        result =  {'InstanceId': 'i-12345678',
-                   'Storage': {
-                       'S3': {
-                           'Bucket': 'mybucket',
-                           'Prefix': 'foobar',
-                           'AWSAccessKeyId': 'AKIAIOSFODNN7EXAMPLE',
-                           'UploadPolicy': self.POLICY,
-                           'UploadPolicySignature': self.POLICY_SIGNATURE}
-                       }
-                   }
+        result = {
+            'InstanceId': 'i-12345678',
+            'Storage': {
+                'S3': {
+                    'Bucket': 'mybucket',
+                    'Prefix': 'foobar',
+                    'AWSAccessKeyId': 'AKIAIOSFODNN7EXAMPLE',
+                    'UploadPolicy': self.POLICY,
+                    'UploadPolicySignature': self.POLICY_SIGNATURE,
+                }
+            },
+        }
         self.assert_params_for_cmd(args_list, result)
 
-
     def test_policy_provided(self):
         policy = '{"notarealpolicy":true}'
-        base64policy = base64.encodebytes(six.b(policy)).strip().decode('utf-8')
+        base64policy = (
+            base64.encodebytes(policy.encode('latin-1'))
+            .strip()
+            .decode('utf-8')
+        )
         policy_signature = 'a5SmoLOxoM0MHpOdC25nE7KIafg='
         args = ' --instance-id i-12345678 --owner-akid AKIAIOSFODNN7EXAMPLE'
         args += ' --owner-sak wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY'
         args += ' --bucket mybucket --prefix foobar --policy %s' % base64policy
         args_list = (self.prefix + args).split()
-        result =  {'InstanceId': 'i-12345678',
-                   'Storage': {
-                       'S3': {
-                           'Bucket': 'mybucket',
-                           'Prefix': 'foobar',
-                           'AWSAccessKeyId': 'AKIAIOSFODNN7EXAMPLE',
-                           'UploadPolicy': b'{"notarealpolicy":true}',
-                           'UploadPolicySignature': policy_signature}
-                       }
-                   }
+        result = {
+            'InstanceId': 'i-12345678',
+            'Storage': {
+                'S3': {
+                    'Bucket': 'mybucket',
+                    'Prefix': 'foobar',
+                    'AWSAccessKeyId': 'AKIAIOSFODNN7EXAMPLE',
+                    'UploadPolicy': b'{"notarealpolicy":true}',
+                    'UploadPolicySignature': policy_signature,
+                }
+            },
+        }
         self.assert_params_for_cmd(args_list, result)
 
     def test_both(self):
-        captured = cStringIO()
+        captured = StringIO()
         json = """{"S3":{"Bucket":"foobar","Prefix":"fiebaz"}}"""
-        args = ' --instance-id i-12345678 --owner-akid blah --owner-sak blah --storage %s' % json
+        args = (
+            ' --instance-id i-12345678 --owner-akid blah --owner-sak blah --storage %s'
+            % json
+        )
         args_list = (self.prefix + args).split()
         _, stderr, _ = self.assert_params_for_cmd(args_list, expected_rc=252)
         self.assertIn('Mixing the --storage option', stderr)
