@@ -14,19 +14,14 @@ from awscli.testutils import BaseAWSCommandParamsTest
 
 
 class TestViewBilling(BaseAWSCommandParamsTest):
-
     prefix = 'route53domains view-billing'
 
     def test_accepts_start_time(self):
         command = self.prefix + ' --start-time 2'
-        expected_params = {
-            'Start': '2'
-        }
+        expected_params = {'Start': '2'}
         self.assert_params_for_cmd(command, expected_params)
 
     def test_accepts_end_time(self):
         command = self.prefix + ' --end-time 2'
-        expected_params = {
-            'End': '2'
-        }
+        expected_params = {'End': '2'}
         self.assert_params_for_cmd(command, expected_params)
