@@ -13,36 +13,44 @@
 import os
 
 from awscrt.s3 import S3RequestType
+
 from awscli.compat import BytesIO
 from awscli.customizations.s3.utils import relative_path
-from awscli.testutils import mock, cd
+from awscli.testutils import cd, mock
 from tests.functional.s3 import (
-    BaseS3TransferCommandTest, BaseS3CLIRunnerTest, BaseCRTTransferClientTest
+    BaseCRTTransferClientTest,
+    BaseS3CLIRunnerTest,
+    BaseS3TransferCommandTest,
 )
 
-class TestSyncCommand(BaseS3TransferCommandTest):
 
+class TestSyncCommand(BaseS3TransferCommandTest):
     prefix = 's3 sync '
 
     def test_website_redirect_ignore_paramfile(self):
         full_path = self.files.create_file('foo.txt', 'mycontent')
-        cmdline = '%s %s s3://bucket/key.txt --website-redirect %s' % \
-            (self.prefix, self.files.rootdir, 'http://someserver')
+        cmdline = '%s %s s3://bucket/key.txt --website-redirect %s' % (
+            self.prefix,
+            self.files.rootdir,
+            'http://someserver',
+        )
         self.parsed_responses = [
             {"CommonPrefixes": [], "Contents": []},
-            {'ETag': '"c8afdb36c52cf4727836669019e69222"'}
+            {'ETag': '"c8afdb36c52cf4727836669019e69222"'},
         ]
         self.run_cmd(cmdline, expected_rc=0)
 
         # The only operations we should have called are ListObjectsV2/PutObject.
-        self.assertEqual(len(self.operations_called), 2, self.operations_called)
+        self.assertEqual(
+            len(self.operations_called), 2, self.operations_called
+        )
         self.assertEqual(self.operations_called[0][0].name, 'ListObjectsV2')
         self.assertEqual(self.operations_called[1][0].name, 'PutObject')
         # Make sure that the specified web address is used as opposed to the
         # contents of the web address when uploading the object
         self.assertEqual(
             self.operations_called[1][1]['WebsiteRedirectLocation'],
-            'http://someserver'
+            'http://someserver',
         )
 
     def test_no_recursive_option(self):
@@ -53,9 +61,7 @@ class TestSyncCommand(BaseS3TransferCommandTest):
     def test_sync_from_non_existant_directory(self):
         non_existant_directory = os.path.join(self.files.rootdir, 'fakedir')
         cmdline = '%s %s s3://bucket/' % (self.prefix, non_existant_directory)
-        self.parsed_responses = [
-            {"CommonPrefixes": [], "Contents": []}
-        ]
+        self.parsed_responses = [{"CommonPrefixes": [], "Contents": []}]
         _, stderr, _ = self.run_cmd(cmdline, expected_rc=255)
         self.assertIn('does not exist', stderr)
 
@@ -64,71 +70,100 @@ class TestSyncCommand(BaseS3TransferCommandTest):
         non_existant_directory = os.path.join(self.files.rootdir, 'fakedir')
         cmdline = '%s s3://bucket/ %s' % (self.prefix, non_existant_directory)
         self.parsed_responses = [
-            {"CommonPrefixes": [], "Contents": [
-                {"Key": key, "Size": 3,
-                 "LastModified": "2014-01-09T20:45:49.000Z"}]},
-            {'ETag': '"c8afdb36c52cf4727836669019e69222-"',
-             'Body': BytesIO(b'foo')}
+            {
+                "CommonPrefixes": [],
+                "Contents": [
+                    {
+                        "Key": key,
+                        "Size": 3,
+                        "LastModified": "2014-01-09T20:45:49.000Z",
+                        "ETag": '"c8afdb36c52cf4727836669019e69222-"',
+                    }
+                ],
+            },
+            {
+                'ETag': '"c8afdb36c52cf4727836669019e69222-"',
+                'Body': BytesIO(b'foo'),
+            },
         ]
         self.run_cmd(cmdline, expected_rc=0)
         # Make sure the file now exists.
         self.assertTrue(
-            os.path.exists(os.path.join(non_existant_directory, key)))
+            os.path.exists(os.path.join(non_existant_directory, key))
+        )
 
     def test_dryrun_sync(self):
         self.parsed_responses = [
             self.list_objects_response([]),
         ]
         full_path = self.files.create_file('file.txt', 'mycontent')
-        cmdline = (
-            f'{self.prefix} {self.files.rootdir} s3://bucket/ --dryrun'
-        )
+        cmdline = f'{self.prefix} {self.files.rootdir} s3://bucket/ --dryrun'
         stdout, _, _ = self.run_cmd(cmdline, expected_rc=0)
         self.assert_operations_called(
             [
-                ('ListObjectsV2', {
-                    'Bucket': 'bucket',
-                    'Prefix': '',
-                }),
+                (
+                    'ListObjectsV2',
+                    {
+                        'Bucket': 'bucket',
+                        'Prefix': '',
+                    },
+                ),
             ]
         )
         self.assertIn(
             f'(dryrun) upload: {relative_path(full_path)} to '
             f's3://bucket/file.txt',
-            stdout
+            stdout,
         )
 
     def test_glacier_sync_with_force_glacier(self):
         self.parsed_responses = [
             {
                 'Contents': [
-                    {'Key': 'foo/bar.txt', 'ContentLength': '100',
-                     'LastModified': '00:00:00Z',
-                     'StorageClass': 'GLACIER',
-                     'Size': 100},
+                    {
+                        'Key': 'foo/bar.txt',
+                        'ContentLength': '100',
+                        'LastModified': '00:00:00Z',
+                        'StorageClass': 'GLACIER',
+                        'Size': 100,
+                        'ETag': '"foo-1"',
+                    },
                 ],
-                'CommonPrefixes': []
+                'CommonPrefixes': [],
             },
             {'ETag': '"foo-1"', 'Body': BytesIO(b'foo')},
         ]
         cmdline = '%s s3://bucket/foo %s --force-glacier-transfer' % (
-            self.prefix, self.files.rootdir)
+            self.prefix,
+            self.files.rootdir,
+        )
         self.run_cmd(cmdline, expected_rc=0)
-        self.assertEqual(len(self.operations_called), 2, self.operations_called)
+        self.assertEqual(
+            len(self.operations_called), 2, self.operations_called
+        )
         self.assertEqual(self.operations_called[0][0].name, 'ListObjectsV2')
         self.assertEqual(self.operations_called[1][0].name, 'GetObject')
 
     def test_handles_glacier_incompatible_operations(self):
         self.parsed_responses = [
-            {'Contents': [
-                {'Key': 'foo', 'Size': 100,
-                 'LastModified': '00:00:00Z', 'StorageClass': 'GLACIER'},
-                {'Key': 'bar', 'Size': 100,
-                 'LastModified': '00:00:00Z', 'StorageClass': 'DEEP_ARCHIVE'}
-            ]}
+            {
+                'Contents': [
+                    {
+                        'Key': 'foo',
+                        'Size': 100,
+                        'LastModified': '00:00:00Z',
+                        'StorageClass': 'GLACIER',
+                    },
+                    {
+                        'Key': 'bar',
+                        'Size': 100,
+                        'LastModified': '00:00:00Z',
+                        'StorageClass': 'DEEP_ARCHIVE',
+                    },
+                ]
+            }
         ]
-        cmdline = '%s s3://bucket/ %s' % (
-            self.prefix, self.files.rootdir)
+        cmdline = '%s s3://bucket/ %s' % (self.prefix, self.files.rootdir)
         _, stderr, _ = self.run_cmd(cmdline, expected_rc=2)
         # There should not have been a download attempted because the
         # operation was skipped because it is glacier and glacier
@@ -141,15 +176,27 @@ class TestSyncCommand(BaseS3TransferCommandTest):
 
     def test_turn_off_glacier_warnings(self):
         self.parsed_responses = [
-            {'Contents': [
-                {'Key': 'foo', 'Size': 100,
-                 'LastModified': '00:00:00Z', 'StorageClass': 'GLACIER'},
-                {'Key': 'bar', 'Size': 100,
-                 'LastModified': '00:00:00Z', 'StorageClass': 'DEEP_ARCHIVE'}
-            ]}
+            {
+                'Contents': [
+                    {
+                        'Key': 'foo',
+                        'Size': 100,
+                        'LastModified': '00:00:00Z',
+                        'StorageClass': 'GLACIER',
+                    },
+                    {
+                        'Key': 'bar',
+                        'Size': 100,
+                        'LastModified': '00:00:00Z',
+                        'StorageClass': 'DEEP_ARCHIVE',
+                    },
+                ]
+            }
         ]
         cmdline = '%s s3://bucket/ %s --ignore-glacier-warnings' % (
-            self.prefix, self.files.rootdir)
+            self.prefix,
+            self.files.rootdir,
+        )
         _, stderr, _ = self.run_cmd(cmdline, expected_rc=0)
         # There should not have been a download attempted because the
         # operation was skipped because it is glacier incompatible.
@@ -160,39 +207,47 @@ class TestSyncCommand(BaseS3TransferCommandTest):
     def test_warning_on_invalid_timestamp(self):
         full_path = self.files.create_file('foo.txt', 'mycontent')
 
-        cmdline = '%s %s s3://bucket/key.txt' % \
-                  (self.prefix, self.files.rootdir)
+        cmdline = '%s %s s3://bucket/key.txt' % (
+            self.prefix,
+            self.files.rootdir,
+        )
         self.parsed_responses = [
             {"CommonPrefixes": [], "Contents": []},
-            {'ETag': '"c8afdb36c52cf4727836669019e69222"'}
+            {'ETag': '"c8afdb36c52cf4727836669019e69222"'},
         ]
         # Patch get_file_stat to return a value indicating that an invalid
         # timestamp was loaded. It is impossible to set an invalid timestamp
         # on all OSes so it has to be patched.
         # TODO: find another method to test this behavior without patching.
         with mock.patch(
-                'awscli.customizations.s3.filegenerator.get_file_stat',
-                return_value=(None, None)
+            'awscli.customizations.s3.filegenerator.get_file_stat',
+            return_value=(None, None),
         ):
             self.run_cmd(cmdline, expected_rc=2)
 
         # We should still have put the object
-        self.assertEqual(len(self.operations_called), 2, self.operations_called)
+        self.assertEqual(
+            len(self.operations_called), 2, self.operations_called
+        )
         self.assertEqual(self.operations_called[0][0].name, 'ListObjectsV2')
         self.assertEqual(self.operations_called[1][0].name, 'PutObject')
 
     def test_sync_with_delete_on_downloads(self):
         full_path = self.files.create_file('foo.txt', 'mycontent')
         cmdline = '%s s3://bucket %s --delete' % (
-            self.prefix, self.files.rootdir)
+            self.prefix,
+            self.files.rootdir,
+        )
         self.parsed_responses = [
             {"CommonPrefixes": [], "Contents": []},
-            {'ETag': '"c8afdb36c52cf4727836669019e69222"'}
+            {'ETag': '"c8afdb36c52cf4727836669019e69222"'},
         ]
         self.run_cmd(cmdline, expected_rc=0)
 
         # The only operations we should have called are ListObjectsV2.
-        self.assertEqual(len(self.operations_called), 1, self.operations_called)
+        self.assertEqual(
+            len(self.operations_called), 1, self.operations_called
+        )
         self.assertEqual(self.operations_called[0][0].name, 'ListObjectsV2')
 
         self.assertFalse(os.path.exists(full_path))
@@ -203,10 +258,11 @@ class TestSyncCommand(BaseS3TransferCommandTest):
     # the behaviour should be the same: skip the file and emit a warning.
     #
     # This test covers the case where a ValueError is emitted.
-    def test_sync_skips_over_files_deleted_between_listing_and_transfer_valueerror(self):
+    def test_sync_skips_over_files_deleted_between_listing_and_transfer_valueerror(
+        self,
+    ):
         full_path = self.files.create_file('foo.txt', 'mycontent')
-        cmdline = '%s %s s3://bucket/' % (
-            self.prefix, self.files.rootdir)
+        cmdline = '%s %s s3://bucket/' % (self.prefix, self.files.rootdir)
 
         # FileGenerator.list_files should skip over files that cause an
         # IOError to be raised because they are missing when we try to
@@ -215,22 +271,26 @@ class TestSyncCommand(BaseS3TransferCommandTest):
         def side_effect(_):
             os.remove(full_path)
             raise ValueError()
+
         with mock.patch(
-                'awscli.customizations.s3.filegenerator.get_file_stat',
-                side_effect=side_effect
-                ):
+            'awscli.customizations.s3.filegenerator.get_file_stat',
+            side_effect=side_effect,
+        ):
             self.run_cmd(cmdline, expected_rc=2)
 
         # We should not call PutObject because the file was deleted
         # before we could transfer it
-        self.assertEqual(len(self.operations_called), 1, self.operations_called)
+        self.assertEqual(
+            len(self.operations_called), 1, self.operations_called
+        )
         self.assertEqual(self.operations_called[0][0].name, 'ListObjectsV2')
 
     # This test covers the case where an OSError is emitted.
-    def test_sync_skips_over_files_deleted_between_listing_and_transfer_oserror(self):
+    def test_sync_skips_over_files_deleted_between_listing_and_transfer_oserror(
+        self,
+    ):
         full_path = self.files.create_file('foo.txt', 'mycontent')
-        cmdline = '%s %s s3://bucket/' % (
-            self.prefix, self.files.rootdir)
+        cmdline = '%s %s s3://bucket/' % (self.prefix, self.files.rootdir)
 
         # FileGenerator.list_files should skip over files that cause an
         # OSError to be raised because they are missing when we try to
@@ -238,20 +298,24 @@ class TestSyncCommand(BaseS3TransferCommandTest):
         def side_effect(_):
             os.remove(full_path)
             raise OSError()
+
         with mock.patch(
-                'awscli.customizations.s3.filegenerator.get_file_stat',
-                side_effect=side_effect
-                ):
+            'awscli.customizations.s3.filegenerator.get_file_stat',
+            side_effect=side_effect,
+        ):
             self.run_cmd(cmdline, expected_rc=2)
 
         # We should not call PutObject because the file was deleted
         # before we could transfer it
-        self.assertEqual(len(self.operations_called), 1, self.operations_called)
+        self.assertEqual(
+            len(self.operations_called), 1, self.operations_called
+        )
         self.assertEqual(self.operations_called[0][0].name, 'ListObjectsV2')
 
     def test_request_payer(self):
         cmdline = '%s s3://sourcebucket/ s3://mybucket --request-payer' % (
-            self.prefix)
+            self.prefix
+        )
         self.parsed_responses = [
             # Response for ListObjects on source bucket
             self.list_objects_response(['mykey']),
@@ -263,12 +327,18 @@ class TestSyncCommand(BaseS3TransferCommandTest):
         self.assert_operations_called(
             [
                 self.list_objects_request(
-                    'sourcebucket', RequestPayer='requester'),
+                    'sourcebucket', RequestPayer='requester'
+                ),
                 self.list_objects_request(
-                    'mybucket', RequestPayer='requester'),
+                    'mybucket', RequestPayer='requester'
+                ),
                 self.copy_object_request(
-                    'sourcebucket', 'mykey', 'mybucket', 'mykey',
-                    RequestPayer='requester')
+                    'sourcebucket',
+                    'mykey',
+                    'mybucket',
+                    'mykey',
+                    RequestPayer='requester',
+                ),
             ]
         )
 
@@ -281,17 +351,20 @@ class TestSyncCommand(BaseS3TransferCommandTest):
             self.list_objects_response([]),
             # Response for ListObjects on destination bucket
             self.list_objects_response(['key-to-delete']),
-            self.delete_object_response()
+            self.delete_object_response(),
         ]
         self.run_cmd(cmdline, expected_rc=0)
         self.assert_operations_called(
             [
                 self.list_objects_request(
-                    'sourcebucket', RequestPayer='requester'),
+                    'sourcebucket', RequestPayer='requester'
+                ),
                 self.list_objects_request(
-                    'mybucket', RequestPayer='requester'),
+                    'mybucket', RequestPayer='requester'
+                ),
                 self.delete_object_request(
-                    'mybucket', 'key-to-delete', RequestPayer='requester'),
+                    'mybucket', 'key-to-delete', RequestPayer='requester'
+                ),
             ]
         )
 
@@ -310,7 +383,7 @@ class TestSyncCommand(BaseS3TransferCommandTest):
         self.assert_operations_called(
             [
                 self.list_objects_request(accesspoint_arn),
-                self.get_object_request(accesspoint_arn, 'mykey')
+                self.get_object_request(accesspoint_arn, 'mykey'),
             ]
         )
 
@@ -323,7 +396,7 @@ class TestSyncCommand(BaseS3TransferCommandTest):
         large_tag_set = {'tag-key': 'val' * 3000}
         metadata = {'tag-key': 'tag-value'}
         self.parsed_responses = [
-            self.list_objects_response(keys=['key'], Size=8 * 1024 ** 2),
+            self.list_objects_response(keys=['key'], Size=8 * 1024**2),
             self.list_objects_response(keys=[]),
             self.head_object_response(
                 Metadata=metadata,
@@ -343,8 +416,13 @@ class TestSyncCommand(BaseS3TransferCommandTest):
                 self.get_object_tagging_request('sourcebucket', 'key'),
                 self.create_mpu_request('bucket', 'key', Metadata=metadata),
                 self.upload_part_copy_request(
-                    'sourcebucket', 'key', 'bucket', 'key', upload_id,
-                    CopySourceRange=mock.ANY, PartNumber=1,
+                    'sourcebucket',
+                    'key',
+                    'bucket',
+                    'key',
+                    upload_id,
+                    CopySourceRange=mock.ANY,
+                    PartNumber=1,
                 ),
                 self.complete_mpu_request('bucket', 'key', upload_id, 1),
                 self.put_object_tagging_request(
@@ -358,7 +436,9 @@ class TestSyncCommand(BaseS3TransferCommandTest):
         cmdline = f'{self.prefix} {self.files.rootdir} s3://bucket/ --checksum-algorithm SHA1'
         self.run_cmd(cmdline, expected_rc=0)
         self.assertEqual(self.operations_called[1][0].name, 'PutObject')
-        self.assertEqual(self.operations_called[1][1]['ChecksumAlgorithm'], 'SHA1')
+        self.assertEqual(
+            self.operations_called[1][1]['ChecksumAlgorithm'], 'SHA1'
+        )
 
     def test_copy_with_checksum_algorithm_update_sha1(self):
         cmdline = f'{self.prefix} s3://src-bucket/ s3://dest-bucket/ --checksum-algorithm SHA1'
@@ -370,17 +450,15 @@ class TestSyncCommand(BaseS3TransferCommandTest):
                         'Key': 'mykey',
                         'LastModified': '00:00:00Z',
                         'Size': 100,
-                        'ChecksumAlgorithm': 'SHA1'
+                        'ChecksumAlgorithm': 'SHA1',
                     }
                 ],
-                'CommonPrefixes': []
+                'CommonPrefixes': [],
             },
             # Response for ListObjects on destination bucket
             self.list_objects_response([]),
             # Response for CopyObject
-            {
-                'ChecksumSHA1': 'sha1-checksum'
-            }
+            {'ChecksumSHA1': 'sha1-checksum'},
         ]
         self.run_cmd(cmdline, expected_rc=0)
         self.assert_operations_called(
@@ -388,16 +466,14 @@ class TestSyncCommand(BaseS3TransferCommandTest):
                 self.list_objects_request('src-bucket'),
                 self.list_objects_request('dest-bucket'),
                 (
-                    'CopyObject', {
-                        'CopySource': {
-                            'Bucket': 'src-bucket',
-                            'Key': 'mykey'
-                        },
+                    'CopyObject',
+                    {
+                        'CopySource': {'Bucket': 'src-bucket', 'Key': 'mykey'},
                         'Bucket': 'dest-bucket',
                         'Key': 'mykey',
-                        'ChecksumAlgorithm': 'SHA1'
-                    }
-                )
+                        'ChecksumAlgorithm': 'SHA1',
+                    },
+                ),
             ]
         )
 
@@ -406,7 +482,9 @@ class TestSyncCommand(BaseS3TransferCommandTest):
         cmdline = f'{self.prefix} {self.files.rootdir} s3://bucket/ --checksum-algorithm SHA256'
         self.run_cmd(cmdline, expected_rc=0)
         self.assertEqual(self.operations_called[1][0].name, 'PutObject')
-        self.assertEqual(self.operations_called[1][1]['ChecksumAlgorithm'], 'SHA256')
+        self.assertEqual(
+            self.operations_called[1][1]['ChecksumAlgorithm'], 'SHA256'
+        )
 
     def test_download_with_checksum_mode_sha1(self):
         self.parsed_responses = [
@@ -415,14 +493,16 @@ class TestSyncCommand(BaseS3TransferCommandTest):
             {
                 'ETag': 'foo-1',
                 'ChecksumSHA1': 'checksum',
-                'Body': BytesIO(b'foo')
-            }
+                'Body': BytesIO(b'foo'),
+            },
         ]
         cmdline = f'{self.prefix} s3://bucket/foo {self.files.rootdir} --checksum-mode ENABLED'
         self.run_cmd(cmdline, expected_rc=0)
         self.assertEqual(self.operations_called[0][0].name, 'ListObjectsV2')
         self.assertEqual(self.operations_called[1][0].name, 'GetObject')
-        self.assertIn(('ChecksumMode', 'ENABLED'), self.operations_called[1][1].items())
+        self.assertIn(
+            ('ChecksumMode', 'ENABLED'), self.operations_called[1][1].items()
+        )
 
     def test_download_with_checksum_mode_sha256(self):
         self.parsed_responses = [
@@ -431,14 +511,16 @@ class TestSyncCommand(BaseS3TransferCommandTest):
             {
                 'ETag': 'foo-1',
                 'ChecksumSHA256': 'checksum',
-                'Body': BytesIO(b'foo')
-            }
+                'Body': BytesIO(b'foo'),
+            },
         ]
         cmdline = f'{self.prefix} s3://bucket/foo {self.files.rootdir} --checksum-mode ENABLED'
         self.run_cmd(cmdline, expected_rc=0)
         self.assertEqual(self.operations_called[0][0].name, 'ListObjectsV2')
         self.assertEqual(self.operations_called[1][0].name, 'GetObject')
-        self.assertIn(('ChecksumMode', 'ENABLED'), self.operations_called[1][1].items())
+        self.assertIn(
+            ('ChecksumMode', 'ENABLED'), self.operations_called[1][1].items()
+        )
 
     def test_download_with_checksum_mode_crc64nvme(self):
         self.parsed_responses = [
@@ -447,22 +529,30 @@ class TestSyncCommand(BaseS3TransferCommandTest):
             {
                 'ETag': 'foo-1',
                 'ChecksumCRC64NVME': 'checksum',
-                'Body': BytesIO(b'foo')
-            }
+                'Body': BytesIO(b'foo'),
+            },
         ]
         cmdline = f'{self.prefix} s3://bucket/foo {self.files.rootdir} --checksum-mode ENABLED'
         self.run_cmd(cmdline, expected_rc=0)
         self.assertEqual(self.operations_called[0][0].name, 'ListObjectsV2')
         self.assertEqual(self.operations_called[1][0].name, 'GetObject')
-        self.assertIn(('ChecksumMode', 'ENABLED'), self.operations_called[1][1].items())
+        self.assertIn(
+            ('ChecksumMode', 'ENABLED'), self.operations_called[1][1].items()
+        )
 
 
 class TestSyncSourceRegion(BaseS3CLIRunnerTest):
     def test_respects_source_region(self):
         source_region = 'af-south-1'
         cmdline = [
-            's3', 'sync', 's3://sourcebucket/', 's3://bucket/',
-            '--region', self.region, '--source-region', source_region
+            's3',
+            'sync',
+            's3://sourcebucket/',
+            's3://bucket/',
+            '--region',
+            self.region,
+            '--source-region',
+            source_region,
         ]
         self.add_botocore_list_objects_response(['key'])
         self.add_botocore_list_objects_response([])
@@ -472,13 +562,19 @@ class TestSyncSourceRegion(BaseS3CLIRunnerTest):
         self.assert_operations_to_endpoints(
             cli_runner_result=result,
             expected_operations_to_endpoints=[
-                ('ListObjectsV2',
-                 self.get_virtual_s3_host('sourcebucket', source_region)),
-                ('ListObjectsV2',
-                 self.get_virtual_s3_host('bucket', self.region)),
-                ('CopyObject',
-                 self.get_virtual_s3_host('bucket', self.region))
-            ]
+                (
+                    'ListObjectsV2',
+                    self.get_virtual_s3_host('sourcebucket', source_region),
+                ),
+                (
+                    'ListObjectsV2',
+                    self.get_virtual_s3_host('bucket', self.region),
+                ),
+                (
+                    'CopyObject',
+                    self.get_virtual_s3_host('bucket', self.region),
+                ),
+            ],
         )
 
 
@@ -486,7 +582,10 @@ class TestSyncWithCRTClient(BaseCRTTransferClientTest):
     def test_upload_sync_using_crt_client(self):
         filename = self.files.create_file('myfile', 'mycontent')
         cmdline = [
-            's3', 'sync', self.files.rootdir, 's3://bucket/',
+            's3',
+            'sync',
+            self.files.rootdir,
+            's3://bucket/',
         ]
         self.add_botocore_list_objects_response([])
         self.run_command(cmdline)
@@ -502,7 +601,10 @@ class TestSyncWithCRTClient(BaseCRTTransferClientTest):
 
     def test_download_sync_using_crt_client(self):
         cmdline = [
-            's3', 'sync', 's3://bucket/', self.files.rootdir,
+            's3',
+            'sync',
+            's3://bucket/',
+            self.files.rootdir,
         ]
         self.add_botocore_list_objects_response(['key'])
         self.run_command(cmdline)
@@ -519,7 +621,11 @@ class TestSyncWithCRTClient(BaseCRTTransferClientTest):
     def test_upload_sync_with_delete_using_crt_client(self):
         filename = self.files.create_file('a-file', 'mycontent')
         cmdline = [
-            's3', 'sync', self.files.rootdir, 's3://bucket/', '--delete'
+            's3',
+            'sync',
+            self.files.rootdir,
+            's3://bucket/',
+            '--delete',
         ]
         self.add_botocore_list_objects_response(['delete-this'])
         self.run_command(cmdline)
@@ -537,13 +643,17 @@ class TestSyncWithCRTClient(BaseCRTTransferClientTest):
             expected_type=S3RequestType.DEFAULT,
             expected_host=self.get_virtual_s3_host('bucket'),
             expected_path='/delete-this',
-            expected_http_method='DELETE'
+            expected_http_method='DELETE',
         )
 
     def test_download_sync_with_delete_using_crt_client(self):
         self.files.create_file('delete-this', 'content')
         cmdline = [
-            's3', 'sync', 's3://bucket/', self.files.rootdir, '--delete'
+            's3',
+            'sync',
+            's3://bucket/',
+            self.files.rootdir,
+            '--delete',
         ]
         self.add_botocore_list_objects_response(['key'])
         self.run_command(cmdline)
@@ -559,9 +669,7 @@ class TestSyncWithCRTClient(BaseCRTTransferClientTest):
         self.assertFalse(os.path.exists('delete-this'))
 
     def test_does_not_use_crt_client_for_copy_syncs(self):
-        cmdline = [
-            's3', 'sync', 's3://bucket/', 's3://otherbucket/'
-        ]
+        cmdline = ['s3', 'sync', 's3://bucket/', 's3://otherbucket/']
         self.add_botocore_list_objects_response(['key'])
         self.add_botocore_list_objects_response([])
         self.add_botocore_copy_object_response()
@@ -569,34 +677,58 @@ class TestSyncWithCRTClient(BaseCRTTransferClientTest):
         self.assertEqual(self.get_crt_make_request_calls(), [])
         self.assert_no_remaining_botocore_responses()
 
+
 class TestSyncCommandWithS3Express(BaseS3TransferCommandTest):
     prefix = 's3 sync '
 
     def test_incompatible_with_sync_upload(self):
-        cmdline = '%s %s s3://testdirectorybucket--usw2-az1--x-s3/' % (self.prefix, self.files.rootdir)
+        cmdline = '%s %s s3://testdirectorybucket--usw2-az1--x-s3/' % (
+            self.prefix,
+            self.files.rootdir,
+        )
         stderr = self.run_cmd(cmdline, expected_rc=252)[1]
-        self.assertIn('Cannot use sync command with a directory bucket.', stderr)
+        self.assertIn(
+            'Cannot use sync command with a directory bucket.', stderr
+        )
 
     def test_incompatible_with_sync_download(self):
-        cmdline = '%s s3://testdirectorybucket--usw2-az1--x-s3/ %s' % (self.prefix, self.files.rootdir)
+        cmdline = '%s s3://testdirectorybucket--usw2-az1--x-s3/ %s' % (
+            self.prefix,
+            self.files.rootdir,
+        )
         stderr = self.run_cmd(cmdline, expected_rc=252)[1]
-        self.assertIn('Cannot use sync command with a directory bucket.', stderr)
+        self.assertIn(
+            'Cannot use sync command with a directory bucket.', stderr
+        )
 
     def test_incompatible_with_sync_copy(self):
-        cmdline = '%s s3://bucket/ s3://testdirectorybucket--usw2-az1--x-s3/' % self.prefix
+        cmdline = (
+            '%s s3://bucket/ s3://testdirectorybucket--usw2-az1--x-s3/'
+            % self.prefix
+        )
         stderr = self.run_cmd(cmdline, expected_rc=252)[1]
-        self.assertIn('Cannot use sync command with a directory bucket.', stderr)
+        self.assertIn(
+            'Cannot use sync command with a directory bucket.', stderr
+        )
 
     def test_incompatible_with_sync_with_delete(self):
-        cmdline = '%s s3://bucket/ s3://testdirectorybucket--usw2-az1--x-s3/ --delete' % self.prefix
+        cmdline = (
+            '%s s3://bucket/ s3://testdirectorybucket--usw2-az1--x-s3/ --delete'
+            % self.prefix
+        )
         stderr = self.run_cmd(cmdline, expected_rc=252)[1]
-        self.assertIn('Cannot use sync command with a directory bucket.', stderr)
+        self.assertIn(
+            'Cannot use sync command with a directory bucket.', stderr
+        )
 
-    def test_compatible_with_sync_with_local_directory_like_directory_bucket(self):
-        self.parsed_responses = [
-            {'Contents': []}
-        ]
-        cmdline = '%s s3://bucket/ testdirectorybucket--usw2-az1--x-s3/' % self.prefix
+    def test_compatible_with_sync_with_local_directory_like_directory_bucket(
+        self,
+    ):
+        self.parsed_responses = [{'Contents': []}]
+        cmdline = (
+            '%s s3://bucket/ testdirectorybucket--usw2-az1--x-s3/'
+            % self.prefix
+        )
         with cd(self.files.rootdir):
             _, stderr, _ = self.run_cmd(cmdline)
         # Just asserting that command validated and made an API call
