@@ -17,8 +17,10 @@ import os
 from botocore.loaders import Loader
 
 from awscli.testutils import (
-    create_clidriver, FileCreator, BaseAWSCommandParamsTest,
-    BaseAWSHelpOutputTest
+    BaseAWSCommandParamsTest,
+    BaseAWSHelpOutputTest,
+    FileCreator,
+    create_clidriver,
 )
 
 # NOTE: Typically, the functional tests reuse preexisting models. However
@@ -42,14 +44,11 @@ DOCTYPE_MODEL = {
     "operations": {
         "DescribeResource": {
             "name": "DescribeResource",
-            "http": {
-                "method": "POST",
-                "requestUri": "/"
-            },
+            "http": {"method": "POST", "requestUri": "/"},
             "input": {"shape": "DescribeResourceShape"},
             "output": {"shape": "DescribeResourceShape"},
             "errors": [],
-            "documentation": "<p>Describes resource.</p>"
+            "documentation": "<p>Describes resource.</p>",
         }
     },
     "shapes": {
@@ -62,27 +61,24 @@ DOCTYPE_MODEL = {
                 "MapOfDocTypesParam": {"shape": "MapOfDocTypes"},
                 "NestedListsOfDocTypesParam": {
                     "shape": "NestedListsOfDocTypes"
-                }
-            }
+                },
+            },
         },
         "DocType": {
             "type": "structure",
             "members": {},
             "document": True,
-            "documentation": "<p>Document type</p>"
-        },
-        "ListOfDocTypes": {
-            "type": "list",
-            "member": {"shape": "DocType"}
+            "documentation": "<p>Document type</p>",
         },
+        "ListOfDocTypes": {"type": "list", "member": {"shape": "DocType"}},
         "MapOfDocTypes": {
             "type": "map",
             "key": {"shape": "String"},
-            "value": {"shape": "DocType"}
+            "value": {"shape": "DocType"},
         },
         "NestedListsOfDocTypes": {
             "type": "list",
-            "member": {"shape": "ListOfDocTypes"}
+            "member": {"shape": "ListOfDocTypes"},
         },
         "Mixed": {
             "type": "structure",
@@ -91,13 +87,14 @@ DOCTYPE_MODEL = {
                 "StringMember": {"shape": "String"},
                 "ListOfDocTypes": {"shape": "ListOfDocTypes"},
                 "MapOfDocTypes": {"shape": "MapOfDocTypes"},
-                "NestedListsOfDocTypes": {"shape": "NestedListsOfDocTypes"}
+                "NestedListsOfDocTypes": {"shape": "NestedListsOfDocTypes"},
             },
             "documentation": (
-                "<p>Structure with modeled and document type parameter</p>"),
+                "<p>Structure with modeled and document type parameter</p>"
+            ),
         },
-        "String": {"type": "string"}
-    }
+        "String": {"type": "string"},
+    },
 }
 
 
@@ -106,7 +103,7 @@ def _add_doctype_service_model(file_creator, session, model=None):
         model = DOCTYPE_MODEL
     file_creator.create_file(
         os.path.join('doctype', '2011-06-15', 'service-2.json'),
-        json.dumps(model)
+        json.dumps(model),
     )
     data_path = session.get_config_variable('data_path').split(os.pathsep)
     loader = Loader()
@@ -124,8 +121,9 @@ class TestDocumentTypeIO(BaseAWSCommandParamsTest):
         super(TestDocumentTypeIO, self).tearDown()
         self.files.remove_all()
 
-    def assert_raises_shorthand_syntax_error(self, cmdline,
-                                             stderr_contains=None):
+    def assert_raises_shorthand_syntax_error(
+        self, cmdline, stderr_contains=None
+    ):
         _, stderr, _ = self.run_cmd(cmdline, expected_rc=252)
         if stderr_contains:
             self.assertIn(stderr_contains, stderr)
@@ -139,34 +137,44 @@ class TestDocumentTypeIO(BaseAWSCommandParamsTest):
 
     def test_can_provide_json_for_doc_type(self):
         cmdline = [
-            'doctype', 'describe-resource', '--doc-type-param',
-            '{"foo":"bar"}'
+            'doctype',
+            'describe-resource',
+            '--doc-type-param',
+            '{"foo":"bar"}',
         ]
         self.assert_params_for_cmd(
-            cmdline, params={'DocTypeParam': {"foo": "bar"}})
+            cmdline, params={'DocTypeParam': {"foo": "bar"}}
+        )
 
     def test_can_provide_json_for_doc_type_with_scalar_value(self):
         cmdline = [
-            'doctype', 'describe-resource', '--doc-type-param',
-            '"json-string"'
+            'doctype',
+            'describe-resource',
+            '--doc-type-param',
+            '"json-string"',
         ]
         self.assert_params_for_cmd(
-            cmdline, params={'DocTypeParam': 'json-string'})
+            cmdline, params={'DocTypeParam': 'json-string'}
+        )
 
     def test_can_provide_json_for_doc_type_in_list(self):
         cmdline = [
-            'doctype', 'describe-resource', '--list-of-doc-types-param',
-            '["foo", {"bar": "baz"}, 1, null]'
+            'doctype',
+            'describe-resource',
+            '--list-of-doc-types-param',
+            '["foo", {"bar": "baz"}, 1, null]',
         ]
         self.assert_params_for_cmd(
             cmdline,
-            params={'ListOfDocTypesParam': ["foo", {"bar": "baz"}, 1, None]}
+            params={'ListOfDocTypesParam': ["foo", {"bar": "baz"}, 1, None]},
         )
 
     def test_can_provide_json_for_doc_type_in_map(self):
         cmdline = [
-            'doctype', 'describe-resource', '--map-of-doc-types-param',
-            '{"key1": "foo", "key2": {"bar": "baz"}, "key3": 1}'
+            'doctype',
+            'describe-resource',
+            '--map-of-doc-types-param',
+            '{"key1": "foo", "key2": {"bar": "baz"}, "key3": 1}',
         ]
         self.assert_params_for_cmd(
             cmdline,
@@ -174,16 +182,17 @@ class TestDocumentTypeIO(BaseAWSCommandParamsTest):
                 'MapOfDocTypesParam': {
                     "key1": "foo",
                     "key2": {"bar": "baz"},
-                    "key3": 1
+                    "key3": 1,
                 }
-            }
+            },
         )
 
     def test_can_provide_json_for_doc_type_in_nested_list(self):
         cmdline = [
-            'doctype', 'describe-resource',
+            'doctype',
+            'describe-resource',
             '--nested-lists-of-doc-types-param',
-            '[["foo", {"bar": "baz"}, 1, null]]'
+            '[["foo", {"bar": "baz"}, 1, null]]',
         ]
         self.assert_params_for_cmd(
             cmdline,
@@ -191,12 +200,13 @@ class TestDocumentTypeIO(BaseAWSCommandParamsTest):
                 'NestedListsOfDocTypesParam': [
                     ["foo", {"bar": "baz"}, 1, None]
                 ]
-            }
+            },
         )
 
     def test_can_provide_json_for_nested_doc_type(self):
         cmdline = [
-            'doctype', 'describe-resource',
+            'doctype',
+            'describe-resource',
             '--modeled-mixed-with-doc-type-param',
             (
                 '{'
@@ -206,7 +216,7 @@ class TestDocumentTypeIO(BaseAWSCommandParamsTest):
                 '       "key1": "foo", "key2": {"bar": "baz"}, "key3": 1},'
                 '   "NestedListsOfDocTypes":[["foo", {"bar": "baz"}, 1, null]]'
                 '}'
-            )
+            ),
         ]
         self.assert_params_for_cmd(
             cmdline,
@@ -217,67 +227,78 @@ class TestDocumentTypeIO(BaseAWSCommandParamsTest):
                     'MapOfDocTypes': {
                         "key1": "foo",
                         "key2": {"bar": "baz"},
-                        "key3": 1
+                        "key3": 1,
                     },
-                    'NestedListsOfDocTypes': [["foo", {"bar": "baz"}, 1, None]]
+                    'NestedListsOfDocTypes': [
+                        ["foo", {"bar": "baz"}, 1, None]
+                    ],
                 }
-            }
+            },
         )
 
     def test_shorthand_not_supported_for_doc_type_argument(self):
         cmdline = [
-            'doctype', 'describe-resource',
-            '--doc-type-param', 'foo=1',
+            'doctype',
+            'describe-resource',
+            '--doc-type-param',
+            'foo=1',
         ]
         self.assert_raises_shorthand_syntax_error(
             cmdline,
             stderr_contains=(
                 "Error parsing parameter '--doc-type-param': Invalid JSON"
-            )
+            ),
         )
 
     def test_shorthand_not_supported_for_doc_type_in_list(self):
         cmdline = [
-            'doctype', 'describe-resource',
-            '--list-of-doc-types-param', 'bar,1,null',
+            'doctype',
+            'describe-resource',
+            '--list-of-doc-types-param',
+            'bar,1,null',
         ]
         self.assert_raises_shorthand_syntax_error(
             cmdline,
             stderr_contains=(
                 "Error parsing parameter '--list-of-doc-types-param': "
                 "Invalid JSON"
-            )
+            ),
         )
 
     def test_shorthand_not_supported_for_doc_type_in_map(self):
         cmdline = [
-            'doctype', 'describe-resource',
-            '--map-of-doc-types-param', 'key1={foo=bar}',
+            'doctype',
+            'describe-resource',
+            '--map-of-doc-types-param',
+            'key1={foo=bar}',
         ]
         self.assert_raises_shorthand_syntax_error(
             cmdline,
             stderr_contains=(
                 "Error parsing parameter '--map-of-doc-types-param': "
                 "Invalid JSON"
-            )
+            ),
         )
 
     def test_shorthand_not_supported_for_doc_type_in_nested_list(self):
         cmdline = [
-            'doctype', 'describe-resource',
-            '--nested-lists-of-doc-types-param', '[bar,1,null],[foo,2]',
+            'doctype',
+            'describe-resource',
+            '--nested-lists-of-doc-types-param',
+            '[bar,1,null],[foo,2]',
         ]
         self.assert_raises_shorthand_syntax_error(
             cmdline,
             stderr_contains=(
                 "Error parsing parameter '--nested-lists-of-doc-types-param': "
                 "Invalid JSON"
-            )
+            ),
         )
 
     def test_shorthand_not_supported_for_nested_doc_type(self):
         cmdline = [
-            'doctype', 'describe-resource',
+            'doctype',
+            'describe-resource',
             '--modeled-mixed-with-doc-type-param',
             'DocType={foo=bar}',
         ]
@@ -285,12 +306,13 @@ class TestDocumentTypeIO(BaseAWSCommandParamsTest):
             cmdline,
             stderr_contains=self.nested_doctype_shorthand_error(
                 '--modeled-mixed-with-doc-type-param', member_name='DocType'
-            )
+            ),
         )
 
     def test_shorthand_not_supported_for_nested_doc_type_in_list(self):
         cmdline = [
-            'doctype', 'describe-resource',
+            'doctype',
+            'describe-resource',
             '--modeled-mixed-with-doc-type-param',
             'ListOfDocTypes=[{foo=bar}]',
         ]
@@ -298,13 +320,14 @@ class TestDocumentTypeIO(BaseAWSCommandParamsTest):
             cmdline,
             stderr_contains=self.nested_doctype_shorthand_error(
                 '--modeled-mixed-with-doc-type-param',
-                member_name='ListOfDocTypes'
-            )
+                member_name='ListOfDocTypes',
+            ),
         )
 
     def test_shorthand_not_supported_for_nested_doc_type_in_map(self):
         cmdline = [
-            'doctype', 'describe-resource',
+            'doctype',
+            'describe-resource',
             '--modeled-mixed-with-doc-type-param',
             'MapOfDocTypes={key={foo=bar}}',
         ]
@@ -312,13 +335,14 @@ class TestDocumentTypeIO(BaseAWSCommandParamsTest):
             cmdline,
             stderr_contains=self.nested_doctype_shorthand_error(
                 '--modeled-mixed-with-doc-type-param',
-                member_name='MapOfDocTypes'
-            )
+                member_name='MapOfDocTypes',
+            ),
         )
 
     def test_shorthand_not_supported_for_nested_doc_type_in_nested_list(self):
         cmdline = [
-            'doctype', 'describe-resource',
+            'doctype',
+            'describe-resource',
             '--modeled-mixed-with-doc-type-param',
             'NestedListsOfDocTypes=[[{foo=bar}]]',
         ]
@@ -326,13 +350,14 @@ class TestDocumentTypeIO(BaseAWSCommandParamsTest):
             cmdline,
             stderr_contains=self.nested_doctype_shorthand_error(
                 '--modeled-mixed-with-doc-type-param',
-                member_name='NestedListsOfDocTypes'
-            )
+                member_name='NestedListsOfDocTypes',
+            ),
         )
 
     def test_can_use_shorthand_if_only_modeled_members_used(self):
         cmdline = [
-            'doctype', 'describe-resource',
+            'doctype',
+            'describe-resource',
             '--modeled-mixed-with-doc-type-param',
             'StringMember=str-val',
         ]
@@ -342,13 +367,11 @@ class TestDocumentTypeIO(BaseAWSCommandParamsTest):
                 'ModeledMixedWithDocTypeParam': {
                     'StringMember': 'str-val',
                 }
-            }
+            },
         )
 
     def test_can_generate_cli_skeleton(self):
-        cmdline = [
-            'doctype', 'describe-resource', '--generate-cli-skeleton'
-        ]
+        cmdline = ['doctype', 'describe-resource', '--generate-cli-skeleton']
         stdout, _, _ = self.run_cmd(cmdline)
         skeleton_output = json.loads(stdout)
         self.assertEqual(
@@ -360,12 +383,12 @@ class TestDocumentTypeIO(BaseAWSCommandParamsTest):
                     'StringMember': '',
                     'ListOfDocTypes': [{}],
                     'MapOfDocTypes': {'KeyName': {}},
-                    'NestedListsOfDocTypes': [[{}]]
+                    'NestedListsOfDocTypes': [[{}]],
                 },
                 'ListOfDocTypesParam': [{}],
                 'MapOfDocTypesParam': {'KeyName': {}},
-                'NestedListsOfDocTypesParam': [[{}]]
-            }
+                'NestedListsOfDocTypesParam': [[{}]],
+            },
         )
 
 
@@ -380,8 +403,7 @@ class TestDocTypesHelp(BaseAWSHelpOutputTest):
         self.files.remove_all()
 
     def run_help(self):
-        self.driver.main(
-            ['doctype', 'describe-resource', 'help'])
+        self.driver.main(['doctype', 'describe-resource', 'help'])
 
     def filter_params_in_model(self, include_params):
         model = copy.deepcopy(DOCTYPE_MODEL)
@@ -395,9 +417,7 @@ class TestDocTypesHelp(BaseAWSHelpOutputTest):
 
     def assert_has_document_value_in_json_syntax(self, parameter):
         self.assert_text_order(
-            'JSON Syntax::',
-            '{...}',
-            starting_from=parameter
+            'JSON Syntax::', '{...}', starting_from=parameter
         )
 
     def assert_no_shorthand_syntax(self):
@@ -423,30 +443,36 @@ class TestDocTypesHelp(BaseAWSHelpOutputTest):
         self.filter_params_in_model(include_params=['DocTypeParam'])
         self.run_help()
         self.assert_has_document_value_in_json_syntax(
-            parameter='--doc-type-param')
+            parameter='--doc-type-param'
+        )
 
     def test_json_syntax_for_doc_type_in_list(self):
         self.filter_params_in_model(include_params=['ListOfDocTypesParam'])
         self.run_help()
         self.assert_has_document_value_in_json_syntax(
-            parameter='--list-of-doc-types-param')
+            parameter='--list-of-doc-types-param'
+        )
 
     def test_json_syntax_for_doc_type_in_map(self):
         self.filter_params_in_model(include_params=['MapOfDocTypesParam'])
         self.run_help()
         self.assert_has_document_value_in_json_syntax(
-            parameter='--map-of-doc-types-param')
+            parameter='--map-of-doc-types-param'
+        )
 
     def test_json_syntax_for_doc_type_in_nested_list(self):
         self.filter_params_in_model(
-            include_params=['NestedListsOfDocTypesParam'])
+            include_params=['NestedListsOfDocTypesParam']
+        )
         self.run_help()
         self.assert_has_document_value_in_json_syntax(
-            parameter='--nested-lists-of-doc-types-param')
+            parameter='--nested-lists-of-doc-types-param'
+        )
 
     def test_json_syntax_for_nested_doc_type(self):
         self.filter_params_in_model(
-            include_params=['ModeledMixedWithDocTypeParam'])
+            include_params=['ModeledMixedWithDocTypeParam']
+        )
         self.run_help()
         self.assert_text_order(
             'JSON Syntax::',
@@ -454,7 +480,7 @@ class TestDocTypesHelp(BaseAWSHelpOutputTest):
             '"ListOfDocTypes": [',
             '"MapOfDocTypes": {"string": {...}',
             '"NestedListsOfDocTypes": [',
-            starting_from='--modeled-mixed-with-doc-type-param'
+            starting_from='--modeled-mixed-with-doc-type-param',
         )
 
     def test_shorthand_not_documented_for_doc_type_argument(self):
@@ -474,18 +500,20 @@ class TestDocTypesHelp(BaseAWSHelpOutputTest):
 
     def test_shorthand_not_documented_for_doc_type_in_nested_list(self):
         self.filter_params_in_model(
-            include_params=['NestedListsOfDocTypesParam'])
+            include_params=['NestedListsOfDocTypesParam']
+        )
         self.run_help()
         self.assert_no_shorthand_syntax()
 
     def test_documents_shorthand_for_only_modeled_members(self):
         self.filter_params_in_model(
-            include_params=['ModeledMixedWithDocTypeParam'])
+            include_params=['ModeledMixedWithDocTypeParam']
+        )
         self.run_help()
         self.assert_text_order(
             'Shorthand Syntax::',
             'StringMember=string',
-            starting_from='--modeled-mixed-with-doc-type-param'
+            starting_from='--modeled-mixed-with-doc-type-param',
         )
         self.assert_not_contains('DocTypeParam=')
         self.assert_not_contains('ListOfDocTypesParam=')
