@@ -1,5 +1,9 @@
 from awscli import __version__ as awscli_version
 from tests import CLIRunner
+from tests.functional.botocore.test_useragent import (
+    get_captured_ua_strings,
+    parse_registered_feature_ids,
+)
 
 
 def assert_expected_user_agent(result, service, operation):
@@ -10,7 +14,7 @@ def assert_expected_user_agent(result, service, operation):
     assert ' md/arch#' in ua_string
     assert ' md/prompt#off' in ua_string
     assert f' md/command#{service}.{operation}' in ua_string
-    assert ' ua/2.0 ' in ua_string
+    assert ' ua/2.1 ' in ua_string
     assert ' os/' in ua_string
     assert ' lang/python' in ua_string
     assert ' cfg/' in ua_string
@@ -31,3 +35,6 @@ def test_user_agent_for_customization():
     operation = 'ls'
     result = cli_runner.run([service, operation])
     assert_expected_user_agent(result, service, operation)
+    ua_string = result.aws_requests[0].http_requests[0].headers['User-Agent']
+    feature_list = parse_registered_feature_ids(ua_string)
+    assert 'C' in feature_list
