@@ -15,11 +15,10 @@ from functools import partial
 
 import pytest
 
-from awscli.testutils import unittest
 from awscli.autocomplete import parser
+from awscli.testutils import unittest
 from tests.unit.autocomplete import InMemoryIndex
 
-
 # This models an 'aws ec2 stop-instances' command
 # along with the 'region', 'endpoint-url', and 'debug' global params.
 SAMPLE_MODEL = InMemoryIndex(
@@ -40,98 +39,194 @@ SAMPLE_MODEL = InMemoryIndex(
             'aws.s3api': {
                 'get-object': ['outfile', 'bucket', 'key'],
             },
-            'aws.logs': {
-                'tail': ['group_name', 'filter-pattern']
-            }
+            'aws.logs': {'tail': ['group_name', 'filter-pattern']},
         },
         'command_names': {
             '': [('aws', None)],
-            'aws': [('ec2', None), ('logs', None),
-                    ('s3api', None), ('s3', None)],
+            'aws': [
+                ('ec2', None),
+                ('logs', None),
+                ('s3api', None),
+                ('s3', None),
+            ],
             'aws.ec2': [('stop-instances', None)],
             'aws.logs': [('tail', None)],
             'aws.s3': [('cp', None)],
-            'aws.s3api': [('get-object', None)]
+            'aws.s3api': [('get-object', None)],
         },
         'arg_data': {
             '': {
                 'aws': {
-                    'debug': ('debug', 'boolean', 'aws', '', None, False,
-                              False),
-                    'endpoint-url': ('endpoint-url', 'string', 'aws', '', None,
-                                     False, False),
-                    'region': ('region', 'string', 'aws', '', None, False,
-                               False),
+                    'debug': (
+                        'debug',
+                        'boolean',
+                        'aws',
+                        '',
+                        None,
+                        False,
+                        False,
+                    ),
+                    'endpoint-url': (
+                        'endpoint-url',
+                        'string',
+                        'aws',
+                        '',
+                        None,
+                        False,
+                        False,
+                    ),
+                    'region': (
+                        'region',
+                        'string',
+                        'aws',
+                        '',
+                        None,
+                        False,
+                        False,
+                    ),
                 }
             },
             'aws.ec2': {
                 'stop-instances': {
                     'instance-ids': (
-                        'instance-ids', 'string', 'stop-instances', 'aws.ec2.',
-                        '*', False, False),
+                        'instance-ids',
+                        'string',
+                        'stop-instances',
+                        'aws.ec2.',
+                        '*',
+                        False,
+                        False,
+                    ),
                     'foo-arg': (
-                        'foo-arg', 'string', 'stop-instances', 'aws.ec2', None,
-                        False, False),
+                        'foo-arg',
+                        'string',
+                        'stop-instances',
+                        'aws.ec2',
+                        None,
+                        False,
+                        False,
+                    ),
                     'positional': (
-                        'positional', 'string', 'stop-instances', 'aws.ec2',
-                        None, True, False),
+                        'positional',
+                        'string',
+                        'stop-instances',
+                        'aws.ec2',
+                        None,
+                        True,
+                        False,
+                    ),
                 }
             },
             'aws.logs': {
                 'tail': {
                     'group_name': (
-                        'group_name', 'string', 'tail', 'aws.logs.', None,
-                        True, False),
+                        'group_name',
+                        'string',
+                        'tail',
+                        'aws.logs.',
+                        None,
+                        True,
+                        False,
+                    ),
                     'filter-pattern': (
-                        'filter-pattern', 'string', 'tail', 'aws.logs', None,
-                        False, False),
+                        'filter-pattern',
+                        'string',
+                        'tail',
+                        'aws.logs',
+                        None,
+                        False,
+                        False,
+                    ),
                 }
             },
             'aws.s3': {
                 'cp': {
                     'bucket': (
-                        'bucket', 'string', 'cp', 'aws.s3.', None,
-                        False, False),
+                        'bucket',
+                        'string',
+                        'cp',
+                        'aws.s3.',
+                        None,
+                        False,
+                        False,
+                    ),
                     'key': (
-                        'key', 'string', 'cp', 'aws.s3.', None,
-                        False, False),
+                        'key',
+                        'string',
+                        'cp',
+                        'aws.s3.',
+                        None,
+                        False,
+                        False,
+                    ),
                 }
             },
             'aws.s3api': {
                 'get-object': {
                     'outfile': (
-                        'outfile', 'string', 'get-object', 'aws.s3api.', None,
-                        False, False),
+                        'outfile',
+                        'string',
+                        'get-object',
+                        'aws.s3api.',
+                        None,
+                        False,
+                        False,
+                    ),
                     'bucket': (
-                        'bucket', 'string', 'get-object', 'aws.s3api.', None,
-                        False, False),
+                        'bucket',
+                        'string',
+                        'get-object',
+                        'aws.s3api.',
+                        None,
+                        False,
+                        False,
+                    ),
                     'key': (
-                        'key', 'string', 'get-object', 'aws.s3api.', None,
-                        False, False),
+                        'key',
+                        'string',
+                        'get-object',
+                        'aws.s3api.',
+                        None,
+                        False,
+                        False,
+                    ),
                 }
-            }
-        }
+            },
+        },
     },
 )
 
+
 @pytest.mark.parametrize(
     'command_line',
     [
-        ('aws ec2 stop-instances '
-         '--instance-ids i-123 i-124 --foo-arg value --debug '
-         '--endpoint-url https://foo '),
-        ('aws --debug ec2 stop-instances '
-         '--instance-ids i-123 i-124 --foo-arg value '
-         '--endpoint-url https://foo '),
-        ('aws --endpoint-url https://foo --debug ec2 stop-instances '
-         '--instance-ids i-123 i-124 --foo-arg value '),
-        ('aws ec2 --debug --endpoint-url https://foo stop-instances '
-         '--instance-ids i-123 i-124 --foo-arg value '),
-        ('aws ec2 stop-instances --debug --endpoint-url https://foo '
-         '--instance-ids i-123 i-124 --foo-arg value '),
-        ('aws ec2 --endpoint-url https://foo stop-instances --debug '
-         '--instance-ids i-123 i-124 --foo-arg value '),
-    ]
+        (
+            'aws ec2 stop-instances '
+            '--instance-ids i-123 i-124 --foo-arg value --debug '
+            '--endpoint-url https://foo '
+        ),
+        (
+            'aws --debug ec2 stop-instances '
+            '--instance-ids i-123 i-124 --foo-arg value '
+            '--endpoint-url https://foo '
+        ),
+        (
+            'aws --endpoint-url https://foo --debug ec2 stop-instances '
+            '--instance-ids i-123 i-124 --foo-arg value '
+        ),
+        (
+            'aws ec2 --debug --endpoint-url https://foo stop-instances '
+            '--instance-ids i-123 i-124 --foo-arg value '
+        ),
+        (
+            'aws ec2 stop-instances --debug --endpoint-url https://foo '
+            '--instance-ids i-123 i-124 --foo-arg value '
+        ),
+        (
+            'aws ec2 --endpoint-url https://foo stop-instances --debug '
+            '--instance-ids i-123 i-124 --foo-arg value '
+        ),
+    ],
 )
 def test_can_handle_arbitrary_ordering(command_line):
     # This test verifies that parse to the same result given a command
@@ -140,8 +235,7 @@ def test_can_handle_arbitrary_ordering(command_line):
     expected = parser.ParsedResult(
         current_command='stop-instances',
         global_params={'debug': True, 'endpoint-url': 'https://foo'},
-        parsed_params={'instance-ids': ['i-123', 'i-124'],
-                       'foo-arg': 'value'},
+        parsed_params={'instance-ids': ['i-123', 'i-124'], 'foo-arg': 'value'},
         lineage=['aws', 'ec2'],
         current_fragment='',
     )
@@ -153,8 +247,11 @@ def _assert_parses_to(command_line, expected):
     result = p.parse(command_line)
     for key, value in vars(expected).items():
         actual = getattr(result, key)
-        assert getattr(result, key) == value, (
-            '%r != %r for attribute: %r' % (actual, value, key))
+        assert getattr(result, key) == value, '%r != %r for attribute: %r' % (
+            actual,
+            value,
+            key,
+        )
 
 
 def _generate_command_chunks():
@@ -162,9 +259,7 @@ def _generate_command_chunks():
         'aws ec2 stop-instances --instance-ids i-123 i-124 '
         '--foo-arg value --debug --endpoint-url https://foo'
     )
-    return [
-        command_line[:i] for i in range(1, len(command_line))
-    ]
+    return [command_line[:i] for i in range(1, len(command_line))]
 
 
 @pytest.mark.parametrize("chunk", _generate_command_chunks())
@@ -201,8 +296,7 @@ class TestCanParseCLICommand(unittest.TestCase):
 
     def create_parser(self, return_first_command_match=False):
         return parser.CLIParser(
-            SAMPLE_MODEL,
-            return_first_command_match=return_first_command_match
+            SAMPLE_MODEL, return_first_command_match=return_first_command_match
         )
 
     def assert_parsed_results_equal(self, actual, **expected):
@@ -210,8 +304,11 @@ class TestCanParseCLICommand(unittest.TestCase):
         # parsed.
         for key, value in expected.items():
             actual_value = getattr(actual, key)
-            self.assertEqual(actual_value, value, '%r != %r (attr: %r)'
-                             % (actual_value, value, key))
+            self.assertEqual(
+                actual_value,
+                value,
+                '%r != %r (attr: %r)' % (actual_value, value, key),
+            )
 
     def assert_parsed_s3api_result_correct(self, result):
         self.assert_parsed_results_equal(
@@ -220,7 +317,7 @@ class TestCanParseCLICommand(unittest.TestCase):
             parsed_params={
                 'outfile': 'filename',
                 'bucket': 'myBucket',
-                'key': 'foo'
+                'key': 'foo',
             },
             lineage=['aws', 's3api'],
             unparsed_items=[],
@@ -252,47 +349,49 @@ class TestCanParseCLICommand(unittest.TestCase):
         )
 
     def test_can_parse_operation_command_accepts_single_value_arg(self):
-        result = self.cli_parser.parse(
-            'aws ec2 stop-instances --foo-arg bar ')
+        result = self.cli_parser.parse('aws ec2 stop-instances --foo-arg bar ')
         self.assert_parsed_results_equal(
             result,
             current_command='stop-instances',
             global_params={},
             parsed_params={'foo-arg': 'bar'},
-            lineage=['aws', 'ec2']
+            lineage=['aws', 'ec2'],
         )
 
     def test_can_parse_operation_command_with_param(self):
         result = self.cli_parser.parse(
-            'aws ec2 stop-instances --instance-ids i-1 ')
+            'aws ec2 stop-instances --instance-ids i-1 '
+        )
         self.assert_parsed_results_equal(
             result,
             current_command='stop-instances',
             global_params={},
             parsed_params={'instance-ids': ['i-1']},
-            lineage=['aws', 'ec2']
+            lineage=['aws', 'ec2'],
         )
 
     def test_can_parse_bool_param(self):
         result = self.cli_parser.parse(
-            'aws --debug ec2 stop-instances --instance-ids i-1 ')
+            'aws --debug ec2 stop-instances --instance-ids i-1 '
+        )
         self.assert_parsed_results_equal(
             result,
             current_command='stop-instances',
             global_params={'debug': True},
             parsed_params={'instance-ids': ['i-1']},
-            lineage=['aws', 'ec2']
+            lineage=['aws', 'ec2'],
         )
 
     def test_can_parse_bool_param_in_any_location(self):
         result = self.cli_parser.parse(
-            'aws ec2 stop-instances --instance-ids i-1 --debug')
+            'aws ec2 stop-instances --instance-ids i-1 --debug'
+        )
         self.assert_parsed_results_equal(
             result,
             current_command='stop-instances',
             global_params={'debug': True},
             parsed_params={'instance-ids': ['i-1']},
-            lineage=['aws', 'ec2']
+            lineage=['aws', 'ec2'],
         )
 
     def test_can_parse_operation_command(self):
@@ -302,7 +401,7 @@ class TestCanParseCLICommand(unittest.TestCase):
             current_command='stop-instances',
             global_params={},
             parsed_params={},
-            lineage=['aws', 'ec2']
+            lineage=['aws', 'ec2'],
         )
 
     def test_can_parse_service_command(self):
@@ -326,7 +425,8 @@ class TestCanParseCLICommand(unittest.TestCase):
 
     def test_ignores_unknown_args(self):
         result = self.cli_parser.parse(
-            'aws ec2 stop-instances --unknown-arg bar')
+            'aws ec2 stop-instances --unknown-arg bar'
+        )
         self.assert_parsed_results_equal(
             result,
             current_command='stop-instances',
@@ -368,7 +468,8 @@ class TestCanParseCLICommand(unittest.TestCase):
 
     def test_can_consume_one_or_more_nargs(self):
         result = self.cli_parser.parse(
-            'aws ec2 stop-instances --instance-ids i-1 i-2 i-3 ')
+            'aws ec2 stop-instances --instance-ids i-1 i-2 i-3 '
+        )
         self.assert_parsed_results_equal(
             result,
             current_command='stop-instances',
@@ -380,22 +481,33 @@ class TestCanParseCLICommand(unittest.TestCase):
         model = copy.deepcopy(SAMPLE_MODEL)
         nargs_one_or_more = '?'
         model.index['arg_data']['aws.ec2']['stop-instances']['foo-arg'] = (
-            'foo-arg', 'string',
-            'stop-instances', 'aws.ec2', nargs_one_or_more, False, False)
+            'foo-arg',
+            'string',
+            'stop-instances',
+            'aws.ec2',
+            nargs_one_or_more,
+            False,
+            False,
+        )
         p = parser.CLIParser(model)
         self.assertEqual(
-            p.parse(
-                'aws ec2 stop-instances --foo-arg --debug'
-            ).parsed_params['foo-arg'], None)
+            p.parse('aws ec2 stop-instances --foo-arg --debug').parsed_params[
+                'foo-arg'
+            ],
+            None,
+        )
         self.assertEqual(
             p.parse(
                 'aws ec2 stop-instances --foo-arg bar --debug'
-            ).parsed_params['foo-arg'], 'bar')
+            ).parsed_params['foo-arg'],
+            'bar',
+        )
 
     def test_truncates_line_based_on_location(self):
         # The 22nd index cuts off right after `stop-instances`.
         result = self.cli_parser.parse(
-            'aws ec2 stop-instances --instance-ids i-1 i-2 i-3', 22)
+            'aws ec2 stop-instances --instance-ids i-1 i-2 i-3', 22
+        )
         # We should not have parsed the 'instance-ids'.
         self.assert_parsed_results_equal(
             result,
@@ -439,8 +551,7 @@ class TestCanParseCLICommand(unittest.TestCase):
         )
 
     def test_current_fragment_can_be_option(self):
-        result = self.cli_parser.parse(
-            'aws ec2 stop-instances --inst')
+        result = self.cli_parser.parse('aws ec2 stop-instances --inst')
         # We should not have parsed the 'instance-ids'.
         self.assert_parsed_results_equal(
             result,
@@ -451,8 +562,7 @@ class TestCanParseCLICommand(unittest.TestCase):
         )
 
     def test_option_not_preserved_when_space_separated(self):
-        result = self.cli_parser.parse(
-            'aws ec2 stop-instances --inst ')
+        result = self.cli_parser.parse('aws ec2 stop-instances --inst ')
         self.assert_parsed_results_equal(
             result,
             current_command='stop-instances',
@@ -463,8 +573,7 @@ class TestCanParseCLICommand(unittest.TestCase):
         )
 
     def test_can_have_unparsed_option_with_current_fragment(self):
-        result = self.cli_parser.parse(
-            'aws ec2 stop-instances --inst foo')
+        result = self.cli_parser.parse('aws ec2 stop-instances --inst foo')
         self.assert_parsed_results_equal(
             result,
             current_command='stop-instances',
@@ -479,8 +588,7 @@ class TestCanParseCLICommand(unittest.TestCase):
         # auto-completion, but we still need to decided where
         # we should put the 'foo' value.  I think it makes the
         # most sense to put this under "unparsed_items".
-        result = self.cli_parser.parse(
-            'aws ec2 stop-instances --inst foo ')
+        result = self.cli_parser.parse('aws ec2 stop-instances --inst foo ')
         self.assert_parsed_results_equal(
             result,
             current_command='stop-instances',
@@ -491,8 +599,7 @@ class TestCanParseCLICommand(unittest.TestCase):
         )
 
     def test_can_handle_multiple_unknown_options(self):
-        result = self.cli_parser.parse(
-            'aws ec2 stop-instances --inst --foo ')
+        result = self.cli_parser.parse('aws ec2 stop-instances --inst --foo ')
         self.assert_parsed_results_equal(
             result,
             current_command='stop-instances',
@@ -508,7 +615,7 @@ class TestCanParseCLICommand(unittest.TestCase):
             result,
             current_command='aws',
             current_fragment='',
-            unparsed_items=['ec', 'stop-insta']
+            unparsed_items=['ec', 'stop-insta'],
         )
 
     def test_can_handle_error_cases_gracefully(self):
@@ -516,7 +623,8 @@ class TestCanParseCLICommand(unittest.TestCase):
         # It would normally generate a parser error.  We should make sure
         # we handle this gracefully.
         result = self.cli_parser.parse(
-            'aws ec2 stop-instances --foo-arg a b --')
+            'aws ec2 stop-instances --foo-arg a b --'
+        )
         self.assert_parsed_results_equal(
             result,
             current_command='stop-instances',
@@ -634,15 +742,12 @@ class TestCanParseCLICommand(unittest.TestCase):
     def test_parse_positional_with_option(self):
         result = self.cli_parser.parse(
             'aws logs tail mygroup --filter-pattern pat',
-            )
+        )
         self.assert_parsed_results_equal(
             result,
             current_command='tail',
             current_param='filter-pattern',
-            parsed_params={
-                'filter-pattern': None,
-                'group_name': 'mygroup'
-            },
+            parsed_params={'filter-pattern': None, 'group_name': 'mygroup'},
             lineage=['aws', 'logs'],
             current_fragment='pat',
             unparsed_items=[],
@@ -651,7 +756,7 @@ class TestCanParseCLICommand(unittest.TestCase):
     def test_parse_positional_with_option_before(self):
         result = self.cli_parser.parse(
             'aws logs tail --filter-pattern pattern mygroup',
-            )
+        )
         self.assert_parsed_results_equal(
             result,
             current_command='tail',
@@ -667,7 +772,7 @@ class TestCanParseCLICommand(unittest.TestCase):
     def test_parse_outfile_option_in_the_beginning(self):
         result = self.cli_parser.parse(
             'aws s3api get-object filename --bucket myBucket --key foo ',
-            )
+        )
         self.assert_parsed_s3api_result_correct(result)
 
     def test_parse_outfile_option_in_the_middle(self):
@@ -712,5 +817,6 @@ class TestParseState(unittest.TestCase):
         state.current_command = 'describe-instances'
         self.assertEqual(state.current_command, 'describe-instances')
         self.assertEqual(state.lineage, ['aws', 'ec2'])
-        self.assertEqual(state.full_lineage,
-                         ['aws', 'ec2', 'describe-instances'])
+        self.assertEqual(
+            state.full_lineage, ['aws', 'ec2', 'describe-instances']
+        )
