@@ -1,7 +1,9 @@
 import botocore.crt.auth
 
 from tests.unit.botocore.auth.test_signers import (
-    TestS3SigV4Auth, TestSigV4Presign, TestSigV4Resign
+    TestS3SigV4Auth,
+    TestSigV4Presign,
+    TestSigV4Resign,
 )
 
 
