@@ -10,18 +10,25 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-"""Unit tests for the binary event stream decoder. """
-import pytest
-from tests import mock
+"""Unit tests for the binary event stream decoder."""
 
-from botocore.parsers import EventStreamXMLParser
+import pytest
 from botocore.eventstream import (
-    EventStreamMessage, MessagePrelude, EventStreamBuffer,
-    ChecksumMismatch, InvalidPayloadLength, InvalidHeadersLength,
-    DuplicateHeader, EventStreamHeaderParser, DecodeUtils, EventStream,
-    NoInitialResponseError
+    ChecksumMismatch,
+    DecodeUtils,
+    DuplicateHeader,
+    EventStream,
+    EventStreamBuffer,
+    EventStreamHeaderParser,
+    EventStreamMessage,
+    InvalidHeadersLength,
+    MessagePrelude,
+    NoInitialResponseError,
 )
 from botocore.exceptions import EventStreamError
+from botocore.parsers import EventStreamXMLParser
+
+from tests import mock
 
 EMPTY_MESSAGE = (
     b'\x00\x00\x00\x10\x00\x00\x00\x00\x05\xc2H\xeb}\x98\xc8\xff',
@@ -29,12 +36,12 @@ EMPTY_MESSAGE = (
         prelude=MessagePrelude(
             total_length=0x10,
             headers_length=0,
-            crc=0x05c248eb,
+            crc=0x05C248EB,
         ),
         headers={},
         payload=b'',
-        crc=0x7d98c8ff,
-    )
+        crc=0x7D98C8FF,
+    ),
 )
 
 INT8_HEADER = (
@@ -50,8 +57,8 @@ INT8_HEADER = (
         ),
         headers={'byte': -1},
         payload=b'',
-        crc=0xc2f869dc,
-    )
+        crc=0xC2F869DC,
+    ),
 )
 
 INT16_HEADER = (
@@ -63,12 +70,12 @@ INT16_HEADER = (
         prelude=MessagePrelude(
             total_length=0x19,
             headers_length=0x9,
-            crc=0x710e923e,
+            crc=0x710E923E,
         ),
         headers={'short': -1},
         payload=b'',
-        crc=0xb27cb6cc,
-    )
+        crc=0xB27CB6CC,
+    ),
 )
 
 INT32_HEADER = (
@@ -80,12 +87,12 @@ INT32_HEADER = (
         prelude=MessagePrelude(
             total_length=0x1D,
             headers_length=0xD,
-            crc=0x83e3f0e7,
+            crc=0x83E3F0E7,
         ),
         headers={'integer': -1},
         payload=b'',
-        crc=0x8b8e12eb,
-    )
+        crc=0x8B8E12EB,
+    ),
 )
 
 INT64_HEADER = (
@@ -97,55 +104,59 @@ INT64_HEADER = (
         prelude=MessagePrelude(
             total_length=0x1E,
             headers_length=0xE,
-            crc=0x5d4adb8d,
+            crc=0x5D4ADB8D,
         ),
         headers={'long': -1},
         payload=b'',
-        crc=0x4bc232da,
-    )
+        crc=0x4BC232DA,
+    ),
 )
 
 PAYLOAD_NO_HEADERS = (
     b"\x00\x00\x00\x1d\x00\x00\x00\x00\xfdR\x8cZ{'foo':'bar'}\xc3e96",
     EventStreamMessage(
         prelude=MessagePrelude(
-            total_length=0x1d,
+            total_length=0x1D,
             headers_length=0,
-            crc=0xfd528c5a,
+            crc=0xFD528C5A,
         ),
         headers={},
         payload=b"{'foo':'bar'}",
-        crc=0xc3653936,
-    )
+        crc=0xC3653936,
+    ),
 )
 
 PAYLOAD_ONE_STR_HEADER = (
-    (b"\x00\x00\x00=\x00\x00\x00 \x07\xfd\x83\x96\x0ccontent-type\x07\x00\x10"
-     b"application/json{'foo':'bar'}\x8d\x9c\x08\xb1"),
+    (
+        b"\x00\x00\x00=\x00\x00\x00 \x07\xfd\x83\x96\x0ccontent-type\x07\x00\x10"
+        b"application/json{'foo':'bar'}\x8d\x9c\x08\xb1"
+    ),
     EventStreamMessage(
         prelude=MessagePrelude(
-            total_length=0x3d,
+            total_length=0x3D,
             headers_length=0x20,
-            crc=0x07fd8396,
+            crc=0x07FD8396,
         ),
         headers={'content-type': 'application/json'},
         payload=b"{'foo':'bar'}",
-        crc=0x8d9c08b1,
-    )
+        crc=0x8D9C08B1,
+    ),
 )
 
 ALL_HEADERS_TYPES = (
-    (b"\x00\x00\x00\x62\x00\x00\x00\x52\x03\xb5\xcb\x9c"
-     b"\x010\x00\x011\x01\x012\x02\x02\x013\x03\x00\x03"
-     b"\x014\x04\x00\x00\x00\x04\x015\x05\x00\x00\x00\x00\x00\x00\x00\x05"
-     b"\x016\x06\x00\x05bytes\x017\x07\x00\x04utf8"
-     b"\x018\x08\x00\x00\x00\x00\x00\x00\x00\x08\x019\x090123456789abcdef"
-     b"\x63\x35\x36\x71"),
+    (
+        b"\x00\x00\x00\x62\x00\x00\x00\x52\x03\xb5\xcb\x9c"
+        b"\x010\x00\x011\x01\x012\x02\x02\x013\x03\x00\x03"
+        b"\x014\x04\x00\x00\x00\x04\x015\x05\x00\x00\x00\x00\x00\x00\x00\x05"
+        b"\x016\x06\x00\x05bytes\x017\x07\x00\x04utf8"
+        b"\x018\x08\x00\x00\x00\x00\x00\x00\x00\x08\x019\x090123456789abcdef"
+        b"\x63\x35\x36\x71"
+    ),
     EventStreamMessage(
         prelude=MessagePrelude(
             total_length=0x62,
             headers_length=0x52,
-            crc=0x03b5cb9c,
+            crc=0x03B5CB9C,
         ),
         headers={
             '0': True,
@@ -155,26 +166,28 @@ ALL_HEADERS_TYPES = (
             '4': 0x04,
             '5': 0x05,
             '6': b'bytes',
-            '7': u'utf8',
+            '7': 'utf8',
             '8': 0x08,
             '9': b'0123456789abcdef',
         },
         payload=b"",
         crc=0x63353671,
-    )
+    ),
 )
 
 ERROR_EVENT_MESSAGE = (
-    (b"\x00\x00\x00\x52\x00\x00\x00\x42\xbf\x23\x63\x7e"
-     b"\x0d:message-type\x07\x00\x05error"
-     b"\x0b:error-code\x07\x00\x04code"
-     b"\x0e:error-message\x07\x00\x07message"
-     b"\x6b\x6c\xea\x3d"),
+    (
+        b"\x00\x00\x00\x52\x00\x00\x00\x42\xbf\x23\x63\x7e"
+        b"\x0d:message-type\x07\x00\x05error"
+        b"\x0b:error-code\x07\x00\x04code"
+        b"\x0e:error-message\x07\x00\x07message"
+        b"\x6b\x6c\xea\x3d"
+    ),
     EventStreamMessage(
         prelude=MessagePrelude(
             total_length=0x52,
             headers_length=0x42,
-            crc=0xbf23637e,
+            crc=0xBF23637E,
         ),
         headers={
             ':message-type': 'error',
@@ -182,8 +195,8 @@ ERROR_EVENT_MESSAGE = (
             ':error-message': 'message',
         },
         payload=b'',
-        crc=0x6b6cea3d,
-    )
+        crc=0x6B6CEA3D,
+    ),
 )
 
 # Tuples of encoded messages and their expected decoded output
@@ -200,31 +213,51 @@ POSITIVE_CASES = [
 ]
 
 CORRUPTED_HEADER_LENGTH = (
-    (b"\x00\x00\x00=\xFF\x00\x01\x02\x07\xfd\x83\x96\x0ccontent-type\x07\x00"
-     b"\x10application/json{'foo':'bar'}\x8d\x9c\x08\xb1"),
-    InvalidHeadersLength
+    (
+        b"\x00\x00\x00=\xff\x00\x01\x02\x07\xfd\x83\x96\x0ccontent-type\x07\x00"
+        b"\x10application/json{'foo':'bar'}\x8d\x9c\x08\xb1"
+    ),
+    ChecksumMismatch,
 )
 
 CORRUPTED_HEADERS = (
-    (b"\x00\x00\x00=\x00\x00\x00 \x07\xfd\x83\x96\x0ccontent+type\x07\x00\x10"
-     b"application/json{'foo':'bar'}\x8d\x9c\x08\xb1"),
-    ChecksumMismatch
+    (
+        b"\x00\x00\x00=\x00\x00\x00 \x07\xfd\x83\x96\x0ccontent+type\x07\x00\x10"
+        b"application/json{'foo':'bar'}\x8d\x9c\x08\xb1"
+    ),
+    ChecksumMismatch,
 )
 
 CORRUPTED_LENGTH = (
     b"\x01\x00\x00\x1d\x00\x00\x00\x00\xfdR\x8cZ{'foo':'bar'}\xc3e96",
-    InvalidPayloadLength
+    ChecksumMismatch,
 )
 
 CORRUPTED_PAYLOAD = (
     b"\x00\x00\x00\x1d\x00\x00\x00\x00\xfdR\x8cZ{'foo':'bar'\x8d\xc3e96",
-    ChecksumMismatch
+    ChecksumMismatch,
 )
 
 DUPLICATE_HEADER = (
-    (b"\x00\x00\x00\x24\x00\x00\x00\x14\x4b\xb9\x82\xd0"
-     b"\x04test\x04asdf\x04test\x04asdf\xf3\xf4\x75\x63"),
-    DuplicateHeader
+    (
+        b"\x00\x00\x00\x24\x00\x00\x00\x14\x4b\xb9\x82\xd0"
+        b"\x04test\x04asdf\x04test\x04asdf\xf3\xf4\x75\x63"
+    ),
+    DuplicateHeader,
+)
+
+# In contrast to the CORRUPTED_HEADERS case, this message is otherwise
+# well-formed - the checksums match.
+INVALID_HEADERS_LENGTH = (
+    (
+        b"\x00\x00\x00\x3d"  # total length
+        b"\xff\x00\x01\x02"  # headers length
+        b"\x15\x83\xf5\xc2"  # prelude crc
+        b"\x0ccontent-type\x07\x00\x10application/json"  # headers
+        b"{'foo':'bar'}"  # payload
+        b"\x2f\x37\x7f\x5d"  # message crc
+    ),
+    InvalidHeadersLength,
 )
 
 # Tuples of encoded messages and their expected exception
@@ -234,11 +267,12 @@ NEGATIVE_CASES = [
     CORRUPTED_HEADERS,
     CORRUPTED_HEADER_LENGTH,
     DUPLICATE_HEADER,
+    INVALID_HEADERS_LENGTH,
 ]
 
 
 def assert_message_equal(message_a, message_b):
-    """Asserts all fields for two messages are equal. """
+    """Asserts all fields for two messages are equal."""
     assert message_a.prelude.total_length == message_b.prelude.total_length
     assert message_a.prelude.headers_length == message_b.prelude.headers_length
     assert message_a.prelude.crc == message_b.prelude.crc
@@ -248,7 +282,7 @@ def assert_message_equal(message_a, message_b):
 
 
 def test_partial_message():
-    """ Ensure that we can receive partial payloads. """
+    """Ensure that we can receive partial payloads."""
     data = EMPTY_MESSAGE[0]
     event_buffer = EventStreamBuffer()
     # This mid point is an arbitrary break in the middle of the headers
@@ -256,13 +290,13 @@ def test_partial_message():
     event_buffer.add_data(data[:mid_point])
     messages = list(event_buffer)
     assert messages == []
-    event_buffer.add_data(data[mid_point:len(data)])
+    event_buffer.add_data(data[mid_point : len(data)])
     for message in event_buffer:
         assert_message_equal(message, EMPTY_MESSAGE[1])
 
 
 def check_message_decodes(encoded, decoded):
-    """ Ensure the message decodes to what we expect. """
+    """Ensure the message decodes to what we expect."""
     event_buffer = EventStreamBuffer()
     event_buffer.add_data(encoded)
     messages = list(event_buffer)
@@ -272,39 +306,50 @@ def check_message_decodes(encoded, decoded):
 
 @pytest.mark.parametrize("encoded, decoded", POSITIVE_CASES)
 def test_positive_cases(encoded, decoded):
-    """Test that all positive cases decode how we expect. """
+    """Test that all positive cases decode how we expect."""
     check_message_decodes(encoded, decoded)
 
 
 def test_all_positive_cases():
-    """Test all positive cases can be decoded on the same buffer. """
+    """Test all positive cases can be decoded on the same buffer."""
     event_buffer = EventStreamBuffer()
     # add all positive test cases to the same buffer
-    for (encoded, _) in POSITIVE_CASES:
+    for encoded, _ in POSITIVE_CASES:
         event_buffer.add_data(encoded)
     # collect all of the expected messages
     expected_messages = [decoded for (_, decoded) in POSITIVE_CASES]
     # collect all of the decoded messages
     decoded_messages = list(event_buffer)
     # assert all messages match what we expect
-    for (expected, decoded) in zip(expected_messages, decoded_messages):
+    for expected, decoded in zip(expected_messages, decoded_messages):
         assert_message_equal(expected, decoded)
 
 
-@pytest.mark.parametrize("encoded, exception", NEGATIVE_CASES)
+@pytest.mark.parametrize(
+    "encoded, exception",
+    NEGATIVE_CASES,
+    ids=[
+        "corrupted-length",
+        "corrupted-payload",
+        "corrupted-headers",
+        "corrupted-headers-length",
+        "duplicate-headers",
+        "invalid-headers-length",
+    ],
+)
 def test_negative_cases(encoded, exception):
-    """Test that all negative cases raise the expected exception. """
+    """Test that all negative cases raise the expected exception."""
     with pytest.raises(exception):
         check_message_decodes(encoded, None)
 
 
 def test_header_parser():
-    """Test that the header parser supports all header types. """
+    """Test that the header parser supports all header types."""
     headers_data = (
-     b"\x010\x00\x011\x01\x012\x02\x02\x013\x03\x00\x03"
-     b"\x014\x04\x00\x00\x00\x04\x015\x05\x00\x00\x00\x00\x00\x00\x00\x05"
-     b"\x016\x06\x00\x05bytes\x017\x07\x00\x04utf8"
-     b"\x018\x08\x00\x00\x00\x00\x00\x00\x00\x08\x019\x090123456789abcdef"
+        b"\x010\x00\x011\x01\x012\x02\x02\x013\x03\x00\x03"
+        b"\x014\x04\x00\x00\x00\x04\x015\x05\x00\x00\x00\x00\x00\x00\x00\x05"
+        b"\x016\x06\x00\x05bytes\x017\x07\x00\x04utf8"
+        b"\x018\x08\x00\x00\x00\x00\x00\x00\x00\x08\x019\x090123456789abcdef"
     )
 
     expected_headers = {
@@ -315,7 +360,7 @@ def test_header_parser():
         '4': 0x04,
         '5': 0x05,
         '6': b'bytes',
-        '7': u'utf8',
+        '7': 'utf8',
         '8': 0x08,
         '9': b'0123456789abcdef',
     }
@@ -326,7 +371,7 @@ def test_header_parser():
 
 
 def test_message_prelude_properties():
-    """Test that calculated properties from the payload are correct. """
+    """Test that calculated properties from the payload are correct."""
     # Total length: 40, Headers Length: 15, random crc
     prelude = MessagePrelude(40, 15, 0x00000000)
     assert prelude.payload_length == 9
@@ -336,7 +381,7 @@ def test_message_prelude_properties():
 
 def test_message_to_response_dict():
     response_dict = PAYLOAD_ONE_STR_HEADER[1].to_response_dict()
-    assert response_dict['status_code'] ==200
+    assert response_dict['status_code'] == 200
 
     expected_headers = {'content-type': 'application/json'}
     assert response_dict['headers'] == expected_headers
@@ -356,37 +401,37 @@ def test_message_to_response_dict_error():
 
 
 def test_unpack_uint8():
-    (value, bytes_consumed) = DecodeUtils.unpack_uint8(b'\xDE')
+    (value, bytes_consumed) = DecodeUtils.unpack_uint8(b'\xde')
     assert bytes_consumed == 1
     assert value == 0xDE
 
 
 def test_unpack_uint32():
-    (value, bytes_consumed) = DecodeUtils.unpack_uint32(b'\xDE\xAD\xBE\xEF')
+    (value, bytes_consumed) = DecodeUtils.unpack_uint32(b'\xde\xad\xbe\xef')
     assert bytes_consumed == 4
     assert value == 0xDEADBEEF
 
 
 def test_unpack_int8():
-    (value, bytes_consumed) = DecodeUtils.unpack_int8(b'\xFE')
+    (value, bytes_consumed) = DecodeUtils.unpack_int8(b'\xfe')
     assert bytes_consumed == 1
     assert value == -2
 
 
 def test_unpack_int16():
-    (value, bytes_consumed) = DecodeUtils.unpack_int16(b'\xFF\xFE')
+    (value, bytes_consumed) = DecodeUtils.unpack_int16(b'\xff\xfe')
     assert bytes_consumed == 2
     assert value == -2
 
 
 def test_unpack_int32():
-    (value, bytes_consumed) = DecodeUtils.unpack_int32(b'\xFF\xFF\xFF\xFE')
+    (value, bytes_consumed) = DecodeUtils.unpack_int32(b'\xff\xff\xff\xfe')
     assert bytes_consumed == 4
     assert value == -2
 
 
 def test_unpack_int64():
-    test_bytes = b'\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFE'
+    test_bytes = b'\xff\xff\xff\xff\xff\xff\xff\xfe'
     (value, bytes_consumed) = DecodeUtils.unpack_int64(test_bytes)
     assert bytes_consumed == 8
     assert value == -2
@@ -401,7 +446,8 @@ def test_unpack_array_short():
 
 def test_unpack_byte_array_int():
     (value, array_bytes_consumed) = DecodeUtils.unpack_byte_array(
-        b'\x00\x00\x00\x10application/json', length_byte_size=4)
+        b'\x00\x00\x00\x10application/json', length_byte_size=4
+    )
     assert array_bytes_consumed == 20
     assert value == b'application/json'
 
@@ -423,9 +469,10 @@ def test_unpack_prelude():
 
 def create_mock_raw_stream(*data):
     raw_stream = mock.Mock()
+
     def generator():
-        for chunk in data:
-            yield chunk
+        yield from data
+
     raw_stream.stream = generator
     return raw_stream
 
@@ -442,7 +489,7 @@ def test_event_stream_wrapper_iteration():
     assert len(events) == 1
 
     response_dict = {
-        'headers': {'event-id': 0x0000a00c},
+        'headers': {'event-id': 0x0000A00C},
         'body': b"{'foo':'bar'}",
         'status_code': 200,
     }
@@ -470,7 +517,7 @@ def test_event_stream_initial_response():
     raw_stream = create_mock_raw_stream(
         b'\x00\x00\x00~\x00\x00\x00O\xc5\xa3\xdd\xc6\r:message-type\x07\x00',
         b'\x05event\x0b:event-type\x07\x00\x10initial-response\r:content-type',
-        b'\x07\x00\ttext/json{"InitialResponse": "sometext"}\xf6\x98$\x83'
+        b'\x07\x00\ttext/json{"InitialResponse": "sometext"}\xf6\x98$\x83',
     )
     parser = mock.Mock(spec=EventStreamXMLParser)
     output_shape = mock.Mock()
