@@ -1,8 +1,6 @@
 import socket
 
 import pytest
-from urllib3.exceptions import NewConnectionError, ProtocolError, ProxyError
-
 from botocore.awsrequest import (
     AWSHTTPConnectionPool,
     AWSHTTPSConnectionPool,
@@ -19,6 +17,9 @@ from botocore.httpsession import (
     get_cert_path,
     mask_proxy_url,
 )
+from urllib3.exceptions import NewConnectionError, ProtocolError, ProxyError
+from concurrent.futures import CancelledError
+
 from tests import mock, unittest
 
 
@@ -463,6 +464,12 @@ class TestURLLib3Session(unittest.TestCase):
         with pytest.raises(ConnectionClosedError):
             self.make_request_with_error(error)
 
+    def test_catches_cancelled_error(self):
+        self.connection.urlopen.side_effect = CancelledError()
+        session = URLLib3Session()
+        with pytest.raises(CancelledError):
+            session.send(self.request.prepare())
+
     def test_catches_proxy_error(self):
         self.connection.urlopen.side_effect = ProxyError('test', None)
         session = URLLib3Session(
@@ -506,7 +513,7 @@ class TestURLLib3Session(unittest.TestCase):
         proxies = {'https': 'http://proxy.com', 'http': 'http://proxy2.com'}
         session = URLLib3Session(proxies=proxies)
         for proxy, proxy_url in proxies.items():
-            self.request.url = '%s://example.com/' % proxy
+            self.request.url = f'{proxy}://example.com/'
             session.send(self.request.prepare())
 
         session.close()
