@@ -13,29 +13,27 @@
 import unittest
 from io import BytesIO
 
-from tests import mock
-from tests.utils.botocore import get_checksum_cls
-
 from botocore.awsrequest import AWSResponse
-from botocore.model import OperationModel, StringShape, StructureShape
 from botocore.config import Config
-from botocore.exceptions import AwsChunkedWrapperError
-from botocore.exceptions import FlexibleChecksumError
-from botocore.httpchecksum import AwsChunkedWrapper
-from botocore.httpchecksum import StreamingChecksumBody
+from botocore.exceptions import AwsChunkedWrapperError, FlexibleChecksumError
 from botocore.httpchecksum import (
+    AwsChunkedWrapper,
     Crc32Checksum,
-    Sha256Checksum,
-    CrtCrc64NvmeChecksum,
-    Sha1Checksum,
     CrtCrc32cChecksum,
     CrtCrc32Checksum,
     CrtCrc64NvmeChecksum,
+    Sha1Checksum,
+    Sha256Checksum,
+    StreamingChecksumBody,
     apply_request_checksum,
     handle_checksum_body,
     resolve_request_checksum_algorithm,
     resolve_response_checksum_algorithms,
 )
+from botocore.model import OperationModel, StringShape, StructureShape
+
+from tests import mock
+from tests.utils.botocore import get_checksum_cls
 
 
 class TestHttpChecksumHandlers(unittest.TestCase):
@@ -63,7 +61,11 @@ class TestHttpChecksumHandlers(unittest.TestCase):
         return operation
 
     def _make_http_response(
-        self, body, headers=None, context=None, streaming=False,
+        self,
+        body,
+        headers=None,
+        context=None,
+        streaming=False,
     ):
         if context is None:
             context = {}
@@ -205,7 +207,7 @@ class TestHttpChecksumHandlers(unittest.TestCase):
         self.assertEqual(actual_algorithm, expected_algorithm)
 
     def test_request_checksum_algorithm_s3_signature_version_input_streaming(
-            self,
+        self,
     ):
         config = Config(signature_version="s3")
         request = self._build_request(b"")
@@ -466,11 +468,16 @@ class TestHttpChecksumHandlers(unittest.TestCase):
         context = {"checksum": {"response_algorithms": ["sha1", "crc32"]}}
         headers = {"x-amz-checksum-crc32": "DUoRhQ=="}
         http_response, response_dict = self._make_http_response(
-            b"hello world", headers=headers, context=context,
+            b"hello world",
+            headers=headers,
+            context=context,
         )
         operation_model = self._make_operation_model()
         handle_checksum_body(
-            http_response, response_dict, context, operation_model,
+            http_response,
+            response_dict,
+            context,
+            operation_model,
         )
         body = response_dict["body"]
         self.assertEqual(body, b"hello world")
@@ -479,21 +486,31 @@ class TestHttpChecksumHandlers(unittest.TestCase):
 
         headers = {"x-amz-checksum-crc32": "WrOonG=="}
         http_response, response_dict = self._make_http_response(
-            b"hello world", headers=headers, context=context,
+            b"hello world",
+            headers=headers,
+            context=context,
         )
         with self.assertRaises(FlexibleChecksumError):
             handle_checksum_body(
-                http_response, response_dict, context, operation_model,
+                http_response,
+                response_dict,
+                context,
+                operation_model,
             )
 
         # This header should not be checked, we won't calculate a checksum
         # but a proper body should still come out at the end
         headers = {"x-amz-checksum-foo": "FOO=="}
         http_response, response_dict = self._make_http_response(
-            b"hello world", headers=headers, context=context,
+            b"hello world",
+            headers=headers,
+            context=context,
         )
         handle_checksum_body(
-            http_response, response_dict, context, operation_model,
+            http_response,
+            response_dict,
+            context,
+            operation_model,
         )
         body = response_dict["body"]
         self.assertEqual(body, b"hello world")
@@ -504,11 +521,17 @@ class TestHttpChecksumHandlers(unittest.TestCase):
         context = {"checksum": {"response_algorithms": ["sha1", "crc32"]}}
         headers = {"x-amz-checksum-crc32": "DUoRhQ=="}
         http_response, response_dict = self._make_http_response(
-            b"hello world", headers=headers, context=context, streaming=True,
+            b"hello world",
+            headers=headers,
+            context=context,
+            streaming=True,
         )
         operation_model = self._make_operation_model(streaming_output=True)
         handle_checksum_body(
-            http_response, response_dict, context, operation_model,
+            http_response,
+            response_dict,
+            context,
+            operation_model,
         )
         body = response_dict["body"]
         self.assertEqual(body.read(), b"hello world")
@@ -517,10 +540,16 @@ class TestHttpChecksumHandlers(unittest.TestCase):
 
         headers = {"x-amz-checksum-crc32": "WrOonG=="}
         http_response, response_dict = self._make_http_response(
-            b"hello world", headers=headers, context=context, streaming=True,
+            b"hello world",
+            headers=headers,
+            context=context,
+            streaming=True,
         )
         handle_checksum_body(
-            http_response, response_dict, context, operation_model,
+            http_response,
+            response_dict,
+            context,
+            operation_model,
         )
         body = response_dict["body"]
         with self.assertRaises(FlexibleChecksumError):
@@ -530,10 +559,16 @@ class TestHttpChecksumHandlers(unittest.TestCase):
         # but a proper body should still come out at the end
         headers = {"x-amz-checksum-foo": "FOOO=="}
         http_response, response_dict = self._make_http_response(
-            b"hello world", headers=headers, context=context, streaming=True,
+            b"hello world",
+            headers=headers,
+            context=context,
+            streaming=True,
         )
         handle_checksum_body(
-            http_response, response_dict, context, operation_model,
+            http_response,
+            response_dict,
+            context,
+            operation_model,
         )
         body = response_dict["body"]
         self.assertEqual(body.read(), b"hello world")
@@ -547,11 +582,16 @@ class TestHttpChecksumHandlers(unittest.TestCase):
         # instead skipped
         headers = {"x-amz-checksum-crc32": "FOOO==-123"}
         http_response, response_dict = self._make_http_response(
-            b"hello world", headers=headers, context=context,
+            b"hello world",
+            headers=headers,
+            context=context,
         )
         operation_model = self._make_operation_model()
         handle_checksum_body(
-            http_response, response_dict, context, operation_model,
+            http_response,
+            response_dict,
+            context,
+            operation_model,
         )
         body = response_dict["body"]
         self.assertEqual(body, b"hello world")
@@ -563,11 +603,17 @@ class TestHttpChecksumHandlers(unittest.TestCase):
         # instead skipped
         headers = {"x-amz-checksum-crc32": "FOOO==-123"}
         http_response, response_dict = self._make_http_response(
-            b"hello world", headers=headers, context=context, streaming=True,
+            b"hello world",
+            headers=headers,
+            context=context,
+            streaming=True,
         )
         operation_model = self._make_operation_model(streaming_output=True)
         handle_checksum_body(
-            http_response, response_dict, context, operation_model,
+            http_response,
+            response_dict,
+            context,
+            operation_model,
         )
         body = response_dict["body"]
         self.assertEqual(body.read(), b"hello world")
@@ -602,7 +648,7 @@ class TestAwsChunkedWrapper(unittest.TestCase):
         class OneLessBytesIO(BytesIO):
             def read(self, size=-1):
                 # Return 1 less byte than was asked for
-                return super(OneLessBytesIO, self).read(size - 1)
+                return super().read(size - 1)
 
         bytes = OneLessBytesIO(b"abcdefghijklmnopqrstuvwxyz")
         wrapper = AwsChunkedWrapper(bytes, chunk_size=10)
@@ -705,12 +751,14 @@ class TestChecksumImplementations(unittest.TestCase):
 
     def test_sha1(self):
         self.assert_base64_checksum(
-            Sha1Checksum, "Kq5sNclPz7QV2+lfQIuc6R7oRu0=",
+            Sha1Checksum,
+            "Kq5sNclPz7QV2+lfQIuc6R7oRu0=",
         )
 
     def test_sha256(self):
         self.assert_base64_checksum(
-            Sha256Checksum, "uU0nuZNNPgilLlLX2n2r+sSE7+N6U4DukIj3rOLvzek=",
+            Sha256Checksum,
+            "uU0nuZNNPgilLlLX2n2r+sSE7+N6U4DukIj3rOLvzek=",
         )
 
     def test_crt_crc32c(self):
@@ -728,7 +776,10 @@ class TestStreamingChecksumBody(unittest.TestCase):
 
     def _make_wrapper(self, checksum):
         self.wrapper = StreamingChecksumBody(
-            self.fake_body, None, Crc32Checksum(), checksum,
+            self.fake_body,
+            None,
+            Crc32Checksum(),
+            checksum,
         )
 
     def test_basic_read_good(self):
