@@ -1,11 +1,10 @@
 import pytest
-
-from tests import unittest
-
 from botocore import model
 from botocore.compat import OrderedDict
 from botocore.exceptions import MissingServiceIdError
 
+from tests import unittest
+
 
 @pytest.mark.parametrize("property_name", ['api_version', 'protocol'])
 def test_missing_model_attribute_raises_exception(property_name):
@@ -25,17 +24,16 @@ class TestServiceId(unittest.TestCase):
 
 
 class TestServiceModel(unittest.TestCase):
-
     def setUp(self):
         self.model = {
-            'metadata': {'protocol': 'query',
-                         'endpointPrefix': 'endpoint-prefix',
-                         'serviceId': 'MyService'},
+            'metadata': {
+                'protocol': 'query',
+                'endpointPrefix': 'endpoint-prefix',
+                'serviceId': 'MyService',
+            },
             'documentation': 'Documentation value',
             'operations': {},
-            'shapes': {
-                'StringShape': {'type': 'string'}
-            }
+            'shapes': {'StringShape': {'type': 'string'}},
         }
         self.error_shapes = {
             'ExceptionOne': {
@@ -47,9 +45,7 @@ class TestServiceModel(unittest.TestCase):
                 'exception': True,
                 'type': 'structure',
                 'members': {},
-                'error': {
-                    'code': 'FooCode'
-                }
+                'error': {'code': 'FooCode'},
             },
         }
         self.service_model = model.ServiceModel(self.model)
@@ -60,8 +56,9 @@ class TestServiceModel(unittest.TestCase):
         self.assertEqual(self.service_model.metadata.get('protocol'), 'query')
 
     def test_service_name_can_be_overriden(self):
-        service_model = model.ServiceModel(self.model,
-                                           service_name='myservice')
+        service_model = model.ServiceModel(
+            self.model, service_name='myservice'
+        )
         self.assertEqual(service_model.service_name, 'myservice')
 
     def test_service_name_defaults_to_endpoint_prefix(self):
@@ -72,7 +69,8 @@ class TestServiceModel(unittest.TestCase):
 
     def test_hyphenize_service_id(self):
         self.assertEqual(
-            self.service_model.service_id.hyphenize(), 'myservice')
+            self.service_model.service_id.hyphenize(), 'myservice'
+        )
 
     def test_service_id_does_not_exist(self):
         service_model = {
@@ -82,14 +80,13 @@ class TestServiceModel(unittest.TestCase):
             },
             'documentation': 'Documentation value',
             'operations': {},
-            'shapes': {
-                'StringShape': {'type': 'string'}
-            }
+            'shapes': {'StringShape': {'type': 'string'}},
         }
         service_name = 'myservice'
         service_model = model.ServiceModel(service_model, service_name)
-        with self.assertRaisesRegex(model.UndefinedModelAttributeError,
-                                    service_name):
+        with self.assertRaisesRegex(
+            model.UndefinedModelAttributeError, service_name
+        ):
             service_model.service_id
 
     def test_operation_does_not_exist(self):
@@ -100,15 +97,17 @@ class TestServiceModel(unittest.TestCase):
         self.assertEqual(self.service_model.signing_name, 'endpoint-prefix')
 
     def test_documentation_exposed_as_property(self):
-        self.assertEqual(self.service_model.documentation,
-                         'Documentation value')
+        self.assertEqual(
+            self.service_model.documentation, 'Documentation value'
+        )
 
     def test_shape_names(self):
         self.assertEqual(self.service_model.shape_names, ['StringShape'])
 
     def test_repr_has_service_name(self):
-        self.assertEqual(repr(self.service_model),
-                         'ServiceModel(endpoint-prefix)')
+        self.assertEqual(
+            repr(self.service_model), 'ServiceModel(endpoint-prefix)'
+        )
 
     def test_shape_for_error_code(self):
         self.model['shapes'].update(self.error_shapes)
@@ -164,6 +163,19 @@ class TestServiceModel(unittest.TestCase):
         )
         self.assertEqual(len(self.service_model.client_context_parameters), 0)
 
+    def test_protocol_resolution_without_protocols_trait(self):
+        self.assertIsNone(self.service_model.metadata.get('protocols'))
+        self.assertEqual(self.service_model.resolved_protocol, 'query')
+
+    def test_protocol_resolution_picks_highest_supported(self):
+        self.service_model.metadata['protocols'] = ['query', 'json']
+        self.assertEqual(self.service_model.resolved_protocol, 'json')
+
+    def test_protocol_raises_error_for_unsupported_protocol(self):
+        self.service_model.metadata['protocols'] = ['wrongprotocol']
+        with self.assertRaises(model.UnsupportedServiceProtocolsError):
+            self.service_model.resolved_protocol
+
 
 class TestOperationModelFromService(unittest.TestCase):
     def setUp(self):
@@ -177,9 +189,7 @@ class TestOperationModelFromService(unittest.TestCase):
                         'requestUri': '/',
                     },
                     'name': 'OperationName',
-                    'input': {
-                        'shape': 'OperationNameRequest'
-                    },
+                    'input': {'shape': 'OperationNameRequest'},
                     'output': {
                         'shape': 'OperationNameResponse',
                     },
@@ -194,9 +204,7 @@ class TestOperationModelFromService(unittest.TestCase):
                         'requestUri': '/',
                     },
                     'name': 'OperationTwo',
-                    'input': {
-                        'shape': 'OperationNameRequest'
-                    },
+                    'input': {'shape': 'OperationNameRequest'},
                     'output': {
                         'shape': 'OperationNameResponse',
                     },
@@ -209,9 +217,7 @@ class TestOperationModelFromService(unittest.TestCase):
                         'requestUri': '/',
                     },
                     'name': 'PayloadOperation',
-                    'input': {
-                        'shape': 'PayloadOperationRequest'
-                    },
+                    'input': {'shape': 'PayloadOperationRequest'},
                     'output': {
                         'shape': 'PayloadOperationResponse',
                     },
@@ -225,9 +231,7 @@ class TestOperationModelFromService(unittest.TestCase):
                         'requestUri': '/',
                     },
                     'name': 'NoBodyOperation',
-                    'input': {
-                        'shape': 'NoBodyOperationRequest'
-                    },
+                    'input': {'shape': 'NoBodyOperationRequest'},
                     'output': {
                         'shape': 'OperationNameResponse',
                     },
@@ -260,7 +264,7 @@ class TestOperationModelFromService(unittest.TestCase):
                     'members': {
                         'Arg1': {'shape': 'stringType'},
                         'Arg2': {'shape': 'stringType'},
-                    }
+                    },
                 },
                 'OperationNameResponse': {
                     'type': 'structure',
@@ -268,7 +272,7 @@ class TestOperationModelFromService(unittest.TestCase):
                         'String': {
                             'shape': 'stringType',
                         }
-                    }
+                    },
                 },
                 'PayloadOperationRequest': {
                     'type': 'structure',
@@ -276,7 +280,7 @@ class TestOperationModelFromService(unittest.TestCase):
                         'Arg1': {'shape': 'TestConfig'},
                         'Arg2': {'shape': 'stringType'},
                     },
-                    'payload': 'Arg1'
+                    'payload': 'Arg1',
                 },
                 'PayloadOperationResponse': {
                     'type': 'structure',
@@ -285,7 +289,7 @@ class TestOperationModelFromService(unittest.TestCase):
                             'shape': 'stringType',
                         }
                     },
-                    'payload': 'String'
+                    'payload': 'String',
                 },
                 'NoBodyOperationRequest': {
                     'type': 'structure',
@@ -293,9 +297,9 @@ class TestOperationModelFromService(unittest.TestCase):
                         'data': {
                             'location': 'header',
                             'locationName': 'x-amz-data',
-                            'shape': 'stringType'
+                            'shape': 'stringType',
                         }
-                    }
+                    },
                 },
                 'ContextParamOperationRequest': {
                     'type': 'structure',
@@ -311,27 +315,24 @@ class TestOperationModelFromService(unittest.TestCase):
                 },
                 'NoSuchResourceException': {
                     'type': 'structure',
-                    'members': {}
+                    'members': {},
                 },
                 'stringType': {
                     'type': 'string',
                 },
                 'TestConfig': {
                     'type': 'structure',
-                    'members': {
-                        'timeout': {
-                            'shape': 'stringType'
-                        }
-                    }
+                    'members': {'timeout': {'shape': 'stringType'}},
                 },
-            }
+            },
         }
         self.service_model = model.ServiceModel(self.model)
 
     def test_wire_name_always_matches_model(self):
         service_model = model.ServiceModel(self.model)
         operation = model.OperationModel(
-            self.model['operations']['OperationName'], service_model, 'Foo')
+            self.model['operations']['OperationName'], service_model, 'Foo'
+        )
         self.assertEqual(operation.name, 'Foo')
         self.assertEqual(operation.wire_name, 'OperationName')
 
@@ -343,7 +344,8 @@ class TestOperationModelFromService(unittest.TestCase):
     def test_name_and_wire_name_defaults_to_same_value(self):
         service_model = model.ServiceModel(self.model)
         operation = model.OperationModel(
-            self.model['operations']['OperationName'], service_model)
+            self.model['operations']['OperationName'], service_model
+        )
         self.assertEqual(operation.name, 'OperationName')
         self.assertEqual(operation.wire_name, 'OperationName')
 
@@ -353,8 +355,9 @@ class TestOperationModelFromService(unittest.TestCase):
         self.assertEqual(operation.name, 'OperationName')
 
     def test_name_from_service_model_when_differs_from_name(self):
-        self.model['operations']['Foo'] = \
-            self.model['operations']['OperationName']
+        self.model['operations']['Foo'] = self.model['operations'][
+            'OperationName'
+        ]
         service_model = model.ServiceModel(self.model)
         operation = service_model.operation_model('Foo')
         self.assertEqual(operation.name, 'Foo')
@@ -381,8 +384,7 @@ class TestOperationModelFromService(unittest.TestCase):
         operation = service_model.operation_model('OperationName')
         # This is an identity comparison because we don't implement
         # __eq__, so we may need to change this in the future.
-        self.assertEqual(
-            operation.service_model, service_model)
+        self.assertEqual(operation.service_model, service_model)
 
     def test_operation_output_model(self):
         service_model = model.ServiceModel(self.model)
@@ -406,7 +408,8 @@ class TestOperationModelFromService(unittest.TestCase):
         # OperationName only has a NoSuchResourceException
         self.assertEqual(len(operation.error_shapes), 1)
         self.assertEqual(
-            operation.error_shapes[0].name, 'NoSuchResourceException')
+            operation.error_shapes[0].name, 'NoSuchResourceException'
+        )
 
     def test_has_auth(self):
         operation = self.service_model.operation_model('OperationName')
@@ -566,7 +569,7 @@ class TestOperationModelFromService(unittest.TestCase):
 
 class TestOperationModelEventStreamTypes(unittest.TestCase):
     def setUp(self):
-        super(TestOperationModelEventStreamTypes, self).setUp()
+        super().setUp()
         self.model = {
             'metadata': {'protocol': 'rest-xml', 'endpointPrefix': 'foo'},
             'documentation': '',
@@ -584,25 +587,23 @@ class TestOperationModelEventStreamTypes(unittest.TestCase):
             'shapes': {
                 'NormalStructure': {
                     'type': 'structure',
-                    'members': {
-                        'Input': {'shape': 'StringType'}
-                    }
+                    'members': {'Input': {'shape': 'StringType'}},
                 },
                 'OperationRequest': {
                     'type': 'structure',
                     'members': {
                         'String': {'shape': 'StringType'},
-                        "Body": {'shape': 'EventStreamStructure'}
+                        "Body": {'shape': 'EventStreamStructure'},
                     },
-                    'payload': 'Body'
+                    'payload': 'Body',
                 },
                 'OperationResponse': {
                     'type': 'structure',
                     'members': {
                         'String': {'shape': 'StringType'},
-                        "Body": {'shape': 'EventStreamStructure'}
+                        "Body": {'shape': 'EventStreamStructure'},
                     },
-                    'payload': 'Body'
+                    'payload': 'Body',
                 },
                 'StringType': {'type': 'string'},
                 'BlobType': {'type': 'blob'},
@@ -611,31 +612,23 @@ class TestOperationModelEventStreamTypes(unittest.TestCase):
                     'type': 'structure',
                     'members': {
                         'EventA': {'shape': 'EventAStructure'},
-                        'EventB': {'shape': 'EventBStructure'}
-                    }
+                        'EventB': {'shape': 'EventBStructure'},
+                    },
                 },
                 'EventAStructure': {
                     'event': True,
                     'type': 'structure',
                     'members': {
-                        'Payload': {
-                            'shape': 'BlobType',
-                            'eventpayload': True
-                        },
-                        'Header': {
-                            'shape': 'StringType',
-                            'eventheader': True
-                        }
-                    }
+                        'Payload': {'shape': 'BlobType', 'eventpayload': True},
+                        'Header': {'shape': 'StringType', 'eventheader': True},
+                    },
                 },
                 'EventBStructure': {
                     'event': True,
                     'type': 'structure',
-                    'members': {
-                        'Records': {'shape': 'StringType'}
-                    }
-                }
-            }
+                    'members': {'Records': {'shape': 'StringType'}},
+                },
+            },
         }
 
     def update_operation(self, **kwargs):
@@ -681,7 +674,7 @@ class TestOperationModelEventStreamTypes(unittest.TestCase):
 
 class TestOperationModelStreamingTypes(unittest.TestCase):
     def setUp(self):
-        super(TestOperationModelStreamingTypes, self).setUp()
+        super().setUp()
         self.model = {
             'metadata': {'protocol': 'query', 'endpointPrefix': 'foo'},
             'documentation': '',
@@ -705,9 +698,9 @@ class TestOperationModelStreamingTypes(unittest.TestCase):
                         },
                         "Body": {
                             'shape': 'blobType',
-                        }
+                        },
                     },
-                    'payload': 'Body'
+                    'payload': 'Body',
                 },
                 'OperationResponse': {
                     'type': 'structure',
@@ -717,17 +710,15 @@ class TestOperationModelStreamingTypes(unittest.TestCase):
                         },
                         "Body": {
                             'shape': 'blobType',
-                        }
+                        },
                     },
-                    'payload': 'Body'
+                    'payload': 'Body',
                 },
                 'stringType': {
                     'type': 'string',
                 },
-                'blobType': {
-                    'type': 'blob'
-                }
-            }
+                'blobType': {'type': 'blob'},
+            },
         }
 
     def remove_payload(self, type):
@@ -766,16 +757,20 @@ class TestDeepMerge(unittest.TestCase):
             'SetQueueAttributes': {
                 'type': 'structure',
                 'members': {
-                    'MapExample': {'shape': 'StrToStrMap',
-                                   'locationName': 'Attribute'},
-                }
+                    'MapExample': {
+                        'shape': 'StrToStrMap',
+                        'locationName': 'Attribute',
+                    },
+                },
             },
             'SetQueueAttributes2': {
                 'type': 'structure',
                 'members': {
-                    'MapExample': {'shape': 'StrToStrMap',
-                                   'locationName': 'Attribute2'},
-                }
+                    'MapExample': {
+                        'shape': 'StrToStrMap',
+                        'locationName': 'Attribute2',
+                    },
+                },
             },
             'StrToStrMap': {
                 'type': 'map',
@@ -784,7 +779,7 @@ class TestDeepMerge(unittest.TestCase):
                 'flattened': True,
                 'name': 'NotAttribute',
             },
-            'StringType': {'type': 'string'}
+            'StringType': {'type': 'string'},
         }
         self.shape_resolver = model.ShapeResolver(self.shapes)
 
@@ -794,11 +789,15 @@ class TestDeepMerge(unittest.TestCase):
         # map_merged has a serialization as a member trait as well as
         # in the StrToStrMap.
         # The member trait should have precedence.
-        self.assertEqual(map_merged.serialization,
-                         # member beats the definition.
-                         {'name': 'Attribute',
-                          # From the definition.
-                          'flattened': True,})
+        self.assertEqual(
+            map_merged.serialization,
+            # member beats the definition.
+            {
+                'name': 'Attribute',
+                # From the definition.
+                'flattened': True,
+            },
+        )
         # Ensure we don't merge/mutate the original dicts.
         self.assertEqual(map_merged.key.serialization['name'], 'Name')
         self.assertEqual(map_merged.value.serialization['name'], 'Value')
@@ -822,11 +821,9 @@ class TestShapeResolver(unittest.TestCase):
                 'members': {
                     'Bar': {'shape': 'StringType'},
                     'Baz': {'shape': 'StringType'},
-                }
+                },
             },
-            "StringType": {
-                "type": "string"
-            }
+            "StringType": {"type": "string"},
         }
         resolver = model.ShapeResolver(shape_map)
         shape = resolver.get_shape_by_name('Foo')
@@ -840,11 +837,9 @@ class TestShapeResolver(unittest.TestCase):
                 'members': {
                     'Bar': {'shape': 'StringType'},
                     'Baz': {'shape': 'StringType'},
-                }
+                },
             },
-            "StringType": {
-                "type": "string"
-            }
+            "StringType": {"type": "string"},
         }
         resolver = model.ShapeResolver(shape_map)
         shape = resolver.resolve_shape_ref({'shape': 'StringType'})
@@ -858,15 +853,14 @@ class TestShapeResolver(unittest.TestCase):
                 'members': {
                     'Bar': {'shape': 'StringType'},
                     'Baz': {'shape': 'StringType', 'locationName': 'other'},
-                }
+                },
             },
-            "StringType": {
-                "type": "string"
-            }
+            "StringType": {"type": "string"},
         }
         resolver = model.ShapeResolver(shape_map)
-        shape = resolver.resolve_shape_ref({'shape': 'StringType',
-                                            'locationName': 'other'})
+        shape = resolver.resolve_shape_ref(
+            {'shape': 'StringType', 'locationName': 'other'}
+        )
         self.assertEqual(shape.serialization['name'], 'other')
         self.assertEqual(shape.name, 'StringType')
 
@@ -876,15 +870,14 @@ class TestShapeResolver(unittest.TestCase):
                 'type': 'structure',
                 'members': {
                     'Baz': {'shape': 'StringType', 'locationName': 'other'},
-                }
+                },
             },
-            "StringType": {
-                "type": "string"
-            }
+            "StringType": {"type": "string"},
         }
         resolver = model.ShapeResolver(shape_map)
-        shape = resolver.resolve_shape_ref({'shape': 'StringType',
-                                            'locationName': 'other'})
+        shape = resolver.resolve_shape_ref(
+            {'shape': 'StringType', 'locationName': 'other'}
+        )
         self.assertEqual(shape.serialization['name'], 'other')
         # serialization is computed on demand, and a cache is kept.
         # This is just verifying that trying to access serialization again
@@ -896,15 +889,16 @@ class TestShapeResolver(unittest.TestCase):
         shape_map = {
             "StringType": {
                 "type": "string",
-                "documentation": "Original documentation"
+                "documentation": "Original documentation",
             }
         }
         resolver = model.ShapeResolver(shape_map)
         shape = resolver.get_shape_by_name('StringType')
         self.assertEqual(shape.documentation, 'Original documentation')
 
-        shape = resolver.resolve_shape_ref({'shape': 'StringType',
-                                            'documentation': 'override'})
+        shape = resolver.resolve_shape_ref(
+            {'shape': 'StringType', 'documentation': 'override'}
+        )
         self.assertEqual(shape.documentation, 'override')
 
     def test_shape_type_structure(self):
@@ -914,18 +908,19 @@ class TestShapeResolver(unittest.TestCase):
                 'members': {
                     'OldPassword': {'shape': 'passwordType'},
                     'NewPassword': {'shape': 'passwordType'},
-                }
+                },
             },
             'passwordType': {
-                "type":"string",
-            }
+                "type": "string",
+            },
         }
         resolver = model.ShapeResolver(shapes)
         shape = resolver.get_shape_by_name('ChangePasswordRequest')
         self.assertEqual(shape.type_name, 'structure')
         self.assertEqual(shape.name, 'ChangePasswordRequest')
-        self.assertEqual(list(sorted(shape.members)),
-                         ['NewPassword', 'OldPassword'])
+        self.assertEqual(
+            list(sorted(shape.members)), ['NewPassword', 'OldPassword']
+        )
         self.assertEqual(shape.members['OldPassword'].name, 'passwordType')
         self.assertEqual(shape.members['OldPassword'].type_name, 'string')
         self.assertEqual(shape.error_code, None)
@@ -935,7 +930,7 @@ class TestShapeResolver(unittest.TestCase):
             'FooException': {
                 'exception': True,
                 'type': 'structure',
-                'members': {}
+                'members': {},
             }
         }
         # Test without explicit error code
@@ -958,19 +953,20 @@ class TestShapeResolver(unittest.TestCase):
                 'members': {
                     'OldPassword': {'shape': 'passwordType'},
                     'NewPassword': {'shape': 'passwordType'},
-                }
+                },
             },
             'passwordType': {
-                "type":"string",
-                "min":1,
-                "max":128,
-                "sensitive":True
-            }
+                "type": "string",
+                "min": 1,
+                "max": 128,
+                "sensitive": True,
+            },
         }
         resolver = model.ShapeResolver(shapes)
         shape = resolver.get_shape_by_name('ChangePasswordRequest')
-        self.assertEqual(shape.metadata['required'],
-                         ['OldPassword', 'NewPassword'])
+        self.assertEqual(
+            shape.metadata['required'], ['OldPassword', 'NewPassword']
+        )
         member = shape.members['OldPassword']
         self.assertEqual(member.metadata['min'], 1)
         self.assertEqual(member.metadata['max'], 128)
@@ -986,31 +982,27 @@ class TestShapeResolver(unittest.TestCase):
                     }
                 },
                 'exception': True,
-                'retryable': {'throttling': True}
+                'retryable': {'throttling': True},
             }
         }
         resolver = model.ShapeResolver(shapes)
         shape = resolver.get_shape_by_name('ResourceNotFoundException')
         self.assertEqual(
             shape.metadata,
-            {'exception': True, 'retryable': {'throttling': True}}
+            {'exception': True, 'retryable': {'throttling': True}},
         )
 
     def test_shape_list(self):
         shapes = {
             'mfaDeviceListType': {
-                "type":"list",
+                "type": "list",
                 "member": {"shape": "MFADevice"},
             },
             'MFADevice': {
                 'type': 'structure',
-                'members': {
-                    'UserName': {'shape': 'userNameType'}
-                }
+                'members': {'UserName': {'shape': 'userNameType'}},
             },
-            'userNameType': {
-                'type': 'string'
-            }
+            'userNameType': {'type': 'string'},
         }
         resolver = model.ShapeResolver(shapes)
         shape = resolver.get_shape_by_name('mfaDeviceListType')
@@ -1024,11 +1016,7 @@ class TestShapeResolver(unittest.TestCase):
             resolver.get_shape_by_name('NoExistShape')
 
     def test_missing_type_key(self):
-        shapes = {
-            'UnknownType': {
-                'NotTheTypeKey': 'someUnknownType'
-            }
-        }
+        shapes = {'UnknownType': {'NotTheTypeKey': 'someUnknownType'}}
         resolver = model.ShapeResolver(shapes)
         with self.assertRaises(model.InvalidShapeError):
             resolver.get_shape_by_name('UnknownType')
@@ -1042,7 +1030,7 @@ class TestShapeResolver(unittest.TestCase):
                 'members': {
                     'A': {'type': 'string'},
                     'B': {'type': 'string'},
-                }
+                },
             }
         }
         resolver = model.ShapeResolver(shapes)
@@ -1059,18 +1047,20 @@ class TestShapeResolver(unittest.TestCase):
             }
         }
         resolver = model.ShapeResolver(shapes)
-        self.assertIn('StringType',
-                      repr(resolver.get_shape_by_name('StringType')))
+        self.assertIn(
+            'StringType', repr(resolver.get_shape_by_name('StringType'))
+        )
 
 
 class TestBuilders(unittest.TestCase):
-
     def test_structure_shape_builder_with_scalar_types(self):
         b = model.DenormalizedStructureBuilder()
-        shape = b.with_members({
-            'A': {'type': 'string'},
-            'B': {'type': 'integer'},
-        }).build_model()
+        shape = b.with_members(
+            {
+                'A': {'type': 'string'},
+                'B': {'type': 'integer'},
+            }
+        ).build_model()
         self.assertIsInstance(shape, model.StructureShape)
         self.assertEqual(sorted(list(shape.members)), ['A', 'B'])
         self.assertEqual(shape.members['A'].type_name, 'string')
@@ -1078,14 +1068,16 @@ class TestBuilders(unittest.TestCase):
 
     def test_structure_shape_with_structure_type(self):
         b = model.DenormalizedStructureBuilder()
-        shape = b.with_members({
-            'A': {
-                'type': 'structure',
-                'members': {
-                    'A-1': {'type': 'string'},
-                }
-            },
-        }).build_model()
+        shape = b.with_members(
+            {
+                'A': {
+                    'type': 'structure',
+                    'members': {
+                        'A-1': {'type': 'string'},
+                    },
+                },
+            }
+        ).build_model()
         self.assertIsInstance(shape, model.StructureShape)
         self.assertEqual(list(shape.members), ['A'])
         self.assertEqual(shape.members['A'].type_name, 'structure')
@@ -1093,26 +1085,25 @@ class TestBuilders(unittest.TestCase):
 
     def test_structure_shape_with_list(self):
         b = model.DenormalizedStructureBuilder()
-        shape = b.with_members({
-            'A': {
-                'type': 'list',
-                'member': {
-                    'type': 'string'
-                }
-            },
-        }).build_model()
+        shape = b.with_members(
+            {
+                'A': {'type': 'list', 'member': {'type': 'string'}},
+            }
+        ).build_model()
         self.assertIsInstance(shape.members['A'], model.ListShape)
         self.assertEqual(shape.members['A'].member.type_name, 'string')
 
     def test_structure_shape_with_map_type(self):
         b = model.DenormalizedStructureBuilder()
-        shape = b.with_members({
-            'A': {
-                'type': 'map',
-                'key': {'type': 'string'},
-                'value': {'type': 'string'},
+        shape = b.with_members(
+            {
+                'A': {
+                    'type': 'map',
+                    'key': {'type': 'string'},
+                    'value': {'type': 'string'},
+                }
             }
-        }).build_model()
+        ).build_model()
         self.assertIsInstance(shape.members['A'], model.MapShape)
         map_shape = shape.members['A']
         self.assertEqual(map_shape.key.type_name, 'string')
@@ -1120,33 +1111,38 @@ class TestBuilders(unittest.TestCase):
 
     def test_nested_structure(self):
         b = model.DenormalizedStructureBuilder()
-        shape = b.with_members({
-            'A': {
-                'type': 'structure',
-                'members': {
-                    'B': {
-                        'type': 'structure',
-                        'members': {
-                            'C': {
-                                'type': 'string',
-                            }
+        shape = b.with_members(
+            {
+                'A': {
+                    'type': 'structure',
+                    'members': {
+                        'B': {
+                            'type': 'structure',
+                            'members': {
+                                'C': {
+                                    'type': 'string',
+                                }
+                            },
                         }
-                    }
+                    },
                 }
             }
-        }).build_model()
+        ).build_model()
         self.assertEqual(
-            shape.members['A'].members['B'].members['C'].type_name, 'string')
+            shape.members['A'].members['B'].members['C'].type_name, 'string'
+        )
 
     def test_enum_values_on_string_used(self):
         b = model.DenormalizedStructureBuilder()
         enum_values = ['foo', 'bar', 'baz']
-        shape = b.with_members({
-            'A': {
-                'type': 'string',
-                'enum': enum_values,
-            },
-        }).build_model()
+        shape = b.with_members(
+            {
+                'A': {
+                    'type': 'string',
+                    'enum': enum_values,
+                },
+            }
+        ).build_model()
         self.assertIsInstance(shape, model.StructureShape)
         string_shape = shape.members['A']
         self.assertIsInstance(string_shape, model.StringShape)
@@ -1155,70 +1151,76 @@ class TestBuilders(unittest.TestCase):
 
     def test_documentation_on_shape_used(self):
         b = model.DenormalizedStructureBuilder()
-        shape = b.with_members({
-            'A': {
-                'type': 'string',
-                'documentation': 'MyDocs',
-            },
-        }).build_model()
-        self.assertEqual(shape.members['A'].documentation,
-                         'MyDocs')
+        shape = b.with_members(
+            {
+                'A': {
+                    'type': 'string',
+                    'documentation': 'MyDocs',
+                },
+            }
+        ).build_model()
+        self.assertEqual(shape.members['A'].documentation, 'MyDocs')
 
     def test_min_max_used_in_metadata(self):
         b = model.DenormalizedStructureBuilder()
-        shape = b.with_members({
-            'A': {
-                'type': 'string',
-                'documentation': 'MyDocs',
-                'min': 2,
-                'max': 3,
-            },
-        }).build_model()
+        shape = b.with_members(
+            {
+                'A': {
+                    'type': 'string',
+                    'documentation': 'MyDocs',
+                    'min': 2,
+                    'max': 3,
+                },
+            }
+        ).build_model()
         metadata = shape.members['A'].metadata
         self.assertEqual(metadata.get('min'), 2)
         self.assertEqual(metadata.get('max'), 3)
 
     def test_use_shape_name_when_provided(self):
         b = model.DenormalizedStructureBuilder()
-        shape = b.with_members({
-            'A': {
-                'type': 'string',
-                'shape_name': 'MyStringShape',
-            },
-        }).build_model()
+        shape = b.with_members(
+            {
+                'A': {
+                    'type': 'string',
+                    'shape_name': 'MyStringShape',
+                },
+            }
+        ).build_model()
         self.assertEqual(shape.members['A'].name, 'MyStringShape')
 
     def test_unknown_shape_type(self):
         b = model.DenormalizedStructureBuilder()
         with self.assertRaises(model.InvalidShapeError):
-            b.with_members({
-                'A': {
-                    'type': 'brand-new-shape-type',
-                },
-            }).build_model()
+            b.with_members(
+                {
+                    'A': {
+                        'type': 'brand-new-shape-type',
+                    },
+                }
+            ).build_model()
 
     def test_ordered_shape_builder(self):
         b = model.DenormalizedStructureBuilder()
-        shape = b.with_members(OrderedDict(
-            [
-                ('A', {
-                    'type': 'string'
-                }),
-                ('B', {
-                    'type': 'structure',
-                    'members': OrderedDict(
-                        [
-                            ('C', {
-                                'type': 'string'
-                            }),
-                            ('D', {
-                                'type': 'string'
-                            })
-                        ]
-                    )
-                })
-            ]
-        )).build_model()
+        shape = b.with_members(
+            OrderedDict(
+                [
+                    ('A', {'type': 'string'}),
+                    (
+                        'B',
+                        {
+                            'type': 'structure',
+                            'members': OrderedDict(
+                                [
+                                    ('C', {'type': 'string'}),
+                                    ('D', {'type': 'string'}),
+                                ]
+                            ),
+                        },
+                    ),
+                ]
+            )
+        ).build_model()
 
         # Members should be in order
         self.assertEqual(['A', 'B'], list(shape.members.keys()))
