@@ -12,30 +12,27 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-import botocore.config
-from tests import unittest, create_session, temporary_file
-import os
 import logging
-import tempfile
+import os
 import shutil
+import tempfile
 
-import mock
-import pytest
-
-import botocore.session
+import botocore.config
 import botocore.exceptions
-from botocore import UNSIGNED
-from botocore.model import ServiceModel
-from botocore import client
-from botocore.hooks import HierarchicalEmitter
-from botocore.waiter import WaiterModel
-from botocore.paginate import PaginatorModel
-from botocore.configprovider import ConfigChainFactory
 import botocore.loaders
+import botocore.session
+import pytest
+from botocore import UNSIGNED, client
+from botocore.configprovider import ConfigChainFactory
+from botocore.hooks import HierarchicalEmitter
+from botocore.model import ServiceModel
+from botocore.paginate import PaginatorModel
+from botocore.waiter import WaiterModel
+
+from tests import create_session, mock, temporary_file, unittest
 
 
 class BaseSessionTest(unittest.TestCase):
-
     def setUp(self):
         self.environ = {}
         self.environ_patch = mock.patch('os.environ', self.environ)
@@ -44,8 +41,9 @@ class BaseSessionTest(unittest.TestCase):
         self.environ['FOO_REGION'] = 'us-west-11'
         data_path = os.path.join(os.path.dirname(__file__), 'data')
         self.environ['FOO_DATA_PATH'] = data_path
-        config_path = os.path.join(os.path.dirname(__file__), 'cfg',
-                                   'foo_config')
+        config_path = os.path.join(
+            os.path.dirname(__file__), 'cfg', 'foo_config'
+        )
         self.environ['FOO_CONFIG_FILE'] = config_path
         self.session = create_session()
         config_chain_builder = ConfigChainFactory(
@@ -100,7 +98,6 @@ class BaseSessionTest(unittest.TestCase):
 
 
 class SessionTest(BaseSessionTest):
-
     def close_log_file_handler(self, tempdir, filename):
         logger = logging.getLogger('botocore')
         handlers = logger.handlers
@@ -175,13 +172,15 @@ class SessionTest(BaseSessionTest):
         self.environ['FOO_TIMEOUT'] = '10'
         # But we should type convert this to a string.
         self.assertEqual(
-            self.session.get_config_variable('metadata_service_timeout'), 10)
+            self.session.get_config_variable('metadata_service_timeout'), 10
+        )
 
     def test_default_profile_specified_raises_exception(self):
         # If you explicity set the default profile and you don't
         # have that in your config file, an exception is raised.
-        config_path = os.path.join(os.path.dirname(__file__), 'cfg',
-                                   'boto_config_empty')
+        config_path = os.path.join(
+            os.path.dirname(__file__), 'cfg', 'boto_config_empty'
+        )
         self.environ['FOO_CONFIG_FILE'] = config_path
         self.environ['FOO_PROFILE'] = 'default'
         # In this case, even though we specified default, because
@@ -215,9 +214,13 @@ class SessionTest(BaseSessionTest):
             f.flush()
 
             full_config = self.session.full_config
-            self.assertEqual(full_config['profiles']['newprofile'],
-                             {'aws_access_key_id': 'FROM_CREDS_FILE_1',
-                              'aws_secret_access_key': 'FROM_CREDS_FILE_2'})
+            self.assertEqual(
+                full_config['profiles']['newprofile'],
+                {
+                    'aws_access_key_id': 'FROM_CREDS_FILE_1',
+                    'aws_secret_access_key': 'FROM_CREDS_FILE_2',
+                },
+            )
 
     def test_path_not_in_available_profiles(self):
         with temporary_file('w') as f:
@@ -229,12 +232,15 @@ class SessionTest(BaseSessionTest):
 
             profiles = self.session.available_profiles
             self.assertEqual(
-                set(profiles),
-                set(['foo', 'default', 'newprofile']))
+                set(profiles), set(['foo', 'default', 'newprofile'])
+            )
 
     def test_emit_delegates_to_emitter(self):
         calls = []
-        handler = lambda **kwargs: calls.append(kwargs)
+
+        def handler(**kwargs):
+            return calls.append(kwargs)
+
         self.session.register('foo', handler)
         self.session.emit('foo')
         self.assertEqual(len(calls), 1)
@@ -244,7 +250,10 @@ class SessionTest(BaseSessionTest):
         events = HierarchicalEmitter()
         session = create_session(event_hooks=events)
         calls = []
-        handler = lambda **kwargs: calls.append(kwargs)
+
+        def handler(**kwargs):
+            return calls.append(kwargs)
+
         events.register('foo', handler)
 
         session.emit('foo')
@@ -278,7 +287,10 @@ class SessionTest(BaseSessionTest):
 
     def test_register_with_unique_id(self):
         calls = []
-        handler = lambda **kwargs: calls.append(kwargs)
+
+        def handler(**kwargs):
+            return calls.append(kwargs)
+
         self.session.register('foo', handler, unique_id='bar')
         self.session.emit('foo')
         self.assertEqual(calls[0]['event_name'], 'foo')
@@ -290,20 +302,21 @@ class SessionTest(BaseSessionTest):
 
 class TestBuiltinEventHandlers(BaseSessionTest):
     def setUp(self):
-        super(TestBuiltinEventHandlers, self).setUp()
+        super().setUp()
         self.builtin_handlers = [
             ('foo', self.on_foo),
         ]
         self.foo_called = False
-        self.handler_patch = mock.patch('botocore.handlers.BUILTIN_HANDLERS',
-                                        self.builtin_handlers)
+        self.handler_patch = mock.patch(
+            'botocore.handlers.BUILTIN_HANDLERS', self.builtin_handlers
+        )
         self.handler_patch.start()
 
     def on_foo(self, **kwargs):
         self.foo_called = True
 
     def tearDown(self):
-        super(TestBuiltinEventHandlers, self).tearDown()
+        super().tearDown()
         self.handler_patch.stop()
 
     def test_registered_builtin_handlers(self):
@@ -328,8 +341,9 @@ class TestSessionConfigurationVars(BaseSessionTest):
 
         # Explicit override.
         self.session.set_config_variable('foobar', 'session-instance')
-        self.assertEqual(self.session.get_config_variable('foobar'),
-                         'session-instance')
+        self.assertEqual(
+            self.session.get_config_variable('foobar'), 'session-instance'
+        )
 
         # Back to default value.
         del self.environ['FOOBAR']
@@ -351,8 +365,7 @@ class TestSessionConfigurationVars(BaseSessionTest):
         value = self.session.get_config_variable('region')
         self.assertEqual(value, 'instance-var')
 
-        value = self.session.get_config_variable(
-            'region', methods=('env',))
+        value = self.session.get_config_variable('region', methods=('env',))
         self.assertEqual(value, 'env-var')
 
 
@@ -361,14 +374,16 @@ class TestSessionPartitionFiles(BaseSessionTest):
         mock_resolver = mock.Mock()
         mock_resolver.get_available_partitions.return_value = ['foo']
         self.session._register_internal_component(
-            'endpoint_resolver', mock_resolver)
+            'endpoint_resolver', mock_resolver
+        )
         self.assertEqual(['foo'], self.session.get_available_partitions())
 
     def test_proxies_list_endpoints_to_resolver(self):
         resolver = mock.Mock()
         resolver.get_available_endpoints.return_value = ['a', 'b']
         self.session._register_internal_component(
-            'endpoint_resolver', resolver)
+            'endpoint_resolver', resolver
+        )
         self.session.get_available_regions('foo', 'bar', True)
 
     def test_provides_empty_list_for_unknown_service_regions(self):
@@ -388,7 +403,8 @@ class TestSessionUserAgent(BaseSessionTest):
     def test_can_append_to_user_agent(self):
         self.session.user_agent_extra = 'custom-thing/other'
         self.assertTrue(
-            self.session.user_agent().endswith('custom-thing/other'))
+            self.session.user_agent().endswith('custom-thing/other')
+        )
 
     def test_execution_env_not_set(self):
         self.assertFalse(self.session.user_agent().endswith('FooEnv'))
@@ -424,9 +440,10 @@ class TestConfigLoaderObject(BaseSessionTest):
             session.set_config_variable('credentials_file', f.name)
             # Now trying to retrieve the scoped config should pull in
             # values from the shared credentials file.
-            self.assertEqual(session.get_scoped_config(),
-                             {'aws_access_key_id': 'a',
-                              'aws_secret_access_key': 'b'})
+            self.assertEqual(
+                session.get_scoped_config(),
+                {'aws_access_key_id': 'a', 'aws_secret_access_key': 'b'},
+            )
 
 
 class TestGetServiceModel(BaseSessionTest):
@@ -452,8 +469,7 @@ class TestGetPaginatorModel(BaseSessionTest):
         # Verify we get a PaginatorModel back
         self.assertIsInstance(model, PaginatorModel)
         # Verify we called the loader correctly.
-        loader.load_service_model.assert_called_with(
-            'foo', 'paginators-1')
+        loader.load_service_model.assert_called_with('foo', 'paginators-1')
 
 
 class TestGetWaiterModel(BaseSessionTest):
@@ -468,8 +484,7 @@ class TestGetWaiterModel(BaseSessionTest):
         self.assertIsInstance(model, WaiterModel)
         self.assertEqual(model.waiter_names, [])
         # and (2) call the loader correctly.
-        loader.load_service_model.assert_called_with(
-            'foo', 'waiters-2')
+        loader.load_service_model.assert_called_with('foo', 'waiters-2')
 
 
 class TestCreateClient(BaseSessionTest):
@@ -479,36 +494,40 @@ class TestCreateClient(BaseSessionTest):
 
     def test_credential_provider_not_called_when_creds_provided(self):
         cred_provider = mock.Mock()
-        self.session.register_component(
-            'credential_provider', cred_provider)
+        self.session.register_component('credential_provider', cred_provider)
         self.session.create_client(
-            'sts', 'us-west-2',
+            'sts',
+            'us-west-2',
             aws_access_key_id='foo',
             aws_secret_access_key='bar',
-            aws_session_token='baz')
-        self.assertFalse(cred_provider.load_credentials.called,
-                         "Credential provider was called even though "
-                         "explicit credentials were provided to the "
-                         "create_client call.")
+            aws_session_token='baz',
+        )
+        self.assertFalse(
+            cred_provider.load_credentials.called,
+            "Credential provider was called even though "
+            "explicit credentials were provided to the "
+            "create_client call.",
+        )
 
     def test_cred_provider_called_when_partial_creds_provided(self):
         with self.assertRaises(botocore.exceptions.PartialCredentialsError):
             self.session.create_client(
-                'sts', 'us-west-2',
+                'sts',
+                'us-west-2',
                 aws_access_key_id='foo',
-                aws_secret_access_key=None
+                aws_secret_access_key=None,
             )
         with self.assertRaises(botocore.exceptions.PartialCredentialsError):
             self.session.create_client(
-                'sts', 'us-west-2',
+                'sts',
+                'us-west-2',
                 aws_access_key_id=None,
                 aws_secret_access_key='foo',
             )
 
     def test_cred_provider_not_called_on_unsigned_client(self):
         cred_provider = mock.Mock()
-        self.session.register_component(
-            'credential_provider', cred_provider)
+        self.session.register_component('credential_provider', cred_provider)
         config = botocore.config.Config(signature_version=UNSIGNED)
         self.session.create_client('sts', 'us-west-2', config=config)
         self.assertFalse(cred_provider.load_credentials.called)
@@ -523,9 +542,16 @@ class TestCreateClient(BaseSessionTest):
         config = botocore.config.Config(region_name='us-west-2')
         self.session.create_client('sts', config=config)
         client_creator.return_value.create_client.assert_called_with(
-            service_name=mock.ANY, region_name=mock.ANY, is_secure=mock.ANY,
-            endpoint_url=mock.ANY, verify=mock.ANY, credentials=mock.ANY,
-            scoped_config=mock.ANY, client_config=config, auth_token=mock.ANY)
+            service_name=mock.ANY,
+            region_name=mock.ANY,
+            is_secure=mock.ANY,
+            endpoint_url=mock.ANY,
+            verify=mock.ANY,
+            credentials=mock.ANY,
+            scoped_config=mock.ANY,
+            client_config=config,
+            auth_token=mock.ANY,
+        )
 
     @mock.patch('botocore.client.ClientCreator')
     def test_create_client_with_default_client_config(self, client_creator):
@@ -534,9 +560,16 @@ class TestCreateClient(BaseSessionTest):
         self.session.create_client('sts')
 
         client_creator.return_value.create_client.assert_called_with(
-            service_name=mock.ANY, region_name=mock.ANY, is_secure=mock.ANY,
-            endpoint_url=mock.ANY, verify=mock.ANY, credentials=mock.ANY,
-            scoped_config=mock.ANY, client_config=config, auth_token=mock.ANY)
+            service_name=mock.ANY,
+            region_name=mock.ANY,
+            is_secure=mock.ANY,
+            endpoint_url=mock.ANY,
+            verify=mock.ANY,
+            credentials=mock.ANY,
+            scoped_config=mock.ANY,
+            client_config=config,
+            auth_token=mock.ANY,
+        )
 
     @mock.patch('botocore.client.ClientCreator')
     def test_create_client_with_merging_client_configs(self, client_creator):
@@ -548,7 +581,9 @@ class TestCreateClient(BaseSessionTest):
         # Grab the client config used in creating the client
         used_client_config = (
             client_creator.return_value.create_client.call_args[1][
-                'client_config'])
+                'client_config'
+            ]
+        )
         # Check that the client configs were merged
         self.assertEqual(used_client_config.region_name, 'us-east-1')
         # Make sure that the client config used is not the default client
@@ -557,15 +592,15 @@ class TestCreateClient(BaseSessionTest):
         self.assertIsNot(used_client_config, other_config)
 
     def test_create_client_with_region(self):
-        ec2_client = self.session.create_client(
-            'ec2', 'us-west-2')
+        ec2_client = self.session.create_client('ec2', 'us-west-2')
         self.assertEqual(ec2_client.meta.region_name, 'us-west-2')
 
     def test_create_client_with_region_and_client_config(self):
         config = botocore.config.Config()
         # Use a client config with no region configured.
         ec2_client = self.session.create_client(
-            'ec2', region_name='us-west-2', config=config)
+            'ec2', region_name='us-west-2', config=config
+        )
         self.assertEqual(ec2_client.meta.region_name, 'us-west-2')
 
         # If the region name is changed, it should not change the
@@ -574,8 +609,7 @@ class TestCreateClient(BaseSessionTest):
         self.assertEqual(ec2_client.meta.region_name, 'us-west-2')
 
         # Now make a new client with the updated client config.
-        ec2_client = self.session.create_client(
-            'ec2', config=config)
+        ec2_client = self.session.create_client('ec2', config=config)
         self.assertEqual(ec2_client.meta.region_name, 'us-east-1')
 
     def test_create_client_no_region_and_no_client_config(self):
@@ -592,8 +626,9 @@ class TestCreateClient(BaseSessionTest):
             f.flush()
 
             self.session.create_client('ec2', 'us-west-2')
-            call_kwargs = client_creator.return_value.\
-                create_client.call_args[1]
+            call_kwargs = client_creator.return_value.create_client.call_args[
+                1
+            ]
             self.assertEqual(call_kwargs['verify'], 'config-certs.pem')
 
     @mock.patch('botocore.client.ClientCreator')
@@ -606,7 +641,8 @@ class TestCreateClient(BaseSessionTest):
     @mock.patch('botocore.client.ClientCreator')
     def test_create_client_with_verify_param(self, client_creator):
         self.session.create_client(
-            'ec2', 'us-west-2', verify='verify-certs.pem')
+            'ec2', 'us-west-2', verify='verify-certs.pem'
+        )
         call_kwargs = client_creator.return_value.create_client.call_args[1]
         self.assertEqual(call_kwargs['verify'], 'verify-certs.pem')
 
@@ -625,64 +661,113 @@ class TestCreateClient(BaseSessionTest):
 
             # Set the ca cert using the verify parameter
             self.session.create_client(
-                'ec2', 'us-west-2', verify='verify-certs.pem')
-            call_kwargs = client_creator.return_value.\
-                create_client.call_args[1]
+                'ec2', 'us-west-2', verify='verify-certs.pem'
+            )
+            call_kwargs = client_creator.return_value.create_client.call_args[
+                1
+            ]
             # The verify parameter should override all the other
             # configurations
             self.assertEqual(call_kwargs['verify'], 'verify-certs.pem')
 
+    @mock.patch('botocore.client.ClientCreator')
+    def test_create_client_with_credentials(self, client_creator):
+        self.session.create_client(
+            'sts',
+            'us-west-2',
+            aws_access_key_id='foo',
+            aws_secret_access_key='bar',
+            aws_session_token='baz',
+            aws_account_id='bin',
+        )
+        credentials = (
+            client_creator.return_value.create_client.call_args.kwargs[
+                'credentials'
+            ]
+        )
+        self.assertEqual(credentials.access_key, 'foo')
+        self.assertEqual(credentials.secret_key, 'bar')
+        self.assertEqual(credentials.token, 'baz')
+        self.assertEqual(credentials.account_id, 'bin')
+
+    @mock.patch('botocore.client.ClientCreator')
+    def test_create_client_with_ignored_credentials(self, client_creator):
+        with self.assertLogs('botocore.session', level='DEBUG') as log:
+            self.session.create_client(
+                'sts',
+                'us-west-2',
+                aws_account_id='foo',
+            )
+            credentials = (
+                client_creator.return_value.create_client.call_args.kwargs[
+                    'credentials'
+                ]
+            )
+            self.assertIn(
+                'Ignoring the following credential-related values',
+                log.output[0],
+            )
+            self.assertIn('aws_account_id', log.output[0])
+            self.assertEqual(credentials.account_id, None)
+
 
 class TestSessionComponent(BaseSessionTest):
     def test_internal_component(self):
         component = object()
         self.session._register_internal_component('internal', component)
         self.assertIs(
-            self.session._get_internal_component('internal'), component)
+            self.session._get_internal_component('internal'), component
+        )
         with self.assertRaises(ValueError):
             self.session.get_component('internal')
 
     def test_internal_endpoint_resolver_is_same_as_deprecated_public(self):
         endpoint_resolver = self.session._get_internal_component(
-            'endpoint_resolver')
+            'endpoint_resolver'
+        )
         # get_component has been deprecated to the public
         with pytest.warns(DeprecationWarning):
             self.assertIs(
                 self.session.get_component('endpoint_resolver'),
-                endpoint_resolver
+                endpoint_resolver,
             )
 
     def test_internal_exceptions_factory_is_same_as_deprecated_public(self):
         exceptions_factory = self.session._get_internal_component(
-            'exceptions_factory')
+            'exceptions_factory'
+        )
         # get_component has been deprecated to the public
         with pytest.warns(DeprecationWarning):
             self.assertIs(
                 self.session.get_component('exceptions_factory'),
-                exceptions_factory
+                exceptions_factory,
             )
 
 
 class TestClientMonitoring(BaseSessionTest):
     def assert_created_client_is_monitored(self, session):
-        with mock.patch('botocore.monitoring.Monitor',
-                        spec=True) as mock_monitor:
+        with mock.patch(
+            'botocore.monitoring.Monitor', spec=True
+        ) as mock_monitor:
             client = session.create_client('ec2', 'us-west-2')
         mock_monitor.return_value.register.assert_called_with(
-            client.meta.events)
+            client.meta.events
+        )
 
     def assert_monitoring_host_and_port(self, session, host, port):
-        with mock.patch('botocore.monitoring.SocketPublisher',
-                        spec=True) as mock_publisher:
-            client = session.create_client('ec2', 'us-west-2')
+        with mock.patch(
+            'botocore.monitoring.SocketPublisher', spec=True
+        ) as mock_publisher:
+            session.create_client('ec2', 'us-west-2')
         self.assertEqual(mock_publisher.call_count, 1)
         _, args, kwargs = mock_publisher.mock_calls[0]
         self.assertEqual(kwargs.get('host'), host)
         self.assertEqual(kwargs.get('port'), port)
 
     def assert_created_client_is_not_monitored(self, session):
-        with mock.patch('botocore.session.monitoring.Monitor',
-                        spec=True) as mock_monitor:
+        with mock.patch(
+            'botocore.session.monitoring.Monitor', spec=True
+        ) as mock_monitor:
             session.create_client('ec2', 'us-west-2')
             mock_monitor.return_value.register.assert_not_called()
 
@@ -754,14 +839,20 @@ class TestComponentLocator(unittest.TestCase):
 
     def test_can_lazy_register_a_component(self):
         component = object()
-        lazy = lambda: component
+
+        def lazy():
+            return component
+
         self.components.lazy_register_component('foo', lazy)
         self.assertIs(self.components.get_component('foo'), component)
 
     def test_latest_registration_wins_even_if_lazy(self):
         first = object()
         second = object()
-        lazy_second = lambda: second
+
+        def lazy_second():
+            return second
+
         self.components.register_component('foo', first)
         self.components.lazy_register_component('foo', lazy_second)
         self.assertIs(self.components.get_component('foo'), second)
@@ -769,12 +860,17 @@ class TestComponentLocator(unittest.TestCase):
     def test_latest_registration_overrides_lazy(self):
         first = object()
         second = object()
-        lazy_first = lambda: first
+
+        def lazy_first():
+            return first
+
         self.components.lazy_register_component('foo', lazy_first)
         self.components.register_component('foo', second)
         self.assertIs(self.components.get_component('foo'), second)
 
-    def test_lazy_registration_factory_does_not_remove_from_list_on_error(self):
+    def test_lazy_registration_factory_does_not_remove_from_list_on_error(
+        self,
+    ):
         class ArbitraryError(Exception):
             pass
 
@@ -815,7 +911,7 @@ class TestSessionRegionSetup(BaseSessionTest):
 
     def test_new_session_with_invalid_region(self):
         with self.assertRaises(botocore.exceptions.InvalidRegionError):
-            s3_client = self.session.create_client('s3', 'not.a.real#region')
+            self.session.create_client('s3', 'not.a.real#region')
 
     def test_new_session_with_none_region(self):
         s3_client = self.session.create_client('s3', region_name=None)
