@@ -12,18 +12,18 @@
 # language governing permissions and limitations under the License.
 
 import os
-import mock
 
-from . import FakeSession
-from awscli.testutils import unittest
-from awscli.compat import six
+from awscli.compat import StringIO
 from awscli.customizations.configure.importer import (
-    CredentialImporter,
     ConfigureImportCommand,
-    CSVCredentialParser,
+    CredentialImporter,
     CredentialParserError,
+    CSVCredentialParser,
 )
 from awscli.customizations.configure.writer import ConfigFileWriter
+from awscli.testutils import mock, unittest
+
+from . import FakeSession
 
 CSV_HEADERS = (
     'User name,Password,Access key ID,Secret access key,Console login link\n'
@@ -34,11 +34,12 @@ class TestConfigureImportCommand(unittest.TestCase):
     def setUp(self):
         self.session = FakeSession({'config_file': 'myconfigfile'})
         self.fake_credentials_filename = os.path.expanduser(
-            '~/fake_credentials_filename')
+            '~/fake_credentials_filename'
+        )
         self.session.profile = None
         self.mock_writer = mock.Mock(spec=ConfigFileWriter)
         self.importer = CredentialImporter(self.mock_writer)
-        self.stdout = six.StringIO()
+        self.stdout = StringIO()
         self.import_command = ConfigureImportCommand(
             self.session,
             importer=self.importer,
@@ -50,7 +51,9 @@ class TestConfigureImportCommand(unittest.TestCase):
         update_args, _ = self.mock_writer.update_config.call_args
         self.assertEqual(update_args[0], profile)
         self.assertIn('/fake_credentials_filename', update_args[1])
-        self.assertIn('Successfully imported 1 profile', self.stdout.getvalue())
+        self.assertIn(
+            'Successfully imported 1 profile', self.stdout.getvalue()
+        )
 
     def test_import_downloaded_csv(self):
         row = 'PROFILENAME,PW,AKID,SAK,https://console.link\n'
@@ -81,13 +84,40 @@ class TestConfigureImportCommand(unittest.TestCase):
         )
         self.import_command(args=['--csv', content], parsed_globals=None)
         self.assertEqual(self.mock_writer.update_config.call_count, 2)
-        self.assertIn('Successfully imported 2 profile', self.stdout.getvalue())
+        self.assertIn(
+            'Successfully imported 2 profile', self.stdout.getvalue()
+        )
 
     def test_import_downloaded_bad_headers(self):
         content = 'User name,Secret access key\n'
         with self.assertRaises(CredentialParserError):
             self.import_command(args=['--csv', content], parsed_globals=None)
 
+    def test_raises_error_when_plain_file_path_passed(self):
+        with open('temp_creds.csv', 'w') as f:
+            f.write('User name,Access key ID,Secret access key\nuser,AKID,SAK')
+        try:
+            with self.assertRaises(ValueError) as cm:
+                self.import_command(args=['--csv', 'temp_creds.csv'], parsed_globals=None)
+            self.assertIn("without the 'file://' prefix", str(cm.exception))
+        finally:
+            os.remove('temp_creds.csv')
+
+    def test_inline_csv_succeeds(self):
+        csv_string = 'User name,Access key ID,Secret access key\nuser,AKID,SAK'
+        self.import_command(args=['--csv', csv_string], parsed_globals=None)
+        self.assertIn('Successfully imported 1 profile', self.stdout.getvalue())
+
+    def test_csv_content_from_file_succeeds(self):
+        with open('temp_creds.csv', 'w') as f:
+            f.write('User name,Access key ID,Secret access key\nuser,AKID,SAK')
+        try:
+            with open('temp_creds.csv', 'r') as f:
+                contents = f.read()
+            self.import_command(args=['--csv', contents], parsed_globals=None)
+            self.assertIn('Successfully imported 1 profile', self.stdout.getvalue())
+        finally:
+            os.remove('temp_creds.csv')
 
 class TestCSVCredentialParser(unittest.TestCase):
     def setUp(self):
@@ -111,7 +141,7 @@ class TestCSVCredentialParser(unittest.TestCase):
 
     def test_csv_parser_with_bom(self):
         contents = (
-            u'\ufeffUser name,Access key ID,Secret access key\n'
+            '\ufeffUser name,Access key ID,Secret access key\n'
             'PROFILENAME,AKID,SAK\n'
         )
         self.assert_parse_matches_expected(contents)
@@ -130,7 +160,7 @@ class TestCSVCredentialParser(unittest.TestCase):
 
     def test_csv_parser_multiple_entries_bom(self):
         contents = (
-            u'\ufeffUser name,Access key ID,Secret access key\n'
+            '\ufeffUser name,Access key ID,Secret access key\n'
             'PROFILENAME1,AKID1,SAK1\n'
             'PROFILENAME2,AKID2,SAK2\n'
         )
