@@ -11,8 +11,8 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-from awscli.testutils import unittest
 from awscli.customizations.emr.createdefaultroles import assume_role_policy
+from awscli.testutils import unittest
 
 
 class TestDefaultRoles(unittest.TestCase):
@@ -24,9 +24,9 @@ class TestDefaultRoles(unittest.TestCase):
                 "Sid": "",
                 "Effect": "Allow",
                 "Principal": {"Service": "ec2.amazonaws.com"},
-                "Action": "sts:AssumeRole"
+                "Action": "sts:AssumeRole",
             }
-        ]
+        ],
     }
 
     def test_assume_role_policy(self):
