@@ -14,9 +14,9 @@
 import json
 
 from awscli.testutils import mock
-
-from tests.unit.customizations.emr import EMRBaseAWSCommandParamsTest as \
-    BaseAWSCommandParamsTest
+from tests.unit.customizations.emr import (
+    EMRBaseAWSCommandParamsTest as BaseAWSCommandParamsTest,
+)
 
 describe_cluster_result_mock_ig = {
     "Cluster": {
@@ -24,37 +24,32 @@ describe_cluster_result_mock_ig = {
             "Timeline": {
                 "ReadyDateTime": 1398376089.0,
                 "EndDateTime": 1398376477.0,
-                "CreationDateTime": 1398375871.0
+                "CreationDateTime": 1398375871.0,
             },
             "State": "TERMINATED",
             "StateChangeReason": {
                 "Message": "Terminated by user request",
-                "Code": "USER_REQUEST"
-            }
+                "Code": "USER_REQUEST",
+            },
         },
         "Ec2InstanceAttributes": {
             "IamInstanceProfile": "EMR_EC2_DefaultRole",
-            "Ec2AvailabilityZone": "us-east-1b"
+            "Ec2AvailabilityZone": "us-east-1b",
         },
         "InstanceCollectionType": "INSTANCE_GROUP",
         "Name": "ABCD",
         "Tags": [],
         "TerminationProtected": "false",
         "RunningAmiVersion": "2.4.2",
-        "Applications": [
-            {
-                "Version": "1.0.3",
-                "Name": "hadoop"
-            }
-        ],
+        "Applications": [{"Version": "1.0.3", "Name": "hadoop"}],
         "VisibleToAllUsers": "true",
         "RequestedAmiVersion": "2.4.2",
         "LogUri": "s3n://abc/logs/",
         "AutoTerminate": "false",
         "Id": "j-ABCD",
-        "MasterPublicDnsName": "ec2-01-01-1-188.compute-1.amazonaws.com"
-        }
+        "MasterPublicDnsName": "ec2-01-01-1-188.compute-1.amazonaws.com",
     }
+}
 
 describe_cluster_result_mock_if = {
     "Cluster": {
@@ -62,42 +57,35 @@ describe_cluster_result_mock_if = {
             "Timeline": {
                 "ReadyDateTime": 1398376089.0,
                 "EndDateTime": 1398376477.0,
-                "CreationDateTime": 1398375871.0
+                "CreationDateTime": 1398375871.0,
             },
             "State": "TERMINATED",
             "StateChangeReason": {
                 "Message": "Terminated by user request",
-                "Code": "USER_REQUEST"
-            }
+                "Code": "USER_REQUEST",
+            },
         },
         "Ec2InstanceAttributes": {
             "IamInstanceProfile": "EMR_EC2_DefaultRole",
-            "Ec2AvailabilityZone": "us-east-1b"
+            "Ec2AvailabilityZone": "us-east-1b",
         },
         "InstanceCollectionType": "INSTANCE_FLEET",
         "Name": "ABCD",
         "Tags": [],
         "TerminationProtected": "false",
         "RunningAmiVersion": "2.4.2",
-        "Applications": [
-            {
-                "Version": "1.0.3",
-                "Name": "hadoop"
-            }
-        ],
+        "Applications": [{"Version": "1.0.3", "Name": "hadoop"}],
         "VisibleToAllUsers": "true",
         "RequestedAmiVersion": "2.4.2",
         "LogUri": "s3n://abc/logs/",
         "AutoTerminate": "false",
         "Id": "j-ABCD",
-        "MasterPublicDnsName": "ec2-01-01-1-188.compute-1.amazonaws.com"
-        }
+        "MasterPublicDnsName": "ec2-01-01-1-188.compute-1.amazonaws.com",
     }
+}
 
 list_instance_groups_result_mock = {
-    "ResponseMetadata": {
-        "RequestId": '12ec323c-50b1-11e4-b653-afa4228d882f'
-    },
+    "ResponseMetadata": {"RequestId": '12ec323c-50b1-11e4-b653-afa4228d882f'},
     "InstanceGroups": [
         {
             "RequestedInstanceCount": 1,
@@ -105,13 +93,13 @@ list_instance_groups_result_mock = {
                 "Timeline": {
                     "ReadyDateTime": 1398376083.0,
                     "EndDateTime": 1398376476.0,
-                    "CreationDateTime": 1398375871.0
+                    "CreationDateTime": 1398375871.0,
                 },
                 "State": "TERMINATED",
                 "StateChangeReason": {
                     "Message": "Job flow terminated",
-                    "Code": "CLUSTER_TERMINATED"
-                }
+                    "Code": "CLUSTER_TERMINATED",
+                },
             },
             "Name": "Master instance group",
             "InstanceGroupType": "MASTER",
@@ -119,7 +107,7 @@ list_instance_groups_result_mock = {
             "CustomAmiId": "ami-deadbeef",
             "Id": "ig-ABCD",
             "Market": "ON_DEMAND",
-            "RunningInstanceCount": 0
+            "RunningInstanceCount": 0,
         },
         {
             "RequestedInstanceCount": 2,
@@ -127,13 +115,13 @@ list_instance_groups_result_mock = {
                 "Timeline": {
                     "ReadyDateTime": 1398376089.0,
                     "EndDateTime": 1398376476.0,
-                    "CreationDateTime": 1398375871.0
+                    "CreationDateTime": 1398375871.0,
                 },
                 "State": "TERMINATED",
                 "StateChangeReason": {
                     "Message": "Job flow terminated",
-                    "Code": "CLUSTER_TERMINATED"
-                }
+                    "Code": "CLUSTER_TERMINATED",
+                },
             },
             "Name": "Core instance group",
             "InstanceGroupType": "CORE",
@@ -141,15 +129,13 @@ list_instance_groups_result_mock = {
             "CustomAmiId": "ami-deadpork",
             "Id": "ig-DEF",
             "Market": "ON_DEMAND",
-            "RunningInstanceCount": 0
-        }
-    ]
+            "RunningInstanceCount": 0,
+        },
+    ],
 }
 
 list_instance_fleets_result_mock = {
-    "ResponseMetadata": {
-        "RequestId": '12ec323c-50b1-11e4-b653-afa4228d882f'
-    },
+    "ResponseMetadata": {"RequestId": '12ec323c-50b1-11e4-b653-afa4228d882f'},
     "InstanceFleets": [
         {
             "TargetSpotCapacity": 0,
@@ -160,13 +146,13 @@ list_instance_fleets_result_mock = {
                 "Timeline": {
                     "ReadyDateTime": 1398376083.0,
                     "EndDateTime": 1398376476.0,
-                    "CreationDateTime": 1398375871.0
+                    "CreationDateTime": 1398375871.0,
                 },
                 "State": "TERMINATED",
                 "StateChangeReason": {
                     "Message": "Job flow terminated",
-                    "Code": "CLUSTER_TERMINATED"
-                }
+                    "Code": "CLUSTER_TERMINATED",
+                },
             },
             "InstanceTypeSpecifications": [
                 {
@@ -174,50 +160,56 @@ list_instance_fleets_result_mock = {
                     "BidPrice": "1",
                     "InstanceType": "m3.xlarge",
                     "CustomAmiId": "ami-deadbeef",
-                    "BidPriceAsPercentageOfOnDemandPrice": 0.0
+                    "BidPriceAsPercentageOfOnDemandPrice": 0.0,
                 }
             ],
-            "LaunchSpecifications" : {
-                "SpotSpecification": {"TimeoutDurationMinutes": 77, "TimeoutAction": "TERMINATE_CLUSTER",
-                                        "AllocationStrategy": "capacity-optimized-prioritized"},
-                "OnDemandSpecification": {"AllocationStrategy": "lowest-price"}
+            "LaunchSpecifications": {
+                "SpotSpecification": {
+                    "TimeoutDurationMinutes": 77,
+                    "TimeoutAction": "TERMINATE_CLUSTER",
+                    "AllocationStrategy": "capacity-optimized-prioritized",
+                },
+                "OnDemandSpecification": {
+                    "AllocationStrategy": "lowest-price"
+                },
             },
             "ResizeSpecifications": {
-                "OnDemandResizeSpecification": {"AllocationStrategy": "lowest-price",
+                "OnDemandResizeSpecification": {
+                    "AllocationStrategy": "lowest-price",
                     "CapacityReservationOptions": {
                         "CapacityReservationPreference": "open",
-                        "UsageStrategy": "use-capacity-reservations-first"
-                    }
+                        "UsageStrategy": "use-capacity-reservations-first",
+                    },
+                },
+                "SpotResizeSpecification": {
+                    "AllocationStrategy": "capacity-optimized"
                 },
-                "SpotResizeSpecification": {"AllocationStrategy": "capacity-optimized"}
             },
             "Name": "Master instance group",
             "InstanceFleetType": "MASTER",
             "InstanceType": "m1.large",
             "Id": "if-ABCD",
-            "Context": "testContext"
+            "Context": "testContext",
         }
-    ]
+    ],
 }
 
 list_bootstrap_actions_result_mock = {
-    "ResponseMetadata": {
-        "RequestId": '12ec323c-50b1-11e4-b653-afa4228d882f'
-    },
+    "ResponseMetadata": {"RequestId": '12ec323c-50b1-11e4-b653-afa4228d882f'},
     "BootstrapActions": [
         {
             "Args": [],
             "Name": "Install HBase",
-            "ScriptPath": "s3://elasticmapreduce/bootstrap-actions/setup-hbase"
+            "ScriptPath": "s3://elasticmapreduce/bootstrap-actions/setup-hbase",
         }
-    ]
+    ],
 }
 
 EXPECTED_RESULT_IG = {
     "Cluster": {
         "Ec2InstanceAttributes": {
             "IamInstanceProfile": "EMR_EC2_DefaultRole",
-            "Ec2AvailabilityZone": "us-east-1b"
+            "Ec2AvailabilityZone": "us-east-1b",
         },
         "InstanceCollectionType": "INSTANCE_GROUP",
         "Name": "ABCD",
@@ -231,13 +223,13 @@ EXPECTED_RESULT_IG = {
                     "Timeline": {
                         "ReadyDateTime": 1398376083.0,
                         "CreationDateTime": 1398375871.0,
-                        "EndDateTime": 1398376476.0
+                        "EndDateTime": 1398376476.0,
                     },
                     "State": "TERMINATED",
                     "StateChangeReason": {
                         "Message": "Job flow terminated",
-                        "Code": "CLUSTER_TERMINATED"
-                    }
+                        "Code": "CLUSTER_TERMINATED",
+                    },
                 },
                 "RunningInstanceCount": 0,
                 "Name": "Master instance group",
@@ -245,7 +237,7 @@ EXPECTED_RESULT_IG = {
                 "InstanceType": "m1.large",
                 "CustomAmiId": "ami-deadbeef",
                 "Market": "ON_DEMAND",
-                "Id": "ig-ABCD"
+                "Id": "ig-ABCD",
             },
             {
                 "RequestedInstanceCount": 2,
@@ -253,13 +245,13 @@ EXPECTED_RESULT_IG = {
                     "Timeline": {
                         "ReadyDateTime": 1398376089.0,
                         "CreationDateTime": 1398375871.0,
-                        "EndDateTime": 1398376476.0
+                        "EndDateTime": 1398376476.0,
                     },
                     "State": "TERMINATED",
                     "StateChangeReason": {
                         "Message": "Job flow terminated",
-                        "Code": "CLUSTER_TERMINATED"
-                    }
+                        "Code": "CLUSTER_TERMINATED",
+                    },
                 },
                 "RunningInstanceCount": 0,
                 "Name": "Core instance group",
@@ -267,8 +259,8 @@ EXPECTED_RESULT_IG = {
                 "InstanceType": "m1.large",
                 "CustomAmiId": "ami-deadpork",
                 "Market": "ON_DEMAND",
-                "Id": "ig-DEF"
-            }
+                "Id": "ig-DEF",
+            },
         ],
         "RequestedAmiVersion": "2.4.2",
         "AutoTerminate": "false",
@@ -277,31 +269,26 @@ EXPECTED_RESULT_IG = {
             "Timeline": {
                 "ReadyDateTime": 1398376089.0,
                 "CreationDateTime": 1398375871.0,
-                "EndDateTime": 1398376477.0
+                "EndDateTime": 1398376477.0,
             },
             "State": "TERMINATED",
             "StateChangeReason": {
                 "Message": "Terminated by user request",
-                "Code": "USER_REQUEST"
-            }
+                "Code": "USER_REQUEST",
+            },
         },
         "Tags": [],
-        "Applications": [
-            {
-                "Version": "1.0.3",
-                "Name": "hadoop"
-            }
-        ],
+        "Applications": [{"Version": "1.0.3", "Name": "hadoop"}],
         "VisibleToAllUsers": "true",
         "BootstrapActions": [
             {
                 "Args": [],
                 "Name": "Install HBase",
                 "ScriptPath": "s3://elasticmapreduce/bootstrap-actions/"
-                              "setup-hbase"
+                "setup-hbase",
             }
         ],
-        "Id": "j-ABCD"
+        "Id": "j-ABCD",
     }
 }
 
@@ -309,7 +296,7 @@ EXPECTED_RESULT_IF = {
     "Cluster": {
         "Ec2InstanceAttributes": {
             "IamInstanceProfile": "EMR_EC2_DefaultRole",
-            "Ec2AvailabilityZone": "us-east-1b"
+            "Ec2AvailabilityZone": "us-east-1b",
         },
         "InstanceCollectionType": "INSTANCE_FLEET",
         "Name": "ABCD",
@@ -326,13 +313,13 @@ EXPECTED_RESULT_IF = {
                     "Timeline": {
                         "ReadyDateTime": 1398376083.0,
                         "EndDateTime": 1398376476.0,
-                        "CreationDateTime": 1398375871.0
+                        "CreationDateTime": 1398375871.0,
                     },
                     "State": "TERMINATED",
                     "StateChangeReason": {
                         "Message": "Job flow terminated",
-                        "Code": "CLUSTER_TERMINATED"
-                    }
+                        "Code": "CLUSTER_TERMINATED",
+                    },
                 },
                 "InstanceTypeSpecifications": [
                     {
@@ -340,28 +327,36 @@ EXPECTED_RESULT_IF = {
                         "BidPrice": "1",
                         "InstanceType": "m3.xlarge",
                         "CustomAmiId": "ami-deadbeef",
-                        "BidPriceAsPercentageOfOnDemandPrice": 0.0
+                        "BidPriceAsPercentageOfOnDemandPrice": 0.0,
                     }
                 ],
-                "LaunchSpecifications" : {
-                    "SpotSpecification": {"TimeoutDurationMinutes": 77, "TimeoutAction": "TERMINATE_CLUSTER",
-                                          "AllocationStrategy": "capacity-optimized-prioritized"},
-                    "OnDemandSpecification": {"AllocationStrategy": "lowest-price"}
+                "LaunchSpecifications": {
+                    "SpotSpecification": {
+                        "TimeoutDurationMinutes": 77,
+                        "TimeoutAction": "TERMINATE_CLUSTER",
+                        "AllocationStrategy": "capacity-optimized-prioritized",
+                    },
+                    "OnDemandSpecification": {
+                        "AllocationStrategy": "lowest-price"
+                    },
                 },
                 "ResizeSpecifications": {
-                    "OnDemandResizeSpecification": {"AllocationStrategy": "lowest-price",
+                    "OnDemandResizeSpecification": {
+                        "AllocationStrategy": "lowest-price",
                         "CapacityReservationOptions": {
                             "CapacityReservationPreference": "open",
-                            "UsageStrategy": "use-capacity-reservations-first"
-                        }
+                            "UsageStrategy": "use-capacity-reservations-first",
+                        },
+                    },
+                    "SpotResizeSpecification": {
+                        "AllocationStrategy": "capacity-optimized"
                     },
-                    "SpotResizeSpecification": {"AllocationStrategy": "capacity-optimized"}
                 },
                 "Name": "Master instance group",
                 "InstanceFleetType": "MASTER",
                 "InstanceType": "m1.large",
                 "Id": "if-ABCD",
-                "Context": "testContext"
+                "Context": "testContext",
             }
         ],
         "RequestedAmiVersion": "2.4.2",
@@ -371,38 +366,36 @@ EXPECTED_RESULT_IF = {
             "Timeline": {
                 "ReadyDateTime": 1398376089.0,
                 "CreationDateTime": 1398375871.0,
-                "EndDateTime": 1398376477.0
+                "EndDateTime": 1398376477.0,
             },
             "State": "TERMINATED",
             "StateChangeReason": {
                 "Message": "Terminated by user request",
-                "Code": "USER_REQUEST"
-            }
+                "Code": "USER_REQUEST",
+            },
         },
         "Tags": [],
-        "Applications": [
-            {
-                "Version": "1.0.3",
-                "Name": "hadoop"
-            }
-        ],
+        "Applications": [{"Version": "1.0.3", "Name": "hadoop"}],
         "VisibleToAllUsers": "true",
         "BootstrapActions": [
             {
                 "Args": [],
                 "Name": "Install HBase",
                 "ScriptPath": "s3://elasticmapreduce/bootstrap-actions/"
-                              "setup-hbase"
+                "setup-hbase",
             }
         ],
-        "Id": "j-ABCD"
+        "Id": "j-ABCD",
     }
 }
 
+
 class TestDescribeCluster(BaseAWSCommandParamsTest):
     prefix = 'emr describe-cluster'
 
-    @mock.patch('awscli.customizations.emr.emr.DescribeCluster._construct_result')
+    @mock.patch(
+        'awscli.customizations.emr.emr.DescribeCluster._construct_result'
+    )
     def test_operations_called(self, construct_result_patch):
         construct_result_patch.return_value = dict()
 
@@ -412,19 +405,17 @@ class TestDescribeCluster(BaseAWSCommandParamsTest):
         self.run_cmd(cmdline, expected_rc=0)
 
         self.assertEqual(len(self.operations_called), 3)
-        self.assertEqual(self.operations_called[0][0].name,
-                         'DescribeCluster')
-        self.assertEqual(self.operations_called[0][1]['ClusterId'],
-                         'j-ABCD')
-        self.assertEqual(self.operations_called[1][0].name,
-                         'ListInstanceGroups')
-        self.assertEqual(self.operations_called[1][1]['ClusterId'],
-                         'j-ABCD')
+        self.assertEqual(self.operations_called[0][0].name, 'DescribeCluster')
+        self.assertEqual(self.operations_called[0][1]['ClusterId'], 'j-ABCD')
+        self.assertEqual(
+            self.operations_called[1][0].name, 'ListInstanceGroups'
+        )
+        self.assertEqual(self.operations_called[1][1]['ClusterId'], 'j-ABCD')
 
-        self.assertEqual(self.operations_called[2][0].name,
-                         'ListBootstrapActions')
-        self.assertEqual(self.operations_called[2][1]['ClusterId'],
-                         'j-ABCD')
+        self.assertEqual(
+            self.operations_called[2][0].name, 'ListBootstrapActions'
+        )
+        self.assertEqual(self.operations_called[2][1]['ClusterId'], 'j-ABCD')
 
     @mock.patch('awscli.customizations.emr.emr.DescribeCluster._call')
     def test_constructed_result_ig(self, call_patch):
@@ -446,6 +437,7 @@ class TestDescribeCluster(BaseAWSCommandParamsTest):
         result_json = json.loads(result[0])
         self.assertEqual(result_json, EXPECTED_RESULT_IF)
 
+
 def side_effect_of_call_ig(*args, **kwargs):
     if args[1] == 'describe_cluster':
         return describe_cluster_result_mock_ig
@@ -456,6 +448,7 @@ def side_effect_of_call_ig(*args, **kwargs):
     elif args[1] == 'list_bootstrap_actions':
         return list_bootstrap_actions_result_mock
 
+
 def side_effect_of_call_if(*args, **kwargs):
     if args[1] == 'describe_cluster':
         return describe_cluster_result_mock_if
@@ -466,5 +459,6 @@ def side_effect_of_call_if(*args, **kwargs):
     elif args[1] == 'list_bootstrap_actions':
         return list_bootstrap_actions_result_mock
 
+
 if __name__ == "__main__":
     unittest.main()
