@@ -11,29 +11,32 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-from awscli.testutils import mock
-
-from tests.unit.customizations.emr import EMRBaseAWSCommandParamsTest as \
-    BaseAWSCommandParamsTest
 from copy import deepcopy
 
+from awscli.testutils import mock
+from tests.unit.customizations.emr import (
+    EMRBaseAWSCommandParamsTest as BaseAWSCommandParamsTest,
+)
+
 
 class TestDisableHBaseBackups(BaseAWSCommandParamsTest):
     prefix = 'emr disable-hbase-backups'
     DISABLE_FULL_BACKUP = '--disable-full-backups'
     DISABLE_INCR_BACKUP = '--disable-incremental-backups'
-    default_steps = [{
-        'HadoopJarStep': {
-            'Args': [
-                'emr.hbase.backup.Main',
-                '--set-scheduled-backup',
-                'false'
-            ],
-            'Jar': '/home/hadoop/lib/hbase.jar'
-        },
-        'Name': 'Modify Backup Schedule',
-        'ActionOnFailure': 'CANCEL_AND_WAIT'
-    }]
+    default_steps = [
+        {
+            'HadoopJarStep': {
+                'Args': [
+                    'emr.hbase.backup.Main',
+                    '--set-scheduled-backup',
+                    'false',
+                ],
+                'Jar': '/home/hadoop/lib/hbase.jar',
+            },
+            'Name': 'Modify Backup Schedule',
+            'ActionOnFailure': 'CANCEL_AND_WAIT',
+        }
+    ]
 
     def test_disable_hbase_backups_full(self):
         args = ' --cluster-id j-ABCD --full'
@@ -69,24 +72,28 @@ class TestDisableHBaseBackups(BaseAWSCommandParamsTest):
     def test_disable_hbase_backups_none(self):
         args = ' --cluster-id j-ABCD'
         cmdline = self.prefix + args
-        expected_error_msg = '\nShould specify at least one of --full' +\
-                             ' and --incremental.\n'
+        expected_error_msg = (
+            '\nShould specify at least one of --full' + ' and --incremental.\n'
+        )
         result = self.run_cmd(cmdline, 252)
 
         self.assertEqual(expected_error_msg, result[1])
 
-    @mock.patch('awscli.customizations.emr.'
-                'emrutils.get_release_label')
+    @mock.patch('awscli.customizations.emr.' 'emrutils.get_release_label')
     def test_unsupported_command_on_release_based_cluster_error(
-            self, grl_patch):
+        self, grl_patch
+    ):
         grl_patch.return_value = 'emr-4.0'
         args = ' --cluster-id j-ABCD --full'
         cmdline = self.prefix + args
-        expected_error_msg = ("\naws: error: disable-hbase-backups"
-                              " is not supported with 'emr-4.0' release.\n")
+        expected_error_msg = (
+            "\naws: error: disable-hbase-backups"
+            " is not supported with 'emr-4.0' release.\n"
+        )
         result = self.run_cmd(cmdline, 252)
 
         self.assertEqual(result[1], expected_error_msg)
 
+
 if __name__ == "__main__":
     unittest.main()
