@@ -10,43 +10,44 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-from awscli.testutils import mock, unittest
-from datetime import datetime, timedelta
 import time
+from datetime import datetime, timedelta
 
-from dateutil import tz
 from botocore.session import Session
 from botocore.stub import Stubber
+from dateutil import tz
 
 from awscli.compat import StringIO
-from awscli.customizations.logs.tail import ShortLogEventsFormatter
-from awscli.customizations.logs.tail import PrettyJSONLogEventsFormatter
-from awscli.customizations.logs.tail import DetailedLogEventsFormatter
-from awscli.customizations.logs.tail import TimestampUtils
-from awscli.customizations.logs.tail import NoFollowLogEventsGenerator
-from awscli.customizations.logs.tail import FollowLogEventsGenerator
+from awscli.customizations.logs.tail import (
+    DetailedLogEventsFormatter,
+    FollowLogEventsGenerator,
+    NoFollowLogEventsGenerator,
+    PrettyJSONLogEventsFormatter,
+    ShortLogEventsFormatter,
+    TimestampUtils,
+)
+from awscli.testutils import mock, unittest
 
 
 class BaseLogEventsFormatterTest(unittest.TestCase):
-
     FORMATTER_CLS = None
 
     def setUp(self):
         self.log_event = {
             'timestamp': datetime(2018, 1, 1, 0, 29, 43, 79060, tz.tzutc()),
             'logStreamName': 'stream_name',
-            'message': 'my message'
+            'message': 'my message',
         }
         self.output = StringIO()
 
     def assert_formatted_display(self, expected_msg, **init_kwargs):
         self.FORMATTER_CLS(self.output, **init_kwargs).display_log_event(
-            self.log_event)
+            self.log_event
+        )
         self.assertEqual(expected_msg, self.output.getvalue())
 
 
 class TestShortLogEventsFormatter(BaseLogEventsFormatterTest):
-
     FORMATTER_CLS = ShortLogEventsFormatter
 
     def test_display(self):
@@ -63,20 +64,17 @@ class TestShortLogEventsFormatter(BaseLogEventsFormatterTest):
     def test_ensures_single_newline_ending(self):
         self.log_event['message'] = self.log_event['message'] + '\n\n'
         self.assert_formatted_display(
-            '2018-01-01T00:29:43 my message\n',
-            colorize=False
+            '2018-01-01T00:29:43 my message\n', colorize=False
         )
 
     def test_handles_unicode(self):
         self.log_event['message'] = self.log_event['message'] + '\u00e9'
         self.assert_formatted_display(
-            '2018-01-01T00:29:43 my message\u00e9\n',
-            colorize=False
+            '2018-01-01T00:29:43 my message\u00e9\n', colorize=False
         )
 
 
 class TestPrettyJSONLogEventsFormatter(BaseLogEventsFormatterTest):
-
     FORMATTER_CLS = PrettyJSONLogEventsFormatter
 
     def test_no_json_is_same_as_detailed_output(self):
@@ -102,7 +100,6 @@ class TestPrettyJSONLogEventsFormatter(BaseLogEventsFormatterTest):
 
 
 class TestDetailedLogEventsFormatter(BaseLogEventsFormatterTest):
-
     FORMATTER_CLS = DetailedLogEventsFormatter
 
     def test_display(self):
@@ -134,14 +131,17 @@ class TestDetailedLogEventsFormatter(BaseLogEventsFormatterTest):
 
     def test_display_with_zero_microseconds(self):
         self.log_event['timestamp'] = datetime(
-            2018, 1, 1, 0, 29, 43, 0, tz.tzutc())
-        DetailedLogEventsFormatter(
-            self.output).display_log_event(self.log_event)
+            2018, 1, 1, 0, 29, 43, 0, tz.tzutc()
+        )
+        DetailedLogEventsFormatter(self.output).display_log_event(
+            self.log_event
+        )
         self.assertEqual(
             '\x1b[32m2018-01-01T00:29:43.000000+00:00\x1b[0m '
             '\x1b[36mstream_name\x1b[0m '
             'my message\n',
-            self.output.getvalue())
+            self.output.getvalue(),
+        )
 
 
 class TestTimestampUtils(unittest.TestCase):
@@ -152,20 +152,22 @@ class TestTimestampUtils(unittest.TestCase):
 
     def set_now(self, year=1970, month=1, day=1, hour=0, minute=0, sec=0):
         self.now = datetime(
-            year, month, day, hour, minute, sec, tzinfo=tz.tzutc())
+            year, month, day, hour, minute, sec, tzinfo=tz.tzutc()
+        )
         self.mock_now.return_value = self.now
 
     def test_to_epoch_absolute_timezone_unaware(self):
         self.assertEqual(
             self.timestamp_utils.to_epoch_millis('1970-01-01T00:00:01.000000'),
-            1000
+            1000,
         )
 
     def test_to_epoch_absolute_timezone_aware(self):
         self.assertEqual(
             self.timestamp_utils.to_epoch_millis(
-                '1970-01-01T00:00:01.000000-01:00'),
-            3601000
+                '1970-01-01T00:00:01.000000-01:00'
+            ),
+            3601000,
         )
 
     def test_to_epoch_relative_second(self):
@@ -178,9 +180,7 @@ class TestTimestampUtils(unittest.TestCase):
 
     def test_to_epoch_relative_minute(self):
         self.set_now(minute=2)
-        self.assertEqual(
-            self.timestamp_utils.to_epoch_millis('1m'), 60 * 1000
-        )
+        self.assertEqual(self.timestamp_utils.to_epoch_millis('1m'), 60 * 1000)
 
     def test_to_epoch_relative_hour(self):
         self.set_now(hour=2)
@@ -192,20 +192,20 @@ class TestTimestampUtils(unittest.TestCase):
         self.set_now(day=3)  # 1970-01-03
         self.assertEqual(
             self.timestamp_utils.to_epoch_millis('1d'),
-            (24 * 60 * 60) * 1000  # 1970-01-02
+            (24 * 60 * 60) * 1000,  # 1970-01-02
         )
 
     def test_to_epoch_relative_week(self):
         self.set_now(day=9)  # 1970-01-08
         self.assertEqual(
             self.timestamp_utils.to_epoch_millis('1w'),
-            (24 * 60 * 60) * 1000  # 1970-01-02
+            (24 * 60 * 60) * 1000,  # 1970-01-02
         )
 
     def test_to_datetime(self):
         self.assertEqual(
             self.timestamp_utils.to_datetime(1000),
-            datetime(1970, 1, 1, 0, 0, 1, tzinfo=tz.tzutc())
+            datetime(1970, 1, 1, 0, 0, 1, tzinfo=tz.tzutc()),
         )
 
 
@@ -213,7 +213,8 @@ class BaseLogEventsGeneratorTest(unittest.TestCase):
     def setUp(self):
         self.session = Session()
         self.client = self.session.create_client(
-            'logs', region_name='us-west-2')
+            'logs', region_name='us-west-2'
+        )
         self.stubber = Stubber(self.client)
         self.group_name = 'groupName'
         self.start = '1970-01-01T00:00:01.000000'
@@ -223,7 +224,8 @@ class BaseLogEventsGeneratorTest(unittest.TestCase):
         self.log_stream_name_prefix = 'foo'
         self.log_timestamp = 1000
         self.expected_log_timestamp_as_datetime = datetime(
-            1970, 1, 1, 0, 0, 1, tzinfo=tz.tzutc())
+            1970, 1, 1, 0, 0, 1, tzinfo=tz.tzutc()
+        )
 
     def get_event(self, event_id, event_message, timestamp=None):
         if timestamp is None:
@@ -239,7 +241,8 @@ class BaseLogEventsGeneratorTest(unittest.TestCase):
         return {
             'eventId': event_id,
             'message': event_message,
-            'timestamp': self.expected_log_timestamp_as_datetime + timedelta(seconds=add_seconds),
+            'timestamp': self.expected_log_timestamp_as_datetime
+            + timedelta(seconds=add_seconds),
             'ingestionTime': self.expected_log_timestamp_as_datetime,
         }
 
@@ -247,7 +250,8 @@ class BaseLogEventsGeneratorTest(unittest.TestCase):
 class TestNoFollowLogEventsGenerator(BaseLogEventsGeneratorTest):
     def test_iter_log_events(self):
         logs_generator = NoFollowLogEventsGenerator(
-            self.client, TimestampUtils())
+            self.client, TimestampUtils()
+        )
 
         self.stubber.add_response(
             'filter_log_events',
@@ -256,7 +260,7 @@ class TestNoFollowLogEventsGenerator(BaseLogEventsGeneratorTest):
                     self.get_event('event-1', 'event-1-message'),
                     self.get_event('event-2', 'event-2-message'),
                 ],
-                'nextToken': 'token'
+                'nextToken': 'token',
             },
             expected_params={
                 'logGroupName': self.group_name,
@@ -264,8 +268,8 @@ class TestNoFollowLogEventsGenerator(BaseLogEventsGeneratorTest):
                 'startTime': self.expected_start_as_milli_epoch,
                 'filterPattern': self.filter_pattern,
                 'logStreamNames': self.log_stream_names,
-                'logStreamNamePrefix': self.log_stream_name_prefix
-            }
+                'logStreamNamePrefix': self.log_stream_name_prefix,
+            },
         )
         # Add a new page that has no more results
         self.stubber.add_response(
@@ -282,13 +286,17 @@ class TestNoFollowLogEventsGenerator(BaseLogEventsGeneratorTest):
                 'filterPattern': self.filter_pattern,
                 'logStreamNames': self.log_stream_names,
                 'logStreamNamePrefix': self.log_stream_name_prefix,
-                'nextToken': 'token'
-            }
+                'nextToken': 'token',
+            },
         )
         with self.stubber:
             log_events_iter = logs_generator.iter_log_events(
-                self.group_name, self.start, self.filter_pattern,
-                self.log_stream_names, self.log_stream_name_prefix)
+                self.group_name,
+                self.start,
+                self.filter_pattern,
+                self.log_stream_names,
+                self.log_stream_name_prefix,
+            )
             actual_log_events = [event for event in log_events_iter]
         self.assertEqual(
             actual_log_events,
@@ -296,7 +304,7 @@ class TestNoFollowLogEventsGenerator(BaseLogEventsGeneratorTest):
                 self.get_expected_event('event-1', 'event-1-message'),
                 self.get_expected_event('event-2', 'event-2-message'),
                 self.get_expected_event('event-3', 'event-3-message'),
-            ]
+            ],
         )
 
 
@@ -305,7 +313,8 @@ class TestFollowLogEventsGenerator(BaseLogEventsGeneratorTest):
         super(TestFollowLogEventsGenerator, self).setUp()
         self.mock_sleep = mock.Mock(time.sleep)
         self.logs_generator = FollowLogEventsGenerator(
-            self.client, TimestampUtils(), self.mock_sleep)
+            self.client, TimestampUtils(), self.mock_sleep
+        )
 
     def test_iter_log_events(self):
         self.stubber.add_response(
@@ -315,7 +324,7 @@ class TestFollowLogEventsGenerator(BaseLogEventsGeneratorTest):
                     self.get_event('event-1', 'event-1-message'),
                     self.get_event('event-2', 'event-2-message'),
                 ],
-                'nextToken': 'token'
+                'nextToken': 'token',
             },
             expected_params={
                 'logGroupName': self.group_name,
@@ -324,7 +333,7 @@ class TestFollowLogEventsGenerator(BaseLogEventsGeneratorTest):
                 'filterPattern': self.filter_pattern,
                 'logStreamNames': self.log_stream_names,
                 'logStreamNamePrefix': self.log_stream_name_prefix,
-            }
+            },
         )
         # Add a new page that has no nextToken
         self.stubber.add_response(
@@ -341,14 +350,18 @@ class TestFollowLogEventsGenerator(BaseLogEventsGeneratorTest):
                 'filterPattern': self.filter_pattern,
                 'logStreamNames': self.log_stream_names,
                 'logStreamNamePrefix': self.log_stream_name_prefix,
-                'nextToken': 'token'
-            }
+                'nextToken': 'token',
+            },
         )
         self.mock_sleep.side_effect = KeyboardInterrupt()
         with self.stubber:
             log_events_iter = self.logs_generator.iter_log_events(
-                self.group_name, self.start, self.filter_pattern,
-                self.log_stream_names, self.log_stream_name_prefix)
+                self.group_name,
+                self.start,
+                self.filter_pattern,
+                self.log_stream_names,
+                self.log_stream_name_prefix,
+            )
             actual_log_events = [event for event in log_events_iter]
         self.mock_sleep.assert_called_once_with(5)
         self.assertEqual(
@@ -357,7 +370,7 @@ class TestFollowLogEventsGenerator(BaseLogEventsGeneratorTest):
                 self.get_expected_event('event-1', 'event-1-message'),
                 self.get_expected_event('event-2', 'event-2-message'),
                 self.get_expected_event('event-3', 'event-3-message'),
-            ]
+            ],
         )
 
     def test_polls_with_last_next_token(self):
@@ -367,12 +380,12 @@ class TestFollowLogEventsGenerator(BaseLogEventsGeneratorTest):
                 'events': [
                     self.get_event('event-1', 'event-1-message', 1000),
                 ],
-                'nextToken': 'token'
+                'nextToken': 'token',
             },
             expected_params={
                 'logGroupName': self.group_name,
                 'interleaved': True,
-            }
+            },
         )
         # Add a new page that has no nextToken
         self.stubber.add_response(
@@ -385,8 +398,8 @@ class TestFollowLogEventsGenerator(BaseLogEventsGeneratorTest):
             expected_params={
                 'logGroupName': self.group_name,
                 'interleaved': True,
-                'nextToken': 'token'
-            }
+                'nextToken': 'token',
+            },
         )
 
         # Because there is no token for the last page, it should remove
@@ -402,16 +415,14 @@ class TestFollowLogEventsGenerator(BaseLogEventsGeneratorTest):
             expected_params={
                 'logGroupName': self.group_name,
                 'interleaved': True,
-                'startTime': 2000
-            }
+                'startTime': 2000,
+            },
         )
-        self.mock_sleep.side_effect = [
-            None,
-            KeyboardInterrupt()
-        ]
+        self.mock_sleep.side_effect = [None, KeyboardInterrupt()]
         with self.stubber:
             log_events_iter = self.logs_generator.iter_log_events(
-                self.group_name)
+                self.group_name
+            )
             actual_log_events = [event for event in log_events_iter]
         self.mock_sleep.assert_has_calls([mock.call(5), mock.call(5)])
         self.assertEqual(
@@ -420,7 +431,7 @@ class TestFollowLogEventsGenerator(BaseLogEventsGeneratorTest):
                 self.get_expected_event('event-1', 'event-1-message'),
                 self.get_expected_event('event-2', 'event-2-message', 1),
                 self.get_expected_event('event-3', 'event-3-message', 2),
-            ]
+            ],
         )
 
     def test_iter_log_events_filters_empty_events_list(self):
@@ -432,7 +443,7 @@ class TestFollowLogEventsGenerator(BaseLogEventsGeneratorTest):
             expected_params={
                 'logGroupName': self.group_name,
                 'interleaved': True,
-            }
+            },
         )
         # Add a new page that has events
         # It should make a call with the same parameters as the
@@ -449,15 +460,13 @@ class TestFollowLogEventsGenerator(BaseLogEventsGeneratorTest):
             expected_params={
                 'logGroupName': self.group_name,
                 'interleaved': True,
-            }
+            },
         )
-        self.mock_sleep.side_effect = [
-            None,
-            KeyboardInterrupt()
-        ]
+        self.mock_sleep.side_effect = [None, KeyboardInterrupt()]
         with self.stubber:
             log_events_iter = self.logs_generator.iter_log_events(
-                self.group_name)
+                self.group_name
+            )
             actual_log_events = [event for event in log_events_iter]
         self.mock_sleep.assert_has_calls([mock.call(5), mock.call(5)])
         self.assertEqual(
@@ -466,10 +475,9 @@ class TestFollowLogEventsGenerator(BaseLogEventsGeneratorTest):
                 self.get_expected_event('event-1', 'event-1-message'),
                 self.get_expected_event('event-2', 'event-2-message'),
                 self.get_expected_event('event-3', 'event-3-message'),
-            ]
+            ],
         )
 
-
     def test_iter_log_events_filters_old_events(self):
         self.stubber.add_response(
             'filter_log_events',
@@ -482,7 +490,7 @@ class TestFollowLogEventsGenerator(BaseLogEventsGeneratorTest):
             expected_params={
                 'logGroupName': self.group_name,
                 'interleaved': True,
-            }
+            },
         )
         # Add a new page that has no nextToken
         # It should update startTime with the max timestamp
@@ -499,16 +507,16 @@ class TestFollowLogEventsGenerator(BaseLogEventsGeneratorTest):
             expected_params={
                 'logGroupName': self.group_name,
                 'interleaved': True,
-                'startTime': self.get_event('event-2', 'event-2-message')['timestamp']
-            }
+                'startTime': self.get_event('event-2', 'event-2-message')[
+                    'timestamp'
+                ],
+            },
         )
-        self.mock_sleep.side_effect = [
-            None,
-            KeyboardInterrupt()
-        ]
+        self.mock_sleep.side_effect = [None, KeyboardInterrupt()]
         with self.stubber:
             log_events_iter = self.logs_generator.iter_log_events(
-                self.group_name)
+                self.group_name
+            )
             actual_log_events = [event for event in log_events_iter]
         self.mock_sleep.assert_has_calls([mock.call(5), mock.call(5)])
         self.assertEqual(
@@ -517,5 +525,5 @@ class TestFollowLogEventsGenerator(BaseLogEventsGeneratorTest):
                 self.get_expected_event('event-1', 'event-1-message'),
                 self.get_expected_event('event-2', 'event-2-message'),
                 self.get_expected_event('event-3', 'event-3-message'),
-            ]
+            ],
         )
