@@ -10,14 +10,14 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-import pytest
 import sys
 
+import pytest
+
 from awscli.customizations.s3 import transferconfig
 
 
 class TestTransferConfig:
-
     def build_config_with(self, **config_from_user):
         return transferconfig.RuntimeConfig().build_config(**config_from_user)
 
@@ -32,7 +32,7 @@ class TestTransferConfig:
     def test_user_provides_partial_overrides(self):
         config_from_user = {
             'max_concurrent_requests': '20',
-            'multipart_threshold': str(64 * (1024 ** 2)),
+            'multipart_threshold': str(64 * (1024**2)),
         }
         runtime_config = self.build_config_with(**config_from_user)
         # Our overrides were accepted.
@@ -68,18 +68,18 @@ class TestTransferConfig:
         # of Py_ssize_t on python 3, but notably not the maximum size of an
         # int since they are effectively unbounded.
         long_value = sys.maxsize + 1
-        runtime_config = self.build_config_with(
-            multipart_threshold=long_value)
+        runtime_config = self.build_config_with(multipart_threshold=long_value)
         assert runtime_config['multipart_threshold'] == long_value
 
     @pytest.mark.parametrize(
-        'provided,resolved', [
+        'provided,resolved',
+        [
             (None, 'auto'),
             ('auto', 'auto'),
             ('classic', 'classic'),
             ('default', 'classic'),
             ('crt', 'crt'),
-        ]
+        ],
     )
     def test_set_preferred_transfer_client(self, provided, resolved):
         config_kwargs = {}
@@ -97,14 +97,19 @@ class TestTransferConfig:
             ('max_bandwidth', '1000', 1000),
             ('max_bandwidth', '1000B/s', 1000),
             ('max_bandwidth', '8000b/s', 1000),
-
             # target_bandwidth cases
             ('target_bandwidth', '5MB/s', 5 * 1024 * 1024),
             ('target_bandwidth', '1Mb/s', 1 * 1024 * 1024 / 8),
             ('target_bandwidth', '1000', 1000),
             ('target_bandwidth', '1000B/s', 1000),
             ('target_bandwidth', '8000b/s', 1000),
-        ]
+            # disk_throughput cases
+            ('disk_throughput', '1MB/s', 1024 * 1024),
+            ('disk_throughput', '10Mb/s', 10 * 1024 * 1024 / 8),
+            ('disk_throughput', '1000', 1000),
+            ('disk_throughput', '1000B/s', 1000),
+            ('disk_throughput', '8000b/s', 1000),
+        ],
     )
     def test_rate_conversions(self, config_name, provided, expected):
         params = {config_name: provided}
@@ -121,7 +126,6 @@ class TestTransferConfig:
             ('max_bandwidth', '100/s'),
             ('max_bandwidth', ''),
             ('max_bandwidth', 'value-with-no-digits'),
-
             # target_bandwidth cases
             ('target_bandwidth', '1MB'),
             ('target_bandwidth', '1B'),
@@ -129,7 +133,14 @@ class TestTransferConfig:
             ('target_bandwidth', '100/s'),
             ('target_bandwidth', ''),
             ('target_bandwidth', 'value-with-no-digits'),
-        ]
+            # disk_throughput cases
+            ('disk_throughput', '1MB'),
+            ('disk_throughput', '1B'),
+            ('disk_throughput', '1b'),
+            ('disk_throughput', '100/s'),
+            ('disk_throughput', ''),
+            ('disk_throughput', 'value-with-no-digits'),
+        ],
     )
     def test_invalid_rate_values(self, config_name, provided):
         params = {config_name: provided}
@@ -140,6 +151,22 @@ class TestTransferConfig:
         with pytest.raises(transferconfig.InvalidConfigError):
             self.build_config_with(preferred_transfer_client='not-supported')
 
+    @pytest.mark.parametrize(
+        'attr,val,expected',
+        [
+            ('should_stream', 'true', True),
+            ('should_stream', 'false', False),
+            ('should_stream', None, None),
+            ('direct_io', 'true', True),
+            ('direct_io', 'false', False),
+            ('direct_io', None, None),
+        ],
+    )
+    def test_convert_booleans(self, attr, val, expected):
+        params = {attr: val}
+        runtime_config = self.build_config_with(**params)
+        assert runtime_config[attr] == expected
+
 
 class TestConvertToS3TransferConfig:
     def test_convert(self):
@@ -151,15 +178,18 @@ class TestConvertToS3TransferConfig:
             'max_bandwidth': 1024 * 1024,
             'addressing_style': 'path',
             'use_accelerate_endpoint': True,
+            'io_chunksize': 1024 * 1024,
             # This is a TransferConfig only option, it should
             # just be ignored if it's in the ~/.aws/config for now.
             'max_in_memory_upload_chunks': 1000,
         }
         result = transferconfig.create_transfer_config_from_runtime_config(
-            runtime_config)
+            runtime_config
+        )
         assert result.multipart_threshold == 1
         assert result.multipart_chunksize == 2
         assert result.max_request_concurrency == 3
         assert result.max_request_queue_size == 4
         assert result.max_bandwidth == 1024 * 1024
+        assert result.io_chunksize == 1024 * 1024
         assert result.max_in_memory_upload_chunks != 1000
