@@ -10,15 +10,16 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-from awscli.testutils import unittest
-import mock
+from botocore.hooks import HierarchicalEmitter
 
 from awscli.clidriver import CLIDriver
-from awscli.customizations.commands import BasicHelp, BasicCommand
-from awscli.customizations.commands import BasicDocHandler
-from awscli.testutils import BaseAWSCommandParamsTest
-from botocore.hooks import HierarchicalEmitter
-from tests.unit.test_clidriver import FakeSession, FakeCommand
+from awscli.customizations.commands import (
+    BasicCommand,
+    BasicDocHandler,
+    BasicHelp,
+)
+from awscli.testutils import BaseAWSCommandParamsTest, mock, unittest
+from tests.unit.test_clidriver import FakeCommand, FakeSession
 
 
 class MockCustomCommand(BasicCommand):
@@ -28,22 +29,22 @@ class MockCustomCommand(BasicCommand):
 
 
 class TestCommandLoader(unittest.TestCase):
-
     def test_basic_help_with_contents(self):
         cmd_object = mock.Mock()
         mock_module = mock.Mock()
         mock_module.__file__ = '/some/root'
         cmd_object.DESCRIPTION = BasicCommand.FROM_FILE(
-            'foo', 'bar', 'baz.txt', root_module=mock_module)
+            'foo', 'bar', 'baz.txt', root_module=mock_module
+        )
         help_command = BasicHelp(mock.Mock(), cmd_object, {}, {})
         with mock.patch('awscli.customizations.commands._open') as mock_open:
-            mock_open.return_value.__enter__.return_value.read.return_value = \
+            mock_open.return_value.__enter__.return_value.read.return_value = (
                 'fake description'
+            )
             self.assertEqual(help_command.description, 'fake description')
 
 
 class TestBasicCommand(unittest.TestCase):
-
     def setUp(self):
         self.session = mock.Mock()
         self.command = BasicCommand(self.session)
@@ -80,8 +81,7 @@ class TestBasicCommand(unittest.TestCase):
         self.assertEqual(lineage[0], self.command)
         self.assertIsInstance(lineage[1], BasicCommand)
         self.assertEqual(
-            subcommand.lineage_names,
-            [self.command.name, subcommand.name]
+            subcommand.lineage_names, [self.command.name, subcommand.name]
         )
 
     def test_event_class(self):
@@ -102,7 +102,7 @@ class TestBasicCommandHooks(unittest.TestCase):
     def setUp(self):
         self.session = FakeSession()
         self.session.get_config_variable = mock.Mock()
-        return_values = {'cli_auto_prompt': 'off'}
+        return_values = {'cli_auto_prompt': 'off', 'cli_help_output': None}
         self.session.get_config_variable.side_effect = return_values
         self.emitter = mock.Mock(wraps=HierarchicalEmitter())
         self.session.emitter = self.emitter
@@ -119,21 +119,22 @@ class TestBasicCommandHooks(unittest.TestCase):
 
     def test_expected_events_are_emitted_in_order(self):
         driver = CLIDriver(session=self.session)
-        self.emitter.register(
-            'building-command-table.s3', self.inject_command)
+        self.emitter.register('building-command-table.s3', self.inject_command)
 
         driver.main('s3 foo'.split())
 
-        self.assert_events_fired_in_order([
-            'building-command-table.main',
-            'building-top-level-params',
-            'top-level-args-parsed',
-            'session-initialized',
-            'building-command-table.s3',
-            'building-command-table.s3_foo',
-            'building-arg-table.s3_foo',
-            'before-building-argument-table-parser.s3.foo'
-        ])
+        self.assert_events_fired_in_order(
+            [
+                'building-command-table.main',
+                'building-top-level-params',
+                'top-level-args-parsed',
+                'session-initialized',
+                'building-command-table.s3',
+                'building-command-table.s3_foo',
+                'building-arg-table.s3_foo',
+                'before-building-argument-table-parser.s3.foo',
+            ]
+        )
 
 
 class TestBasicDocHandler(unittest.TestCase):
@@ -217,8 +218,7 @@ class TestUserAgentCommandSection(BaseAWSCommandParamsTest):
 
     def test_customization_in_user_agent_s3_ls(self):
         cmd = 's3 ls'
-        # it should fail but the user_agent should be correct
-        self.run_cmd(cmd, expected_rc=255)
+        self.run_cmd(cmd)
         self._assert_customization_in_user_agent(' md/command#s3.ls')
 
     def test_customization_in_user_agent_logs_tail(self):
