@@ -15,22 +15,23 @@ import subprocess
 
 from botocore.session import Session
 
-from awscli.testutils import unittest
-from awscli.testutils import mock
-from awscli.testutils import FileCreator
-from awscli.alias import AliasSubCommandInjector, InvalidAliasException
-from awscli.alias import AliasLoader
-from awscli.alias import AliasCommandInjector
-from awscli.alias import BaseAliasCommand
-from awscli.alias import ServiceAliasCommand
-from awscli.alias import ExternalAliasCommand
-from awscli.alias import InternalAliasSubCommand
-from awscli.argparser import MainArgParser, ArgParseException
-from awscli.commands import CLICommand
+from awscli.alias import (
+    AliasCommandInjector,
+    AliasLoader,
+    AliasSubCommandInjector,
+    BaseAliasCommand,
+    ExternalAliasCommand,
+    InternalAliasSubCommand,
+    InvalidAliasException,
+    ServiceAliasCommand,
+)
+from awscli.argparser import ArgParseException, MainArgParser
 from awscli.clidriver import CLIDriver
+from awscli.commands import CLICommand
+from awscli.testutils import FileCreator, mock, unittest
 
 
-class FakeParsedArgs(object):
+class FakeParsedArgs:
     def __init__(self, **kwargs):
         self.__dict__.update(kwargs)
 
@@ -72,7 +73,8 @@ class TestAliasLoader(unittest.TestCase):
             f.write('my-alias = my-alias-value')
         alias_interface = AliasLoader(self.alias_file)
         self.assertEqual(
-            alias_interface.get_aliases(), {'my-alias': 'my-alias-value'})
+            alias_interface.get_aliases(), {'my-alias': 'my-alias-value'}
+        )
 
     def test_get_aliases_with_alias_that_includes_parameter(self):
         with open(self.alias_file, 'a+') as f:
@@ -80,35 +82,37 @@ class TestAliasLoader(unittest.TestCase):
         alias_interface = AliasLoader(self.alias_file)
         self.assertEqual(
             alias_interface.get_aliases(),
-            {'my-alias': 'my-alias-value --my-parameter my-value'})
+            {'my-alias': 'my-alias-value --my-parameter my-value'},
+        )
 
     def test_get_aliases_with_alias_that_includes_newlines(self):
         with open(self.alias_file, 'a+') as f:
             f.write('my-alias = my-alias-value\n')
         alias_interface = AliasLoader(self.alias_file)
         self.assertEqual(
-            alias_interface.get_aliases(), {'my-alias': 'my-alias-value'})
+            alias_interface.get_aliases(), {'my-alias': 'my-alias-value'}
+        )
 
     def test_get_aliases_with_alias_that_is_indented(self):
         with open(self.alias_file, 'a+') as f:
             f.write('my-alias = \n  my-alias-value\n')
         alias_interface = AliasLoader(self.alias_file)
         self.assertEqual(
-            alias_interface.get_aliases(), {'my-alias': 'my-alias-value'})
+            alias_interface.get_aliases(), {'my-alias': 'my-alias-value'}
+        )
 
     def test_get_aliases_with_multiple_lines(self):
         with open(self.alias_file, 'a+') as f:
             f.write(
-                'my-alias = \n'
-                '  my-alias-value \\ \n'
-                '  --parameter foo\n'
+                'my-alias = \n' '  my-alias-value \\ \n' '  --parameter foo\n'
             )
         alias_interface = AliasLoader(self.alias_file)
         self.assertEqual(
             alias_interface.get_aliases(),
             # The backslash and newline should be preserved, but
             # still have the beginning and end newlines removed.
-            {'my-alias': 'my-alias-value \\\n--parameter foo'})
+            {'my-alias': 'my-alias-value \\\n--parameter foo'},
+        )
 
     def test_get_aliases_with_multiple_aliases(self):
         with open(self.alias_file, 'a+') as f:
@@ -117,8 +121,11 @@ class TestAliasLoader(unittest.TestCase):
         alias_interface = AliasLoader(self.alias_file)
         self.assertEqual(
             alias_interface.get_aliases(),
-            {'my-alias': 'my-alias-value',
-             'my-second-alias': 'my-second-alias-value'})
+            {
+                'my-alias': 'my-alias-value',
+                'my-second-alias': 'my-second-alias-value',
+            },
+        )
 
     def test_get_aliases_for_service(self):
         with open(self.alias_file, 'a+') as f:
@@ -128,7 +135,8 @@ class TestAliasLoader(unittest.TestCase):
         alias_interface = AliasLoader(self.alias_file)
         self.assertEqual(
             alias_interface.get_aliases(command=('ec2',)),
-            {'list': 'describe-instances', 'regions': 'describe-regions'})
+            {'list': 'describe-instances', 'regions': 'describe-regions'},
+        )
 
     def test_get_aliases_multiple_nesting(self):
         with open(self.alias_file, 'a+') as f:
@@ -137,7 +145,8 @@ class TestAliasLoader(unittest.TestCase):
         alias_interface = AliasLoader(self.alias_file)
         self.assertEqual(
             alias_interface.get_aliases(command=('ec2', 'wait')),
-            {'instance-new-state': 'describe-instances'})
+            {'instance-new-state': 'describe-instances'},
+        )
 
     def test_command_aliases_cleanup_whitespace(self):
         with open(self.alias_file, 'a+') as f:
@@ -152,7 +161,8 @@ class TestAliasLoader(unittest.TestCase):
             alias_interface.get_aliases(command=('iam',)),
             # The backslash and newline should be preserved, but
             # still have the beginning and end newlines removed.
-            {'my-alias': 'my-alias-value \\\n--parameter foo'})
+            {'my-alias': 'my-alias-value \\\n--parameter foo'},
+        )
 
 
 class TestAliasSubcommandInjector(unittest.TestCase):
@@ -176,10 +186,12 @@ class TestAliasSubcommandInjector(unittest.TestCase):
             command_table=self.command_table,
             event_name='building-command-table.iam',
             session=self.session,
-            command_object=self.command_object)
+            command_object=self.command_object,
+        )
         self.assertIn('list', self.command_table)
         self.assertIsInstance(
-            self.command_table['list'], InternalAliasSubCommand)
+            self.command_table['list'], InternalAliasSubCommand
+        )
 
     def test_global_parser_events_workflow(self):
         with open(self.alias_file, 'a+') as f:
@@ -210,14 +222,17 @@ class TestAliasSubcommandInjector(unittest.TestCase):
         alias_cmd = self.command_table['list']
         alias_cmd([], FakeParsedArgs(command='iam'))
         # We should have plumbed through the global parser correctly:
-        global_parser.parse_known_args.assert_called_with(['iam', 'list-roles'])
+        global_parser.parse_known_args.assert_called_with(
+            ['iam', 'list-roles']
+        )
 
     def test_noop_if_no_cmd_aliases_defined(self):
         self.injector.on_building_command_table(
             command_table=self.command_table,
             event_name='building-command-table.iam',
             session=self.session,
-            command_object=self.command_object)
+            command_object=self.command_object,
+        )
         self.assertEqual(self.command_table, {})
 
     def test_can_inject_external_aliases_in_sub_cmd(self):
@@ -228,10 +243,10 @@ class TestAliasSubcommandInjector(unittest.TestCase):
             command_table=self.command_table,
             event_name='building-command-table.iam',
             session=self.session,
-            command_object=self.command_object)
+            command_object=self.command_object,
+        )
         self.assertIn('list', self.command_table)
-        self.assertIsInstance(
-            self.command_table['list'], ExternalAliasCommand)
+        self.assertIsInstance(self.command_table['list'], ExternalAliasCommand)
 
 
 class TestAliasCommandInjector(unittest.TestCase):
@@ -241,13 +256,14 @@ class TestAliasCommandInjector(unittest.TestCase):
         self.alias_loader = AliasLoader(self.alias_file)
         self.session = mock.Mock(spec=Session)
         self.alias_cmd_injector = AliasCommandInjector(
-            self.session, self.alias_loader)
+            self.session, self.alias_loader
+        )
         self.command_table = {}
         self.parser = MainArgParser(
             command_table=self.command_table,
             version_string='version',
             description='description',
-            argument_table={}
+            argument_table={},
         )
 
     def tearDown(self):
@@ -257,21 +273,21 @@ class TestAliasCommandInjector(unittest.TestCase):
         with open(self.alias_file, 'a+') as f:
             f.write('my-alias = my-alias-value\n')
 
-        self.alias_cmd_injector.inject_aliases(
-            self.command_table, self.parser)
+        self.alias_cmd_injector.inject_aliases(self.command_table, self.parser)
         self.assertIn('my-alias', self.command_table)
         self.assertIsInstance(
-            self.command_table['my-alias'], ServiceAliasCommand)
+            self.command_table['my-alias'], ServiceAliasCommand
+        )
 
     def test_external_alias_command(self):
         with open(self.alias_file, 'a+') as f:
             f.write('my-alias = !my-alias-value\n')
 
-        self.alias_cmd_injector.inject_aliases(
-            self.command_table, self.parser)
+        self.alias_cmd_injector.inject_aliases(self.command_table, self.parser)
         self.assertIn('my-alias', self.command_table)
         self.assertIsInstance(
-            self.command_table['my-alias'], ExternalAliasCommand)
+            self.command_table['my-alias'], ExternalAliasCommand
+        )
 
     def test_clobbers_builtins(self):
         builtin_cmd = mock.Mock(spec=CLICommand)
@@ -280,11 +296,11 @@ class TestAliasCommandInjector(unittest.TestCase):
         with open(self.alias_file, 'a+') as f:
             f.write('builtin = my-alias-value\n')
 
-        self.alias_cmd_injector.inject_aliases(
-            self.command_table, self.parser)
+        self.alias_cmd_injector.inject_aliases(self.command_table, self.parser)
         self.assertIn('builtin', self.command_table)
         self.assertIsInstance(
-            self.command_table['builtin'], ServiceAliasCommand)
+            self.command_table['builtin'], ServiceAliasCommand
+        )
 
     def test_shadow_proxy_command(self):
         builtin_cmd = mock.Mock(spec=CLICommand)
@@ -294,15 +310,12 @@ class TestAliasCommandInjector(unittest.TestCase):
         with open(self.alias_file, 'a+') as f:
             f.write('builtin = builtin\n')
 
-        self.alias_cmd_injector.inject_aliases(
-            self.command_table, self.parser)
+        self.alias_cmd_injector.inject_aliases(self.command_table, self.parser)
 
-        self.command_table['builtin'](
-            [], FakeParsedArgs(command='builtin'))
+        self.command_table['builtin']([], FakeParsedArgs(command='builtin'))
         # The builtin command should be passed to the alias
         # command when added to the table.
-        builtin_cmd.assert_called_with(
-            [], FakeParsedArgs(command='builtin'))
+        builtin_cmd.assert_called_with([], FakeParsedArgs(command='builtin'))
 
 
 class TestBaseAliasCommand(unittest.TestCase):
@@ -329,7 +342,7 @@ class TestInternalAliasSubCommand(unittest.TestCase):
             command_table=self.command_table,
             version_string='version',
             description='description',
-            argument_table={}
+            argument_table={},
         )
 
     def create_alias_sub_command(self):
@@ -348,7 +361,8 @@ class TestInternalAliasSubCommand(unittest.TestCase):
         parsed_globals = FakeParsedArgs(command=self.parent_command)
         alias_cmd(args=[], parsed_globals=parsed_globals)
         self.command_object.assert_called_with(
-            [self.alias_value], parsed_globals,
+            [self.alias_value],
+            parsed_globals,
         )
 
     def test_alias_with_alias_specific_args(self):
@@ -388,8 +402,8 @@ class TestInternalAliasSubCommand(unittest.TestCase):
         self.global_args_parser.add_argument('--endpoint-url')
         alias_cmd = self.create_alias_sub_command()
         parsed_globals = FakeParsedArgs(
-            command=self.parent_command,
-            endpoint_url='http://localhost:8000/')
+            command=self.parent_command, endpoint_url='http://localhost:8000/'
+        )
         alias_cmd(args=[], parsed_globals=parsed_globals)
         self.command_object.assert_called_with(
             ['list-stacks'],
@@ -432,7 +446,8 @@ class TestInternalAliasSubCommand(unittest.TestCase):
         alias_cmd(args=[], parsed_globals=parsed_globals)
         self.command_object.assert_not_called()
         self.shadow_proxy_command.assert_called_with(
-            ['--stack-status-filter', 'CREATE_COMPLETE'], parsed_globals,
+            ['--stack-status-filter', 'CREATE_COMPLETE'],
+            parsed_globals,
         )
 
 
@@ -452,11 +467,11 @@ class TestServiceAliasCommand(unittest.TestCase):
             command_table=command_table,
             version_string='version',
             description='description',
-            argument_table={}
+            argument_table={},
         )
         if extra_params:
             for extra_param in extra_params:
-                parser.add_argument('--'+extra_param)
+                parser.add_argument('--' + extra_param)
         return parser
 
     def test_alias_with_only_service_command(self):
@@ -465,11 +480,13 @@ class TestServiceAliasCommand(unittest.TestCase):
         command_table = self.create_command_table([alias_value])
         parser = self.create_parser(command_table)
         alias_cmd = ServiceAliasCommand(
-            self.alias_name, alias_value, self.session, command_table, parser)
+            self.alias_name, alias_value, self.session, command_table, parser
+        )
 
         alias_cmd([], FakeParsedArgs(command=self.alias_name))
         command_table['myservice'].assert_called_with(
-            [], FakeParsedArgs(command='myservice'))
+            [], FakeParsedArgs(command='myservice')
+        )
 
     def tests_alias_with_shadow_proxy_command(self):
         alias_value = 'some-service'
@@ -482,13 +499,19 @@ class TestServiceAliasCommand(unittest.TestCase):
         parser = self.create_parser(command_table)
 
         alias_cmd = ServiceAliasCommand(
-            self.alias_name, alias_value, self.session, command_table,
-            parser, shadow_proxy_command)
+            self.alias_name,
+            alias_value,
+            self.session,
+            command_table,
+            parser,
+            shadow_proxy_command,
+        )
         command_table[self.alias_name] = alias_cmd
 
         alias_cmd([], FakeParsedArgs(command=self.alias_name))
         shadow_proxy_command.assert_called_with(
-            [], FakeParsedArgs(command=alias_value))
+            [], FakeParsedArgs(command=alias_value)
+        )
 
     def test_alias_with_shadow_proxy_command_no_match(self):
         alias_value = 'some-other-command'
@@ -501,13 +524,19 @@ class TestServiceAliasCommand(unittest.TestCase):
         parser = self.create_parser(command_table)
 
         alias_cmd = ServiceAliasCommand(
-            self.alias_name, alias_value, self.session, command_table,
-            parser, shadow_proxy_command)
+            self.alias_name,
+            alias_value,
+            self.session,
+            command_table,
+            parser,
+            shadow_proxy_command,
+        )
         command_table[self.alias_name] = alias_cmd
 
         alias_cmd([], FakeParsedArgs(command=self.alias_name))
         command_table[alias_value].assert_called_with(
-            [], FakeParsedArgs(command=alias_value))
+            [], FakeParsedArgs(command=alias_value)
+        )
         # Even though it was provided, it should not be called because
         # the alias value did not match the shadow command name.
         self.assertFalse(shadow_proxy_command.called)
@@ -518,12 +547,14 @@ class TestServiceAliasCommand(unittest.TestCase):
         command_table = self.create_command_table(['myservice'])
         parser = self.create_parser(command_table)
         alias_cmd = ServiceAliasCommand(
-            self.alias_name, alias_value, self.session, command_table, parser)
+            self.alias_name, alias_value, self.session, command_table, parser
+        )
 
         parsed_globals = FakeParsedArgs(command=self.alias_name)
         alias_cmd([], parsed_globals)
         command_table['myservice'].assert_called_with(
-            ['myoperation'], FakeParsedArgs(command='myservice'))
+            ['myoperation'], FakeParsedArgs(command='myservice')
+        )
 
     def test_alias_then_help_command(self):
         alias_value = 'myservice myoperation'
@@ -531,12 +562,14 @@ class TestServiceAliasCommand(unittest.TestCase):
         command_table = self.create_command_table(['myservice'])
         parser = self.create_parser(command_table)
         alias_cmd = ServiceAliasCommand(
-            self.alias_name, alias_value, self.session, command_table, parser)
+            self.alias_name, alias_value, self.session, command_table, parser
+        )
 
         parsed_globals = FakeParsedArgs(command=self.alias_name)
         alias_cmd(['help'], parsed_globals)
         command_table['myservice'].assert_called_with(
-            ['myoperation', 'help'], FakeParsedArgs(command='myservice'))
+            ['myoperation', 'help'], FakeParsedArgs(command='myservice')
+        )
 
     def test_alias_then_additional_parameters(self):
         alias_value = 'myservice myoperation'
@@ -544,13 +577,14 @@ class TestServiceAliasCommand(unittest.TestCase):
         command_table = self.create_command_table(['myservice'])
         parser = self.create_parser(command_table)
         alias_cmd = ServiceAliasCommand(
-            self.alias_name, alias_value, self.session, command_table, parser)
+            self.alias_name, alias_value, self.session, command_table, parser
+        )
 
         parsed_globals = FakeParsedArgs(command=self.alias_name)
         alias_cmd(['--parameter', 'val'], parsed_globals)
         command_table['myservice'].assert_called_with(
             ['myoperation', '--parameter', 'val'],
-            FakeParsedArgs(command='myservice')
+            FakeParsedArgs(command='myservice'),
         )
 
     def test_alias_with_operation_and_parameters(self):
@@ -559,12 +593,13 @@ class TestServiceAliasCommand(unittest.TestCase):
         command_table = self.create_command_table(['myservice'])
         parser = self.create_parser(command_table)
         alias_cmd = ServiceAliasCommand(
-            self.alias_name, alias_value, self.session, command_table, parser)
+            self.alias_name, alias_value, self.session, command_table, parser
+        )
 
         alias_cmd([], FakeParsedArgs(command=self.alias_name))
         command_table['myservice'].assert_called_with(
             ['myoperation', '--my-parameter', 'val'],
-            FakeParsedArgs(command='myservice')
+            FakeParsedArgs(command='myservice'),
         )
 
     def test_alias_with_operation_and_global_parameters(self):
@@ -572,14 +607,16 @@ class TestServiceAliasCommand(unittest.TestCase):
 
         command_table = self.create_command_table(['myservice'])
         parser = self.create_parser(
-            command_table, extra_params=['global-param'])
+            command_table, extra_params=['global-param']
+        )
         alias_cmd = ServiceAliasCommand(
-            self.alias_name, alias_value, self.session, command_table, parser)
+            self.alias_name, alias_value, self.session, command_table, parser
+        )
 
         alias_cmd([], FakeParsedArgs(command=self.alias_name))
         command_table['myservice'].assert_called_with(
             ['myoperation'],
-            FakeParsedArgs(command='myservice', global_param='val')
+            FakeParsedArgs(command='myservice', global_param='val'),
         )
 
     def test_maintains_global_defaults_when_missing_from_alias(self):
@@ -589,16 +626,17 @@ class TestServiceAliasCommand(unittest.TestCase):
         parser = self.create_parser(command_table)
         parser.add_argument('--global-with-default', default='default')
         alias_cmd = ServiceAliasCommand(
-            self.alias_name, alias_value, self.session, command_table, parser)
+            self.alias_name, alias_value, self.session, command_table, parser
+        )
         alias_cmd(
             [],
             FakeParsedArgs(
-                command=self.alias_name, global_with_default='default')
+                command=self.alias_name, global_with_default='default'
+            ),
         )
         command_table['myservice'].assert_called_with(
             ['myoperation'],
-            FakeParsedArgs(
-                command='myservice', global_with_default='default')
+            FakeParsedArgs(command='myservice', global_with_default='default'),
         )
 
     def test_sets_global_parameters_when_differs_from_defaults(self):
@@ -608,13 +646,15 @@ class TestServiceAliasCommand(unittest.TestCase):
         parser = self.create_parser(command_table)
         parser.add_argument('--global-with-default', default='default')
         alias_cmd = ServiceAliasCommand(
-            self.alias_name, alias_value, self.session, command_table, parser)
+            self.alias_name, alias_value, self.session, command_table, parser
+        )
 
         alias_cmd([], FakeParsedArgs(command=self.alias_name))
         command_table['myservice'].assert_called_with(
             ['myoperation'],
             FakeParsedArgs(
-                command='myservice', global_with_default='non-default')
+                command='myservice', global_with_default='non-default'
+            ),
         )
 
     def test_global_parameters_can_be_emitted_and_modified(self):
@@ -622,9 +662,11 @@ class TestServiceAliasCommand(unittest.TestCase):
 
         command_table = self.create_command_table(['myservice'])
         parser = self.create_parser(
-            command_table, extra_params=['global-param'])
+            command_table, extra_params=['global-param']
+        )
         alias_cmd = ServiceAliasCommand(
-            self.alias_name, alias_value, self.session, command_table, parser)
+            self.alias_name, alias_value, self.session, command_table, parser
+        )
 
         def replace_global_param_value_with_foo(event_name, **kwargs):
             parsed_args = kwargs['parsed_args']
@@ -633,61 +675,57 @@ class TestServiceAliasCommand(unittest.TestCase):
         self.session.emit.side_effect = replace_global_param_value_with_foo
         alias_cmd([], FakeParsedArgs(command=self.alias_name))
         self.session.emit.assert_called_with(
-            'top-level-args-parsed', parsed_args=mock.ANY,
-            session=self.session)
+            'top-level-args-parsed', parsed_args=mock.ANY, session=self.session
+        )
 
         command_table['myservice'].assert_called_with(
             ['myoperation'],
-            FakeParsedArgs(command='myservice', global_param='foo')
+            FakeParsedArgs(command='myservice', global_param='foo'),
         )
 
     def test_properly_handles_multiple_spaces(self):
-        alias_value = (
-            'myservice myoperation    --my-parameter val'
-        )
+        alias_value = 'myservice myoperation    --my-parameter val'
 
         command_table = self.create_command_table(['myservice'])
         parser = self.create_parser(command_table)
         alias_cmd = ServiceAliasCommand(
-            self.alias_name, alias_value, self.session, command_table, parser)
+            self.alias_name, alias_value, self.session, command_table, parser
+        )
 
         alias_cmd([], FakeParsedArgs(command=self.alias_name))
         command_table['myservice'].assert_called_with(
             ['myoperation', '--my-parameter', 'val'],
-            FakeParsedArgs(command='myservice')
+            FakeParsedArgs(command='myservice'),
         )
 
     def test_properly_parses_aliases_broken_by_multiple_lines(self):
-        alias_value = (
-            'myservice myoperation \\'
-            '\n--my-parameter val'
-        )
+        alias_value = 'myservice myoperation \\' '\n--my-parameter val'
 
         command_table = self.create_command_table(['myservice'])
         parser = self.create_parser(command_table)
         alias_cmd = ServiceAliasCommand(
-            self.alias_name, alias_value, self.session, command_table, parser)
+            self.alias_name, alias_value, self.session, command_table, parser
+        )
 
         alias_cmd([], FakeParsedArgs(command=self.alias_name))
         command_table['myservice'].assert_called_with(
             ['myoperation', '--my-parameter', 'val'],
-            FakeParsedArgs(command='myservice')
+            FakeParsedArgs(command='myservice'),
         )
 
     def test_properly_preserves_quoted_values(self):
-        alias_value = (
-            'myservice myoperation --my-parameter \' \n$""\''
-        )
+        alias_value = 'myservice myoperation --my-parameter \' \n$""\''
 
         command_table = self.create_command_table(['myservice'])
         parser = self.create_parser(command_table)
         alias_cmd = ServiceAliasCommand(
-            self.alias_name, alias_value, self.session, command_table, parser)
+            self.alias_name, alias_value, self.session, command_table, parser
+        )
 
         alias_cmd([], FakeParsedArgs(command=self.alias_name))
         command_table['myservice'].assert_called_with(
             ['myoperation', '--my-parameter', ' \n$""'],
-            FakeParsedArgs(command='myservice')
+            FakeParsedArgs(command='myservice'),
         )
 
     def test_errors_when_service_command_is_invalid(self):
@@ -696,7 +734,8 @@ class TestServiceAliasCommand(unittest.TestCase):
         command_table = self.create_command_table(['myservice'])
         parser = self.create_parser(command_table)
         alias_cmd = ServiceAliasCommand(
-            self.alias_name, alias_value, self.session, command_table, parser)
+            self.alias_name, alias_value, self.session, command_table, parser
+        )
 
         with self.assertRaises(ArgParseException):
             # Even though we catch the system exit, a message will always
@@ -710,9 +749,11 @@ class TestServiceAliasCommand(unittest.TestCase):
 
         command_table = self.create_command_table(['myservice'])
         parser = self.create_parser(
-            command_table, extra_params=['global-param'])
+            command_table, extra_params=['global-param']
+        )
         alias_cmd = ServiceAliasCommand(
-            self.alias_name, alias_value, self.session, command_table, parser)
+            self.alias_name, alias_value, self.session, command_table, parser
+        )
 
         with self.assertRaises(ArgParseException):
             # Even though we catch the system exit, a message will always
@@ -724,29 +765,26 @@ class TestServiceAliasCommand(unittest.TestCase):
     def test_errors_when_shell_cannot_parse_alias(self):
         # Ending with a escape character that does not escape anything
         # is invalid and cannot be properly parsed.
-        alias_value = (
-            'myservice myoperation \\'
-        )
+        alias_value = 'myservice myoperation \\'
 
         command_table = self.create_command_table(['myservice'])
         parser = self.create_parser(command_table)
         alias_cmd = ServiceAliasCommand(
-            self.alias_name, alias_value, self.session, command_table, parser)
+            self.alias_name, alias_value, self.session, command_table, parser
+        )
 
         with self.assertRaises(InvalidAliasException):
             alias_cmd([], FakeParsedArgs(command=self.alias_name))
 
     def test_errors_when_unsupported_global_parameter_in_alias(self):
         # Unsupported global parameters are: --profile and --debug
-        alias_value = (
-            'myservice myoperation --profile value'
-        )
+        alias_value = 'myservice myoperation --profile value'
 
         command_table = self.create_command_table(['myservice'])
-        parser = self.create_parser(
-            command_table, extra_params=['profile'])
+        parser = self.create_parser(command_table, extra_params=['profile'])
         alias_cmd = ServiceAliasCommand(
-            self.alias_name, alias_value, self.session, command_table, parser)
+            self.alias_name, alias_value, self.session, command_table, parser
+        )
 
         with self.assertRaises(InvalidAliasException):
             alias_cmd([], FakeParsedArgs(command=self.alias_name))
@@ -759,33 +797,35 @@ class TestExternalAliasCommand(unittest.TestCase):
     def test_run_external_command(self):
         alias_value = '!ls'
         alias_cmd = ExternalAliasCommand(
-            'alias-name', alias_value, invoker=self.subprocess_call)
+            'alias-name', alias_value, invoker=self.subprocess_call
+        )
         alias_cmd([], FakeParsedArgs(command='alias-name'))
         self.subprocess_call.assert_called_with('ls', shell=True)
 
     def test_external_command_returns_rc_of_subprocess_call(self):
         alias_value = '!ls'
         alias_cmd = ExternalAliasCommand(
-            'alias-name', alias_value, invoker=self.subprocess_call)
+            'alias-name', alias_value, invoker=self.subprocess_call
+        )
         self.subprocess_call.return_value = 1
         self.assertEqual(
-            alias_cmd([], FakeParsedArgs(command='alias-name')), 1)
+            alias_cmd([], FakeParsedArgs(command='alias-name')), 1
+        )
 
     def test_external_command_uses_literal_alias_value(self):
-        alias_value = (
-            '!f () {\n'
-            '  ls .\n'
-            '}; f'
-        )
+        alias_value = '!f () {\n' '  ls .\n' '}; f'
         alias_cmd = ExternalAliasCommand(
-            'alias-name', alias_value, invoker=self.subprocess_call)
+            'alias-name', alias_value, invoker=self.subprocess_call
+        )
         alias_cmd([], FakeParsedArgs(command='alias-name'))
         self.subprocess_call.assert_called_with(alias_value[1:], shell=True)
 
     def test_external_command_then_additional_args(self):
         alias_value = '!f () { ls "$1" }; f'
         alias_cmd = ExternalAliasCommand(
-            'alias-name', alias_value, invoker=self.subprocess_call)
+            'alias-name', alias_value, invoker=self.subprocess_call
+        )
         alias_cmd(['extra'], FakeParsedArgs(command='alias-name'))
         self.subprocess_call.assert_called_with(
-            'f () { ls "$1" }; f extra', shell=True)
+            'f () { ls "$1" }; f extra', shell=True
+        )
