@@ -12,17 +12,33 @@
 # language governing permissions and limitations under the License.
 import json
 
-from botocore.model import ShapeResolver, StructureShape, StringShape, \
-    ListShape, MapShape, Shape, DenormalizedStructureBuilder
+from botocore.model import (
+    DenormalizedStructureBuilder,
+    ListShape,
+    MapShape,
+    Shape,
+    ShapeResolver,
+    StringShape,
+    StructureShape,
+)
 
-from awscli.testutils import mock, unittest, FileCreator
-from awscli.clidocs import OperationDocumentEventHandler, \
-    CLIDocumentEventHandler, TopicListerDocumentEventHandler, \
-    TopicDocumentEventHandler, GlobalOptionsDocumenter
-from awscli.bcdoc.restdoc import ReSTDocument
-from awscli.help import ServiceHelpCommand, TopicListerCommand, \
-    TopicHelpCommand, HelpCommand
 from awscli.arguments import CustomArgument
+from awscli.bcdoc.restdoc import ReSTDocument
+from awscli.clidocs import (
+    CLIDocumentEventHandler,
+    GlobalOptionsDocumenter,
+    OperationDocumentEventHandler,
+    ServiceDocumentEventHandler,
+    TopicDocumentEventHandler,
+    TopicListerDocumentEventHandler,
+)
+from awscli.help import (
+    HelpCommand,
+    ServiceHelpCommand,
+    TopicHelpCommand,
+    TopicListerCommand,
+)
+from awscli.testutils import FileCreator, mock, unittest
 
 
 class TestRecursiveShapes(unittest.TestCase):
@@ -35,11 +51,13 @@ class TestRecursiveShapes(unittest.TestCase):
         self.operation_model.service_model.operation_names = []
         self.help_command.obj = self.operation_model
         self.operation_handler = OperationDocumentEventHandler(
-            self.help_command)
+            self.help_command
+        )
 
     def assert_rendered_docs_contain(self, expected):
-        writes = [args[0][0] for args in
-                  self.help_command.doc.write.call_args_list]
+        writes = [
+            args[0][0] for args in self.help_command.doc.write.call_args_list
+        ]
         writes = '\n'.join(writes)
         self.assertIn(expected, writes)
 
@@ -56,16 +74,20 @@ class TestRecursiveShapes(unittest.TestCase):
                 'members': {
                     'A': {'shape': 'NonRecursive'},
                     'B': {'shape': 'RecursiveStruct'},
-                }
+                },
             },
-            'NonRecursive': {'type': 'string'}
+            'NonRecursive': {'type': 'string'},
         }
-        shape = StructureShape('RecursiveStruct', shape_map['RecursiveStruct'],
-                               ShapeResolver(shape_map))
+        shape = StructureShape(
+            'RecursiveStruct',
+            shape_map['RecursiveStruct'],
+            ShapeResolver(shape_map),
+        )
 
         self.arg_table['arg-name'] = mock.Mock(argument_model=shape)
         self.operation_handler.doc_option_example(
-            'arg-name', self.help_command, 'process-cli-arg.foo.bar')
+            'arg-name', self.help_command, 'process-cli-arg.foo.bar'
+        )
         self.assert_rendered_docs_contain('{ ... recursive ... }')
 
     def test_handle_recursive_output(self):
@@ -75,12 +97,15 @@ class TestRecursiveShapes(unittest.TestCase):
                 'members': {
                     'A': {'shape': 'NonRecursive'},
                     'B': {'shape': 'RecursiveStruct'},
-                }
+                },
             },
-            'NonRecursive': {'type': 'string'}
+            'NonRecursive': {'type': 'string'},
         }
-        shape = StructureShape('RecursiveStruct', shape_map['RecursiveStruct'],
-                               ShapeResolver(shape_map))
+        shape = StructureShape(
+            'RecursiveStruct',
+            shape_map['RecursiveStruct'],
+            ShapeResolver(shape_map),
+        )
 
         operation_model = mock.Mock()
         operation_model.output_shape = shape
@@ -94,16 +119,18 @@ class TestRecursiveShapes(unittest.TestCase):
                 'type': 'structure',
                 'members': {
                     'A': {'shape': 'Empty'},
-                }
+                },
             },
-            'Empty': {'type': 'structure', 'members': {}}
+            'Empty': {'type': 'structure', 'members': {}},
         }
-        shape = StructureShape('InputStruct', shape_map['InputStruct'],
-                               ShapeResolver(shape_map))
+        shape = StructureShape(
+            'InputStruct', shape_map['InputStruct'], ShapeResolver(shape_map)
+        )
 
         self.arg_table['arg-name'] = mock.Mock(argument_model=shape)
         self.operation_handler.doc_option_example(
-            'arg-name', self.help_command, 'process-cli-arg.foo.bar')
+            'arg-name', self.help_command, 'process-cli-arg.foo.bar'
+        )
         self.assert_proper_indentation()
 
     def test_handle_no_output_shape(self):
@@ -114,14 +141,10 @@ class TestRecursiveShapes(unittest.TestCase):
         self.assert_rendered_docs_contain('None')
 
     def test_handle_memberless_output_shape(self):
-        shape_map = {
-            'NoMembers': {
-                'type': 'structure',
-                'members': {}
-            }
-        }
-        shape = StructureShape('NoMembers', shape_map['NoMembers'],
-                               ShapeResolver(shape_map))
+        shape_map = {'NoMembers': {'type': 'structure', 'members': {}}}
+        shape = StructureShape(
+            'NoMembers', shape_map['NoMembers'], ShapeResolver(shape_map)
+        )
 
         operation_model = mock.Mock()
         operation_model.output_shape = shape
@@ -151,11 +174,7 @@ class TestCLIDocumentEventHandler(unittest.TestCase):
         return help_command
 
     def create_tagged_union_shape(self):
-        shape_model = {
-            'type': 'structure',
-            'union': True,
-            'members': {}
-        }
+        shape_model = {'type': 'structure', 'union': True, 'members': {}}
         tagged_union = StructureShape('tagged_union', shape_model)
         return tagged_union
 
@@ -176,8 +195,12 @@ class TestCLIDocumentEventHandler(unittest.TestCase):
         # Create an arbitrary help command class. This was chosen
         # because it is fairly easy to instantiate.
         help_cmd = ServiceHelpCommand(
-            self.session, self.obj, self.command_table, self.arg_table,
-            self.name, self.event_class
+            self.session,
+            self.obj,
+            self.command_table,
+            self.arg_table,
+            self.name,
+            self.event_class,
         )
 
         doc_handler = CLIDocumentEventHandler(help_cmd)
@@ -187,55 +210,71 @@ class TestCLIDocumentEventHandler(unittest.TestCase):
 
     def test_breadcrumbs_html(self):
         help_cmd = ServiceHelpCommand(
-            self.session, self.obj, self.command_table, self.arg_table,
-            self.name, self.event_class
+            self.session,
+            self.obj,
+            self.command_table,
+            self.arg_table,
+            self.name,
+            self.event_class,
         )
         help_cmd.doc.target = 'html'
         doc_handler = CLIDocumentEventHandler(help_cmd)
         doc_handler.doc_breadcrumbs(help_cmd)
         self.assertEqual(
-            help_cmd.doc.getvalue().decode('utf-8'),
-            '[ :ref:`aws <cli:aws>` ]'
+            help_cmd.doc.getvalue().decode('utf-8'), '[ :ref:`aws <cli:aws>` ]\n\n'
         )
 
     def test_breadcrumbs_service_command_html(self):
         help_cmd = ServiceHelpCommand(
-            self.session, self.obj, self.command_table, self.arg_table,
-            self.name, 'ec2'
+            self.session,
+            self.obj,
+            self.command_table,
+            self.arg_table,
+            self.name,
+            'ec2',
         )
         help_cmd.doc.target = 'html'
         doc_handler = CLIDocumentEventHandler(help_cmd)
         doc_handler.doc_breadcrumbs(help_cmd)
         self.assertEqual(
-            help_cmd.doc.getvalue().decode('utf-8'),
-            '[ :ref:`aws <cli:aws>` ]'
+            help_cmd.doc.getvalue().decode('utf-8'), '[ :ref:`aws <cli:aws>` ]\n\n'
         )
 
     def test_breadcrumbs_operation_command_html(self):
         help_cmd = ServiceHelpCommand(
-            self.session, self.obj, self.command_table, self.arg_table,
-            self.name, 'ec2.run-instances'
+            self.session,
+            self.obj,
+            self.command_table,
+            self.arg_table,
+            self.name,
+            'ec2.run-instances',
         )
         help_cmd.doc.target = 'html'
         doc_handler = CLIDocumentEventHandler(help_cmd)
         doc_handler.doc_breadcrumbs(help_cmd)
         self.assertEqual(
             help_cmd.doc.getvalue().decode('utf-8'),
-            '[ :ref:`aws <cli:aws>` . :ref:`ec2 <cli:aws ec2>` ]'
+            '[ :ref:`aws <cli:aws>` . :ref:`ec2 <cli:aws ec2>` ]\n\n'
         )
 
     def test_breadcrumbs_wait_command_html(self):
         help_cmd = ServiceHelpCommand(
-            self.session, self.obj, self.command_table, self.arg_table,
-            self.name, 's3api.wait.object-exists'
+            self.session,
+            self.obj,
+            self.command_table,
+            self.arg_table,
+            self.name,
+            's3api.wait.object-exists',
         )
         help_cmd.doc.target = 'html'
         doc_handler = CLIDocumentEventHandler(help_cmd)
         doc_handler.doc_breadcrumbs(help_cmd)
         self.assertEqual(
             help_cmd.doc.getvalue().decode('utf-8'),
-            ('[ :ref:`aws <cli:aws>` . :ref:`s3api <cli:aws s3api>`'
-             ' . :ref:`wait <cli:aws s3api wait>` ]')
+            (
+                '[ :ref:`aws <cli:aws>` . :ref:`s3api <cli:aws s3api>`'
+                ' . :ref:`wait <cli:aws s3api wait>` ]\n\n'
+            )
         )
 
     def test_documents_json_header_shape(self):
@@ -243,17 +282,14 @@ class TestCLIDocumentEventHandler(unittest.TestCase):
             'type': 'string',
             'jsonvalue': True,
             'location': 'header',
-            'locationName': 'X-Amz-Header-Name'
+            'locationName': 'X-Amz-Header-Name',
         }
         shape = StringShape('JSONValueArg', shape)
         rendered = self.get_help_docs_for_argument(shape)
         self.assertIn('(JSON)', rendered)
 
     def test_documents_enum_values(self):
-        shape = {
-            'type': 'string',
-            'enum': ['FOO', 'BAZ']
-        }
+        shape = {'type': 'string', 'enum': ['FOO', 'BAZ']}
         shape = StringShape('EnumArg', shape)
         rendered = self.get_help_docs_for_argument(shape)
         self.assertIn('Possible values', rendered)
@@ -267,13 +303,15 @@ class TestCLIDocumentEventHandler(unittest.TestCase):
                 'members': {
                     'A': {'shape': 'NonRecursive'},
                     'B': {'shape': 'RecursiveStruct'},
-                }
+                },
             },
-            'NonRecursive': {'type': 'string'}
+            'NonRecursive': {'type': 'string'},
         }
-        shape = StructureShape('RecursiveStruct',
-                               shape_map['RecursiveStruct'],
-                               ShapeResolver(shape_map))
+        shape = StructureShape(
+            'RecursiveStruct',
+            shape_map['RecursiveStruct'],
+            ShapeResolver(shape_map),
+        )
         rendered = self.get_help_docs_for_argument(shape)
         self.assertIn('( ... recursive ... )', rendered)
 
@@ -284,20 +322,22 @@ class TestCLIDocumentEventHandler(unittest.TestCase):
                 'members': {
                     'A': {'shape': 'NestedStruct'},
                     'B': {'shape': 'NestedStruct'},
-                }
+                },
             },
             'NestedStruct': {
                 'type': 'structure',
                 'members': {
                     'Nested_A': {'shape': 'Line'},
                     'Nested_B': {'shape': 'Line'},
-                }
+                },
             },
-            'Line': {'type': 'string'}
+            'Line': {'type': 'string'},
         }
-        shape = StructureShape('UpperStructure',
-                               shape_map['UpperStructure'],
-                               ShapeResolver(shape_map))
+        shape = StructureShape(
+            'UpperStructure',
+            shape_map['UpperStructure'],
+            ShapeResolver(shape_map),
+        )
         rendered = self.get_help_docs_for_argument(shape)
         self.assertEqual(rendered.count('A -> (structure)'), 1)
         self.assertEqual(rendered.count('B -> (structure)'), 1)
@@ -315,12 +355,13 @@ class TestCLIDocumentEventHandler(unittest.TestCase):
                 'members': {
                     'Nested_A': {'shape': 'Line'},
                     'Nested_B': {'shape': 'Line'},
-                }
+                },
             },
-            'Line': {'type': 'string'}
+            'Line': {'type': 'string'},
         }
-        shape = ListShape('UpperList', shape_map['UpperList'],
-                          ShapeResolver(shape_map))
+        shape = ListShape(
+            'UpperList', shape_map['UpperList'], ShapeResolver(shape_map)
+        )
         rendered = self.get_help_docs_for_argument(shape)
         self.assertEqual(rendered.count('(structure)'), 1)
         self.assertEqual(rendered.count('Nested_A -> (string)'), 1)
@@ -338,12 +379,13 @@ class TestCLIDocumentEventHandler(unittest.TestCase):
                 'members': {
                     'Nested_A': {'shape': 'Line'},
                     'Nested_B': {'shape': 'Line'},
-                }
+                },
             },
-            'Line': {'type': 'string'}
+            'Line': {'type': 'string'},
         }
-        shape = MapShape('UpperMap', shape_map['UpperMap'],
-                         ShapeResolver(shape_map))
+        shape = MapShape(
+            'UpperMap', shape_map['UpperMap'], ShapeResolver(shape_map)
+        )
         rendered = self.get_help_docs_for_argument(shape)
         self.assertEqual(rendered.count('key -> (structure)'), 1)
         self.assertEqual(rendered.count('value -> (structure)'), 1)
@@ -372,7 +414,9 @@ class TestCLIDocumentEventHandler(unittest.TestCase):
         self.assertIn(
             'See also: `AWS API Documentation '
             '<https://docs.aws.amazon.com/goto/'
-            'WebAPI/service-1-2-3/myoperation>`_', rendered)
+            'WebAPI/service-1-2-3/myoperation>`_',
+            rendered,
+        )
 
     def test_includes_streaming_blob_options(self):
         help_command = self.create_help_command()
@@ -381,8 +425,9 @@ class TestCLIDocumentEventHandler(unittest.TestCase):
         blob_arg = CustomArgument('blob_arg', argument_model=blob_shape)
         help_command.arg_table = {'blob_arg': blob_arg}
         operation_handler = OperationDocumentEventHandler(help_command)
-        operation_handler.doc_option(arg_name='blob_arg',
-                                     help_command=help_command)
+        operation_handler.doc_option(
+            arg_name='blob_arg', help_command=help_command
+        )
         rendered = help_command.doc.getvalue().decode('utf-8')
         self.assertIn('streaming blob', rendered)
 
@@ -390,38 +435,42 @@ class TestCLIDocumentEventHandler(unittest.TestCase):
         help_command = self.create_help_command()
         blob_shape = Shape('blob_shape', {'type': 'blob'})
         blob_shape.serialization = {'streaming': True}
-        blob_arg = CustomArgument(name='blob_arg',
-                                  argument_model=blob_shape,
-                                  help_text='FooBar')
+        blob_arg = CustomArgument(
+            name='blob_arg', argument_model=blob_shape, help_text='FooBar'
+        )
         help_command.arg_table = {'blob_arg': blob_arg}
         operation_handler = OperationDocumentEventHandler(help_command)
-        operation_handler.doc_option(arg_name='blob_arg',
-                                     help_command=help_command)
+        operation_handler.doc_option(
+            arg_name='blob_arg', help_command=help_command
+        )
         rendered = help_command.doc.getvalue().decode('utf-8')
         self.assertRegex(rendered, r'FooBar[\s\S]*streaming blob')
 
     def test_includes_tagged_union_options(self):
         help_command = self.create_help_command()
         tagged_union = self.create_tagged_union_shape()
-        arg = CustomArgument(name='tagged_union',
-                             argument_model=tagged_union)
+        arg = CustomArgument(name='tagged_union', argument_model=tagged_union)
         help_command.arg_table = {'tagged_union': arg}
         operation_handler = OperationDocumentEventHandler(help_command)
-        operation_handler.doc_option(arg_name='tagged_union',
-                                     help_command=help_command)
+        operation_handler.doc_option(
+            arg_name='tagged_union', help_command=help_command
+        )
         rendered = help_command.doc.getvalue().decode('utf-8')
         self.assertIn('(tagged union structure)', rendered)
 
     def test_tagged_union_comes_after_docstring_options(self):
         help_command = self.create_help_command()
         tagged_union = self.create_tagged_union_shape()
-        arg = CustomArgument(name='tagged_union',
-                             argument_model=tagged_union,
-                             help_text='FooBar')
+        arg = CustomArgument(
+            name='tagged_union',
+            argument_model=tagged_union,
+            help_text='FooBar',
+        )
         help_command.arg_table = {'tagged_union': arg}
         operation_handler = OperationDocumentEventHandler(help_command)
-        operation_handler.doc_option(arg_name='tagged_union',
-                                     help_command=help_command)
+        operation_handler.doc_option(
+            arg_name='tagged_union', help_command=help_command
+        )
         rendered = help_command.doc.getvalue().decode('utf-8')
         self.assertRegex(rendered, r'FooBar[\s\S]*Tagged Union')
 
@@ -429,21 +478,98 @@ class TestCLIDocumentEventHandler(unittest.TestCase):
         help_command = self.create_help_command()
         tagged_union = self.create_tagged_union_shape()
         tagged_union.documentation = "FooBar"
-        shape = DenormalizedStructureBuilder().with_members({
-            'foo': {
-                'type': 'structure',
-                'union': True,
-                'documentation': 'FooBar',
-                'members': {}
-            }
-        }).build_model()
+        shape = (
+            DenormalizedStructureBuilder()
+            .with_members(
+                {
+                    'foo': {
+                        'type': 'structure',
+                        'union': True,
+                        'documentation': 'FooBar',
+                        'members': {},
+                    }
+                }
+            )
+            .build_model()
+        )
         help_command.obj.output_shape = shape
         operation_handler = OperationDocumentEventHandler(help_command)
-        operation_handler.doc_output(help_command=help_command,
-                                     event_name='foobar')
+        operation_handler.doc_output(
+            help_command=help_command, event_name='foobar'
+        )
         rendered = help_command.doc.getvalue().decode('utf-8')
         self.assertRegex(rendered, r'FooBar[\s\S]*Tagged Union')
 
+    def test_documents_required_parameters(self):
+        """Tests that required parameters are correctly documented."""
+        shape_map = {
+            'ParentStructure': {
+                'type': 'structure',
+                'required': ['RequiredParameter'],
+                'members': {
+                    'RequiredParameter': {'shape': 'StringMember'},
+                    'OptionalParameter': {'shape': 'StringMember'},
+                },
+            },
+            'StringMember': {'type': 'string'},
+        }
+
+        resolver = ShapeResolver(shape_map)
+        parent_shape = StructureShape(
+            'ParentStructure', shape_map['ParentStructure'], resolver
+        )
+
+        rendered = self.get_help_docs_for_argument(parent_shape)
+
+        required_index = rendered.find('RequiredParameter -> (string)')
+        optional_index = rendered.find('OptionalParameter -> (string)')
+
+        self.assertIn('[required]', rendered[required_index:optional_index])
+        optional_text = rendered[optional_index:]
+        self.assertNotIn('[required]', optional_text)
+
+    def test_documents_constraints(self):
+        shape = {'type': 'string', 'min': 0, 'max': 10, 'pattern': '.*'}
+        shape = StringShape('ConstrainedArg', shape)
+        arg = CustomArgument('ConstrainedArg', argument_model=shape)
+        help_command = self.create_help_command()
+        help_command.arg_table = {'ConstrainedArg': arg}
+        operation_handler = OperationDocumentEventHandler(help_command)
+        operation_handler.doc_option(
+            arg_name='ConstrainedArg', help_command=help_command
+        )
+        rendered = help_command.doc.getvalue().decode('utf-8')
+        self.assertIn('Constraints', rendered)
+        self.assertIn('min: ``0``', rendered)
+        self.assertIn('max: ``10``', rendered)
+        self.assertIn('pattern: ``.*``', rendered)
+
+    def test_meta_description_operation_command_html(self):
+        help_cmd = ServiceHelpCommand(
+            self.session, self.obj, self.command_table, self.arg_table,
+            self.name, 'ec2.run-instances'
+        )
+        help_cmd.doc.target = 'html'
+        doc_handler = OperationDocumentEventHandler(help_cmd)
+        doc_handler.doc_meta_description(help_cmd)
+
+        meta_description = help_cmd.doc.getvalue().decode('utf-8')
+        self.assertIn(".. meta::\n   :description: ", meta_description)
+        self.assertIn('to run the ec2 run-instances command', meta_description)
+
+    def test_meta_description_service_html(self):
+        help_cmd = ServiceHelpCommand(
+            self.session, self.obj, self.command_table, self.arg_table,
+            self.name, 'ec2'
+        )
+        help_cmd.doc.target = 'html'
+        doc_handler = ServiceDocumentEventHandler(help_cmd)
+        doc_handler.doc_meta_description(help_cmd)
+
+        meta_description = help_cmd.doc.getvalue().decode('utf-8')
+        self.assertIn(".. meta::\n   :description: Learn about the AWS CLI ", meta_description)
+        self.assertIn(' ec2 commands', meta_description)
+
 
 class TestTopicDocumentEventHandlerBase(unittest.TestCase):
     def setUp(self):
@@ -457,10 +583,12 @@ class TestTopicDocumentEventHandlerBase(unittest.TestCase):
         with open(self.json_index, 'w') as f:
             json.dump(self.tags_dict, f, indent=4, sort_keys=True)
 
-        self.index_patch = mock.patch('awscli.topictags.TopicTagDB.index_file',
-                                      self.json_index)
-        self.dir_patch = mock.patch('awscli.topictags.TopicTagDB.topic_dir',
-                                    self.file_creator.rootdir)
+        self.index_patch = mock.patch(
+            'awscli.topictags.TopicTagDB.index_file', self.json_index
+        )
+        self.dir_patch = mock.patch(
+            'awscli.topictags.TopicTagDB.topic_dir', self.file_creator.rootdir
+        )
         self.index_patch.start()
         self.dir_patch.start()
 
@@ -472,29 +600,28 @@ class TestTopicDocumentEventHandlerBase(unittest.TestCase):
 
 class TestTopicListerDocumentEventHandler(TestTopicDocumentEventHandlerBase):
     def setUp(self):
-        super(TestTopicListerDocumentEventHandler, self).setUp()
+        super().setUp()
         self.descriptions = [
             'This describes the first topic',
             'This describes the second topic',
-            'This describes the third topic'
+            'This describes the third topic',
         ]
         self.tags_dict = {
             'topic-name-1': {
                 'title': ['The first topic title'],
                 'description': [self.descriptions[0]],
-                'category': ['General']
+                'category': ['General'],
             },
             'topic-name-2': {
                 'title': ['The second topic title'],
                 'description': [self.descriptions[1]],
-                'category': ['S3']
+                'category': ['S3'],
             },
             'topic-name-3': {
                 'title': ['The third topic title'],
                 'description': [self.descriptions[2]],
-                'category': ['General']
-            }
-
+                'category': ['General'],
+            },
         }
 
         with open(self.json_index, 'w') as f:
@@ -509,31 +636,31 @@ class TestTopicListerDocumentEventHandler(TestTopicDocumentEventHandlerBase):
         self.cmd.doc.target = 'html'
         self.doc_handler.doc_breadcrumbs(self.cmd)
         self.assertEqual(
-            '[ :ref:`aws <cli:aws>` ]',
-            self.cmd.doc.getvalue().decode('utf-8')
+            '[ :ref:`aws <cli:aws>` ]', self.cmd.doc.getvalue().decode('utf-8')
         )
 
     def test_title(self):
         self.doc_handler.doc_title(self.cmd)
         title_contents = self.cmd.doc.getvalue().decode('utf-8')
-        self.assertIn('.. _cli:aws help %s:' % self.cmd.name, title_contents)
+        self.assertIn(f'.. _cli:aws help {self.cmd.name}:', title_contents)
         self.assertIn('AWS CLI Topic Guide', title_contents)
 
     def test_description(self):
         self.doc_handler.doc_description(self.cmd)
         self.assertIn(
             'This is the AWS CLI Topic Guide',
-            self.cmd.doc.getvalue().decode('utf-8')
+            self.cmd.doc.getvalue().decode('utf-8'),
         )
 
     def test_subitems_start(self):
         ref_output = [
             '-------\nGeneral\n-------',
-            ('* topic-name-1: %s\n'
-             '* topic-name-3: %s\n' %
-             (self.descriptions[0], self.descriptions[2])),
+            (
+                f'* topic-name-1: {self.descriptions[0]}\n'
+                f'* topic-name-3: {self.descriptions[2]}\n'
+            ),
             '--\nS3\n--',
-            '* topic-name-2: %s\n' % self.descriptions[1]
+            f'* topic-name-2: {self.descriptions[1]}\n',
         ]
 
         self.doc_handler.doc_subitems_start(self.cmd)
@@ -548,12 +675,14 @@ class TestTopicListerDocumentEventHandler(TestTopicDocumentEventHandlerBase):
         self.cmd.doc.target = 'html'
         ref_output = [
             '-------\nGeneral\n-------',
-            ('* :ref:`topic-name-1 <cli:aws help topic-name-1>`: %s\n'
-             '* :ref:`topic-name-3 <cli:aws help topic-name-3>`: %s\n' %
-             (self.descriptions[0], self.descriptions[2])),
+            (
+                f'* :ref:`topic-name-1 <cli:aws help topic-name-1>`: {self.descriptions[0]}\n'
+                f'* :ref:`topic-name-3 <cli:aws help topic-name-3>`: {self.descriptions[2]}\n'
+            ),
             '--\nS3\n--',
-            ('* :ref:`topic-name-2 <cli:aws help topic-name-2>`: %s\n' %
-             self.descriptions[1])
+            (
+                f'* :ref:`topic-name-2 <cli:aws help topic-name-2>`: {self.descriptions[1]}\n'
+            ),
         ]
 
         self.doc_handler.doc_subitems_start(self.cmd)
@@ -568,7 +697,7 @@ class TestTopicListerDocumentEventHandler(TestTopicDocumentEventHandlerBase):
 
 class TestTopicDocumentEventHandler(TestTopicDocumentEventHandlerBase):
     def setUp(self):
-        super(TestTopicDocumentEventHandler, self).setUp()
+        super().setUp()
         self.name = 'topic-name-1'
         self.title = 'The first topic title'
         self.description = 'This is about the first topic'
@@ -583,7 +712,7 @@ class TestTopicDocumentEventHandler(TestTopicDocumentEventHandlerBase):
                 'description': [self.description],
                 'category': [self.category],
                 'related topic': [self.related_topic],
-                'related command': [self.related_command]
+                'related command': [self.related_command],
             }
         }
         with open(self.json_index, 'w') as f:
@@ -599,13 +728,13 @@ class TestTopicDocumentEventHandler(TestTopicDocumentEventHandlerBase):
         self.doc_handler.doc_breadcrumbs(self.cmd)
         self.assertEqual(
             '[ :ref:`aws <cli:aws>` . :ref:`topics <cli:aws help topics>` ]',
-            self.cmd.doc.getvalue().decode('utf-8')
+            self.cmd.doc.getvalue().decode('utf-8'),
         )
 
     def test_title(self):
         self.doc_handler.doc_title(self.cmd)
         title_contents = self.cmd.doc.getvalue().decode('utf-8')
-        self.assertIn('.. _cli:aws help %s:' % self.name, title_contents)
+        self.assertIn(f'.. _cli:aws help {self.name}:', title_contents)
         self.assertIn(self.title, title_contents)
 
     def test_description(self):
@@ -615,7 +744,7 @@ class TestTopicDocumentEventHandler(TestTopicDocumentEventHandlerBase):
             ':category:' + self.category,
             ':related command: ' + self.related_command,
             ':related topic: ' + self.related_topic,
-            self.topic_body
+            self.topic_body,
         ]
         body = '\n'.join(lines)
         self.file_creator.create_file(self.name + '.rst', body)
@@ -625,9 +754,7 @@ class TestTopicDocumentEventHandler(TestTopicDocumentEventHandlerBase):
         self.assertNotIn(':title ' + self.title, contents)
 
     def test_description_no_tags(self):
-        lines = [
-            self.topic_body
-        ]
+        lines = [self.topic_body]
         body = '\n'.join(lines)
         self.file_creator.create_file(self.name + '.rst', body)
         self.doc_handler.doc_description(self.cmd)
@@ -638,12 +765,12 @@ class TestTopicDocumentEventHandler(TestTopicDocumentEventHandlerBase):
         lines = [
             ':title: ' + self.title,
             ':description: ' + self.description,
-            ':related command: ' + self.related_command
+            ':related command: ' + self.related_command,
         ]
         body_lines = [
             ':related_topic: ' + self.related_topic,
             self.topic_body,
-            ':foo: bar'
+            ':foo: bar',
         ]
         body = '\n'.join(lines + body_lines)
         ref_body = '\n'.join(body_lines)
@@ -666,10 +793,12 @@ class TestGlobalOptionsDocumenter(unittest.TestCase):
             name = f'{t}_type'
             help_text = f'This arg type is {t}'
             choices = ['A', 'B', 'C'] if t == 'string' else []
-            arg_table[name] = CustomArgument(name=name,
-                                             cli_type_name=t,
-                                             help_text=help_text,
-                                             choices=choices)
+            arg_table[name] = CustomArgument(
+                name=name,
+                cli_type_name=t,
+                help_text=help_text,
+                choices=choices,
+            )
         help_command = mock.Mock(spec=HelpCommand)
         help_command.arg_table = arg_table
         help_command.doc = ReSTDocument()
