@@ -18,35 +18,31 @@
 # distribution. This environment variable provides the option to remove the
 # repository root from sys.path to be able to rely on the installed
 # distribution when running the tests.
-import os
-import sys
-import time
-import random
-import shutil
-import contextlib
-import tempfile
 import binascii
-import platform
-import select
+import contextlib
 import datetime
-from io import BytesIO
-from subprocess import Popen, PIPE
-
-from dateutil.tz import tzlocal
+import os
+import platform
+import random
+import select
+import shutil
+import sys
+import tempfile
+import time
 import unittest
+from io import BytesIO
+from subprocess import PIPE, Popen
 from unittest import mock
 
 import botocore.loaders
 import botocore.session
+from botocore import credentials, utils
 from botocore.awsrequest import AWSResponse
-from botocore.compat import urlparse
-from botocore.compat import parse_qs
-from botocore import utils
-from botocore import credentials
-from botocore.httpchecksum import _CHECKSUM_CLS, DEFAULT_CHECKSUM_ALGORITHM
+from botocore.compat import parse_qs, urlparse
 from botocore.configprovider import create_botocore_default_config_mapping
+from botocore.httpchecksum import _CHECKSUM_CLS, DEFAULT_CHECKSUM_ALGORITHM
 from botocore.stub import Stubber
-
+from dateutil.tz import tzlocal
 
 _LOADER = botocore.loaders.Loader()
 
@@ -81,9 +77,12 @@ def skip_if_windows(reason):
         def test_some_non_windows_stuff(self):
             self.assertEqual(...)
     """
+
     def decorator(func):
         return unittest.skipIf(
-            platform.system() not in ['Darwin', 'Linux'], reason)(func)
+            platform.system() not in ['Darwin', 'Linux'], reason
+        )(func)
+
     return decorator
 
 
@@ -124,7 +123,7 @@ def temporary_file(mode):
 
     """
     temporary_directory = tempfile.mkdtemp()
-    basename = 'tmpfile-%s-%s' % (int(time.time()), random.randint(1, 1000))
+    basename = f'tmpfile-{int(time.time())}-{random.randint(1, 1000)}'
     full_filename = os.path.join(temporary_directory, basename)
     open(full_filename, 'w').close()
     try:
@@ -161,7 +160,7 @@ class BaseSessionTest(BaseEnvVar):
     """
 
     def setUp(self, **environ):
-        super(BaseSessionTest, self).setUp()
+        super().setUp()
         self.environ['AWS_ACCESS_KEY_ID'] = 'access_key'
         self.environ['AWS_SECRET_ACCESS_KEY'] = 'secret_key'
         self.environ['AWS_CONFIG_FILE'] = 'no-exist-foo'
@@ -199,10 +198,9 @@ class BaseClientDriverTest(unittest.TestCase):
         self.driver.stop()
 
 
-class ClientDriver(object):
+class ClientDriver:
     CLIENT_SERVER = os.path.join(
-        os.path.dirname(os.path.abspath(__file__)),
-        'cmd-runner'
+        os.path.dirname(os.path.abspath(__file__)), 'cmd-runner'
     )
 
     def __init__(self):
@@ -230,8 +228,12 @@ class ClientDriver(object):
 
     def start(self, env=None):
         """Start up the command runner process."""
-        self._popen = Popen([sys.executable, self.CLIENT_SERVER],
-                            stdout=PIPE, stdin=PIPE, env=env)
+        self._popen = Popen(
+            [sys.executable, self.CLIENT_SERVER],
+            stdout=PIPE,
+            stdin=PIPE,
+            env=env,
+        )
 
     def stop(self):
         """Shutdown the command runner process."""
@@ -280,8 +282,7 @@ class ClientDriver(object):
         self.send_cmd(*cmd)
         result = self._popen.stdout.readline().strip()
         if result != b'OK':
-            raise RuntimeError(
-                "Error from command '%s': %s" % (cmd, result))
+            raise RuntimeError(f"Error from command '{cmd}': {result}")
 
 
 # This is added to this file because it's used in both
@@ -307,18 +308,21 @@ class IntegerRefresher(credentials.RefreshableCredentials):
     _mandatory_refresh_timeout = 1
     _credentials_expire = 3
 
-    def __init__(self, creds_last_for=_credentials_expire,
-                 advisory_refresh=_advisory_refresh_timeout,
-                 mandatory_refresh=_mandatory_refresh_timeout,
-                 refresh_function=None):
-        expires_in = (
-            self._current_datetime() +
-            datetime.timedelta(seconds=creds_last_for))
+    def __init__(
+        self,
+        creds_last_for=_credentials_expire,
+        advisory_refresh=_advisory_refresh_timeout,
+        mandatory_refresh=_mandatory_refresh_timeout,
+        refresh_function=None,
+    ):
+        expires_in = self._current_datetime() + datetime.timedelta(
+            seconds=creds_last_for
+        )
         if refresh_function is None:
             refresh_function = self._do_refresh
-        super(IntegerRefresher, self).__init__(
-            '0', '0', '0', expires_in,
-            refresh_function, 'INTREFRESH')
+        super().__init__(
+            '0', '0', '0', expires_in, refresh_function, 'INTREFRESH'
+        )
         self.creds_last_for = creds_last_for
         self.refresh_counter = 0
         self._advisory_refresh_timeout = advisory_refresh
@@ -361,6 +365,7 @@ def _urlparse(url):
         url = url.decode('utf8')
     return urlparse(url)
 
+
 def assert_url_equal(url1, url2):
     parts1 = _urlparse(url1)
     parts2 = _urlparse(url2)
@@ -393,7 +398,7 @@ class RawResponse(BytesIO):
             contents = self.read()
 
 
-class BaseHTTPStubber(object):
+class BaseHTTPStubber:
     def __init__(self, obj_with_event_emitter, strict=True):
         self.reset()
         self._strict = strict
@@ -403,8 +408,9 @@ class BaseHTTPStubber(object):
         self.requests = []
         self.responses = []
 
-    def add_response(self, url='https://example.com', status=200, headers=None,
-                     body=b''):
+    def add_response(
+        self, url='https://example.com', status=200, headers=None, body=b''
+    ):
         if headers is None:
             headers = {}
 
@@ -459,7 +465,7 @@ class ConsistencyWaiterException(Exception):
     pass
 
 
-class ConsistencyWaiter(object):
+class ConsistencyWaiter:
     """
     A waiter class for some check to reach a consistent state.
 
@@ -475,8 +481,14 @@ class ConsistencyWaiter(object):
     :param delay: The number of seconds to delay the next API call after a
     failed check call. Default of 5 seconds.
     """
-    def __init__(self, min_successes=1, max_attempts=20, delay=5,
-                 delay_initial_poll=False):
+
+    def __init__(
+        self,
+        min_successes=1,
+        max_attempts=20,
+        delay=5,
+        delay_initial_poll=False,
+    ):
         self.min_successes = min_successes
         self.max_attempts = max_attempts
         self.delay = delay
@@ -513,12 +525,14 @@ class ConsistencyWaiter(object):
 
     def _fail_message(self, attempts, successes):
         format_args = (attempts, successes)
-        return 'Failed after %s attempts, only had %s successes' % format_args
+        return 'Failed after {} attempts, only had {} successes'.format(
+            *format_args
+        )
 
 
 class StubbedSession(botocore.session.Session):
     def __init__(self, *args, **kwargs):
-        super(StubbedSession, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._cached_clients = {}
         self._client_stubs = {}
 
@@ -537,8 +551,7 @@ class StubbedSession(botocore.session.Session):
         return self._cached_clients[service_name]
 
     def _create_stubbed_client(self, service_name, *args, **kwargs):
-        client = super(StubbedSession, self).create_client(
-            service_name, *args, **kwargs)
+        client = super().create_client(service_name, *args, **kwargs)
         stubber = Stubber(client)
         self._client_stubs[service_name] = stubber
         return client
@@ -574,8 +587,7 @@ class FreezeTime(contextlib.ContextDecorator):
             date = datetime.datetime.utcnow()
         self.date = date
         self.datetime_patcher = mock.patch.object(
-            module, 'datetime',
-            mock.Mock(wraps=datetime.datetime)
+            module, 'datetime', mock.Mock(wraps=datetime.datetime)
         )
 
     def __enter__(self, *args, **kwargs):
